<?php
/**
 * Customizer default options
 *
 * @package Theme Palace
 * @subpackage tastypress Pro
 * @since tastypress Pro 1.0.0
 * @return array An array of default values
 */

function tastypress_pro_get_default_theme_options() {
	$theme_data = wp_get_theme();
	$tastypress_pro_default_options = array(
		'search_icon_in_primary_menu_enable' => true,
		// Color Options
		'header_title_color'			=> '#fff',
		'header_tagline_color'			=> '#fff',
		'header_txt_logo_extra'			=> 'show-all',
		'colorscheme_hue'				=> '#F38625',
		'colorscheme'					=> 'default',
		'theme_version'					=> 'lite-version',
		'home_layout'					=> 'default-design',
		'search_icon_in_primary_menu_enable'			=>true,
		'cart_menu_enable'			=>true,
		'menu_btn_label'			=> esc_html__( 'Login', 'tastypress-pro' ),
		
		// typography Options
		'theme_typography' 				=> 'default',
		'body_theme_typography' 		=> 'default',
		
		// loader
		'loader_enable'         		=> false,
		'loader_icon'         			=> 'default',

		// breadcrumb
		'breadcrumb_enable'				=> true,
		'breadcrumb_separator'			=> '/',
		
		// layout 
		'site_layout'         			=> 'wide-layout',
		'sidebar_position'         		=> 'right-sidebar',
		'post_sidebar_position' 		=> 'right-sidebar',
		'page_sidebar_position' 		=> 'right-sidebar',
		'menu_sticky'					=> true,
		'social_nav_enable'				=> true,

		// excerpt options
		'long_excerpt_length'           => 25,
		
		// pagination options
		'pagination_enable'         	=> true,
		'pagination_type'         		=> 'default',

		// footer options
		'copyright_text'           		=> sprintf( esc_html_x( 'Copyright &copy; %1$s %2$s. All Rights Reserved', '1: Year, 2: Site Title with home URL', 'tastypress-pro' ), '[the-year]', '[site-link]' ),
		'scroll_top_visible'        	=> true,

		// reset options
		'reset_options'      			=> false,
		
		// homepage options
		'enable_frontpage_content' 		=> false,

		// homepage sections sortable
		'default_sortable' 						=> 'hero,service,menu,about,counter,reserve,testimonial,download',

		'all_sortable' 						=> 'slider,hero,service,menu,about,counter,reserve,testimonial,download,cta,video,team,recent_products,blog,event,release,featured_products,featured_posts,latest_products,trending_product,highlighted,3column,magazine_featured_post,2column,4column,ads,subscription',

		// blog/archive options
		'your_latest_posts_title' 		=> esc_html__( 'Blogs', 'tastypress-pro' ),
		'hide_date' 					=> false,
		'hide_category'					=> false,
		'blog_page_button' 				=> esc_html__( 'READ MORE', 'tastypress-pro' ),
		'blog_column'					=> 'col-1',

		// single post theme options
		'single_post_hide_date' 		=> false,
		'single_post_hide_author'		=> false,
		'single_post_hide_category'		=> false,
		'single_post_hide_tags'			=> false,

		

		/* Front Page */

		// hero
		'hero_section_enable'			=> true,
		'hero_content_type'			=> 'page',
		'hero_title'					=> esc_html__( 'Delicious Food is Worth Waiting', 'tastypress-pro' ),
		'hero_description'				=> esc_html__( 'FASTEST DELIVERY IN TOWN SUMMER SPECIAL!', 'tastypress-pro' ),
		'hero_btn_title'				=> esc_html__( 'View Menu', 'tastypress-pro' ),
		'hero_label'					=> esc_html__( 'Our Happy Customer', 'tastypress-pro' ),
		'hero_sub_label'				=> esc_html__( '(12.5k Review)', 'tastypress-pro' ),
		'hero_excerpt_length'			=> 25,


		// service
		'service_section_enable'		=> true,
		'service_content_type'			=> 'category',
		'service_count'					=> 3,
		'service_excerpt_length'		=> 25,
		'service_sub_title'				=> esc_html('OUR SERVICES', 'tastypress-pro'),
		'service_title'					=> esc_html('Your Food Delivery Partner', 'tastypress-pro'),
		'service_design_type'			=> 'type-1',

		//menu 
		'menu_section_enable'	=> true,
		'menu_count'			=> 4,
		'menu_content_type'		=> 'page',
		'menu_title'				=> esc_html__( 'Explore Our Tasty Food Lists', 'tastypress-pro' ),
		'menu_sub_title'			=> esc_html__( 'Our Menu', 'tastypress-pro' ),


		// about
		'about_section_enable'			=> true,
		'about_content_type'			=> 'page',
		'about_title'					=> esc_html__( 'TRAVEL & TOUR', 'tastypress-pro' ),
		'about_sub_title'				=> esc_html__( 'about', 'tastypress-pro' ),
		'about_description'				=> esc_html__( 'Lots of people are traveling the entire world. They have got their own purposes. You can also travel the world. We will tell you how to travel the river, sea, hilly areas, mountain & so on...', 'tastypress-pro' ),
		'about_btn_title'				=> esc_html__( 'LEARN More', 'tastypress-pro' ),
		'about_excerpt_length'			=> 25,

		// counter
		'counter_section_enable'		=> true,
		'counter_count'					=> 4,
		'counter_column'				=> 'col-4',
		'counter_sub_title'				=> esc_html__( 'Our Experience', 'tastypress-pro' ),
		'counter_title'					=> esc_html__( 'ADVENTURE STARTS HERE', 'tastypress-pro' ),

		// testimonial
		'testimonial_section_enable'	=> true,
		'testimonial_auto_play'			=> false,
		'testimonial_title'				=> esc_html__( 'WHAT PEOPLE SAYS', 'tastypress-pro' ),
		'testimonial_sub_title'			=> esc_html__( 'Testimonials', 'tastypress-pro' ),
		'testimonial_content_type'		=> 'category',
		'testimonial_count'				=> 3,
		'testimonial_excerpt_length'	=> 30,

		// reserve
		'reserve_section_enable'			=> true,
		'reserve_content_type'				=> 'page',
		'reserve_title'						=> esc_html__( 'TRAVEL & TOUR', 'tastypress-pro' ),
		'reserve_sub_title'					=> esc_html__( 'reserve', 'tastypress-pro' ),
		'reserve_description'				=> esc_html__( 'Lots of people are traveling the entire world. They have got their own purposes. You can also travel the world. We will tell you how to travel the river, sea, hilly areas, mountain & so on...', 'tastypress-pro' ),
		'reserve_btn_title'					=> esc_html__( 'LEARN More', 'tastypress-pro' ),
		'reserve_excerpt_length'			=> 25,

		// download
		'download_section_enable'			=> true,
		'download_content_type'				=> 'page',
		'download_title'					=> esc_html__( 'TRAVEL & TOUR', 'tastypress-pro' ),
		'download_sub_title'				=> esc_html__( 'download', 'tastypress-pro' ),
		'download_description'				=> esc_html__( 'Lots of people are traveling the entire world. They have got their own purposes. You can also travel the world. We will tell you how to travel the river, sea, hilly areas, mountain & so on...', 'tastypress-pro' ),
		'download_btn_title'				=> esc_html__( 'LEARN More', 'tastypress-pro' ),
		'download_excerpt_length'			=> 25,




		// Slider
		'slider_section_enable'			=> true,
		'slider_autoplay'				=> false,
		'slider_btn_label' 				=> esc_html__( 'Learn More', 'tastypress-pro' ),
		'slider_sub_title' 				=> esc_html__( 'Learn More', 'tastypress-pro' ),
		'slider_content_type'			=> 'category',
		'slider_count'					=> 3,
		'slider_excerpt_length'			=> 25,
		'slider_search_enable'			=> true,

		// cta
		'cta_section_enable'			=> true,
		'cta_content_type'				=> 'page',
		'cta_title'						=> esc_html__( 'TRAVEL & TOUR', 'tastypress-pro' ),
		'cta_sub_title'					=> esc_html__( 'cta', 'tastypress-pro' ),
		'cta_description'				=> esc_html__( 'Lots of people are traveling the entire world. They have got their own purposes. You can also travel the world. We will tell you how to travel the river, sea, hilly areas, mountain & so on...', 'tastypress-pro' ),
		'cta_btn_title'					=> esc_html__( 'LEARN More', 'tastypress-pro' ),
		'cta_excerpt_length'			=> 25,

		// video
		'video_section_enable'			=> true,
		'video_content_type'			=> 'page',
		'video_title'					=> esc_html__( 'TRAVEL & TOUR', 'tastypress-pro' ),
		'video_sub_title'				=> esc_html__( 'video', 'tastypress-pro' ),
		'video_description'				=> esc_html__( 'Lots of people are traveling the entire world. They have got their own purposes. You can also travel the world. We will tell you how to travel the river, sea, hilly areas, mountain & so on...', 'tastypress-pro' ),
		'video_btn_title'				=> esc_html__( 'LEARN More', 'tastypress-pro' ),
		'video_excerpt_length'			=> 25,


		// team
		'team_section_enable'		=> true,
		'team_content_type'			=> 'category',
		'team_count'				=> 3,
		'team_excerpt_length'		=> 20,
		'team_sub_title'			=> esc_html('MEET OUR STAFFS', 'tastypress-pro'),
		'team_title'				=> esc_html('Team', 'tastypress-pro'),

        //recent products
		'recent_products_section_enable'	=> false,
		'recent_products_content_type'		=> 'product-category',
		'recent_products_count'				=> 4,
		'recent_products_title'				=> esc_html__( 'RECENT PRODUCTS', 'tastypress-pro' ),
		'recent_products_sub_title'			=> esc_html__( 'Trending', 'tastypress-pro' ),


		// Event
		'event_section_enable'			=> true,
		'event_content_type'			=> 'category',
		'event_count'					=> 3,
		'event_title'					=> esc_html__( 'Upcoming Events', 'tastypress-pro' ),
		'event_subtitle'				=> esc_html__( 'Amazing shows around 2019', 'tastypress-pro' ),
		'event_readmore'				=> esc_html__( 'Buy Ticket', 'tastypress-pro' ),
		'event_btn_title'				=> esc_html__( 'View All Events', 'tastypress-pro' ),

		// Gallery Slider
		'gallery_slider_section_enable'			=> true,
		'gallery_slider_autoplay'				=> false,
		'gallery_slider_btn_title'				=> esc_html__( 'Explore More', 'tastypress-pro' ),
		'gallery_slider_content_type'			=> 'category',
		'gallery_slider_count'					=> 5,

		// popular destination
		'popular_destination_section_enable'	=> true,
		'popular_destination_content_type'		=> 'category',
		'popular_destination_description'		=> esc_html__( 'Bacon ipsum dolor amet kevin picanha sausage corned beef chuck shankle kielbasa chicken meatloaf t-bone buffalo. Pork chop pork belly shank sirloin tri-tip ham alcatra turkey bacon buffalo kielbasa pancetta....', 'tastypress-pro' ),
		'popular_destination_title'				=> esc_html__('DESTINATION','tastypress-pro'),
		'popular_destination_sub_title'			=> esc_html__('Top Travel','tastypress-pro'),
		'popular_destination_post_btn_label'	=> esc_html__( 'Read More', 'tastypress-pro' ),
		'popular_destination_btn_label'			=> esc_html__( 'DISCOVER MORE', 'tastypress-pro' ),

		

		// recommended destination
		'recommended_destination_section_enable'	=> true,
		'recommended_destination_content_type'		=> 'category',
		'recommended_destination_description'		=> esc_html__( 'Lots of people are traveling the entire world. They have got their own purposes. You can also travel the world. We will tell you how to travel the river, sea, hilly areas, mountain & so on...', 'tastypress-pro' ),
		'recommended_destination_title'				=> esc_html__('HOTELS & LODGES','tastypress-pro'),
		'recommended_destination_sub_title'			=> esc_html__('Recommended','tastypress-pro'),
		'recommended_destination_post_btn_label'	=> esc_html__( 'Read More', 'tastypress-pro' ),
		'recommended_destination_btn_label'			=> esc_html__( 'VIEW ALL HOTELS', 'tastypress-pro' ),

		// blog
		'blog_section_enable'			=> true,
		'blog_sub_title'				=> esc_html__('Featured', 'tastypress-pro'),
		'blog_title'					=> esc_html__( 'NEWS & ARTICLES', 'tastypress-pro' ),
		'blog_content_type'				=> 'recent',
		'blog_excerpt_length'			=> 30,
		'blog_count'					=> 3,

		// highlighted
		'highlighted_section_enable'	=> true,
		'highlighted_content_type'		=> 'recent',
		'highlighted_excerpt_length'	=> 30,
		'highlighted_count'				=> 5,

		// release
		'release_section_enable'		=> true,
		'release_sub_title'				=> esc_html__('Featured', 'tastypress-pro'),
		'release_title'					=> esc_html__( 'NEWS & ARTICLES', 'tastypress-pro' ),
		'release_content_type'			=> 'post',
		'release_excerpt_length'		=> 30,

		// 3column
		'3column_section_enable'		=> true,
		'3column_title'					=> esc_html__( 'Three Column Post', 'tastypress-pro' ),
		'3column_content_type'			=> 'recent',
		'3column_excerpt_length'		=> 30,
		'3column_count'					=> 3,

		// magazine_featured_post
		'magazine_featured_post_section_enable'		=> true,
		'magazine_featured_post_title'				=> esc_html__( 'Featured Post', 'tastypress-pro' ),
		'magazine_featured_post_content_type'		=> 'recent',
		'magazine_featured_post_excerpt_length'		=> 30,
		'magazine_featured_post_count'				=> 2,

		// 2column
		'2column_section_enable'	=> true,
		'2column_title'				=> esc_html__( 'Two Column Post', 'tastypress-pro' ),
		'2column_content_type'		=> 'recent',
		'2column_excerpt_length'	=> 30,
		'2column_count'				=> 2,

		// 4column
		'4column_section_enable'		=> true,
		'4column_title'					=> esc_html__( 'Four Column Post', 'tastypress-pro' ),
		'4column_content_type'			=> 'recent',
		'4column_excerpt_length'		=> 30,
		'4column_count'					=> 4,		
		


		// recent_news
		'recent_news_section_enable'	=> true,
		'recent_news_title'				=> esc_html__( 'OUR LATEST NEWS', 'tastypress-pro' ),
		'recent_news_sub_title'			=> esc_html__( 'Articles', 'tastypress-pro' ),
		'recent_news_button'			=> esc_html__( 'Learn More', 'tastypress-pro' ),
		'recent_news_content_type'		=> 'category',
		'recent_news_count'				=> 3,
		'recent_news_excerpt_length'	=> 30,

		// featured_posts
		'featured_posts_section_enable'		=> true,
		'featured_posts_content_type'		=> 'category',
		'featured_posts_count'				=> 3,

		//latest products
		'latest_products_section_enable'	=> false,
		'latest_products_content_type'		=> 'product-category',
		'latest_products_count'				=> 4,
		'latest_products_title'				=> esc_html__( 'Shopping Every Day', 'tastypress-pro' ),
		'latest_products_sub_title'			=> esc_html__( 'PRODUCTS', 'tastypress-pro' ),

		//popular collection
		'collection_section_enable'		=> false,
		'collection_title'				=> esc_html__( 'PRODUCTS COLLECTION', 'tastypress-pro' ),
		'collection_subtitle'			=> esc_html__( 'Shop', 'tastypress-pro' ),

		
		//featured section
		'featured_products_section_enable'		=> false,

		//trending_product 
		'trending_product_section_enable'		=> false,
		'trending_product_count'				=> 3,

		// subscription
		'subscription_section_enable'	=> true,
		'subscription_sub_title'		=> esc_html__( 'Subscribe', 'tastypress-pro' ),
		'subscription_title'			=> esc_html__( 'TRAVEL WITH US', 'tastypress-pro' ),
		'subscription_description'		=> esc_html__( 'We recommend you to subscribe to our newpaper, enter your email address below to get daily update about travel & tourism.', 'tastypress-pro' ),
		'subscription_btn_title'		=> esc_html__( 'Subscribe Now', 'tastypress-pro' ),

		'ads_section_enable'			=> true,

	);

	$output = apply_filters( 'tastypress_pro_default_theme_options', $tastypress_pro_default_options );

	// Sort array in ascending order, according to the key:
	if ( ! empty( $output ) ) {
		ksort( $output );
	}

	return $output;
}