<?php
/**
 * 3column Section options
 *
 * @package Theme Palace
 * @subpackage tastypress Pro
 * @since tastypress Pro 1.0.0
 */

// Add 3column section
$wp_customize->add_section( 'tastypress_pro_3column_section', array(
	'title'             => esc_html__( 'Three Column','tastypress-pro' ),
	'description'       => esc_html__( 'Three Column Section options.', 'tastypress-pro' ),
	'panel'             => 'tastypress_pro_front_page_panel',
	'active_callback'   => 'tastypress_pro_if_all_section_enable',
) );

// 3column content enable control and setting
$wp_customize->add_setting( 'tastypress_pro_theme_options[3column_section_enable]', array(
	'default'			=> 	$options['3column_section_enable'],
	'sanitize_callback' => 'tastypress_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Tastypress_Pro_Switch_Control( $wp_customize, 'tastypress_pro_theme_options[3column_section_enable]', array(
	'label'             => esc_html__( 'Three Column Section Enable', 'tastypress-pro' ),
	'section'           => 'tastypress_pro_3column_section',
	'on_off_label' 		=> tastypress_pro_switch_options(),
) ) );

if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'tastypress_pro_theme_options[3column_section_enable]', array(
		'selector'            => '#magazine-three-column-posts .tooltiptext',
		'settings'            => 'tastypress_pro_theme_options[3column_section_enable]',
    ) );
}


// 3column title setting and control
$wp_customize->add_setting( 'tastypress_pro_theme_options[3column_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['3column_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'tastypress_pro_theme_options[3column_title]', array(
	'label'           	=> esc_html__( 'Title', 'tastypress-pro' ),
	'section'        	=> 'tastypress_pro_3column_section',
	'active_callback' 	=> 'tastypress_pro_is_3column_title_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'tastypress_pro_theme_options[3column_title]', array(
		'selector'            => '#magazine-three-column-posts h2.section-title',
		'settings'            => 'tastypress_pro_theme_options[3column_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'tastypress_pro_3column_title_partial',
    ) );
}

$wp_customize->add_setting( 'tastypress_pro_theme_options[3column_count]', array(
	'sanitize_callback' => 'tastypress_pro_sanitize_number_range',
	'validate_callback' => 'tastypress_pro_validate_long_excerpt',
	'default'			=> $options['3column_count'],
) );

$wp_customize->add_control( 'tastypress_pro_theme_options[3column_count]', array(
	'label'       		=> esc_html__( 'No. of Posts', 'tastypress-pro' ),
	'description' 		=> esc_html__( 'Total description words to be displayed in 3column posts.', 'tastypress-pro' ),
	'section'     		=> 'tastypress_pro_3column_section',	
	'active_callback' 	=> 'tastypress_pro_is_3column_section_enable',
	'type'        		=> 'number',
	'input_attrs' 		=> array(
		'style'       => 'width: 80px;',
		'max'         => 30,
		'min'         => 3,
	),
) );



// long Excerpt length setting and control.
$wp_customize->add_setting( 'tastypress_pro_theme_options[3column_excerpt_length]', array(
	'sanitize_callback' => 'tastypress_pro_sanitize_number_range',
	'validate_callback' => 'tastypress_pro_validate_long_excerpt',
	'default'			=> $options['3column_excerpt_length'],
) );

$wp_customize->add_control( 'tastypress_pro_theme_options[3column_excerpt_length]', array(
	'label'       		=> esc_html__( 'Excerpt Lenght', 'tastypress-pro' ),
	'description' 		=> esc_html__( 'Total description words to be displayed in 3column posts.', 'tastypress-pro' ),
	'section'     		=> 'tastypress_pro_3column_section',	
	'active_callback' 	=> 'tastypress_pro_is_3column_section_enable',
	'type'        		=> 'number',
	'input_attrs' 		=> array(
		'style'       => 'width: 80px;',
		'max'         => 100,
		'min'         => 5,
	),
) );



// 3column content type control and setting
$wp_customize->add_setting( 'tastypress_pro_theme_options[3column_content_type]', array(
	'default'          	=> $options['3column_content_type'],
	'sanitize_callback' => 'tastypress_pro_sanitize_select',
) );

$wp_customize->add_control( 'tastypress_pro_theme_options[3column_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'tastypress-pro' ),
	'section'           => 'tastypress_pro_3column_section',
	'type'				=> 'select',
	'active_callback' 	=> 'tastypress_pro_is_3column_section_enable',
	'choices'			=> array(
            'page'      => esc_html__( 'Page', 'tastypress-pro' ),
            'post'      => esc_html__( 'Post', 'tastypress-pro' ),
            'category'  => esc_html__( 'Category', 'tastypress-pro' ),
            'recent' 	=> esc_html__( 'Recent', 'tastypress-pro' ),
        ),
) );

for ( $i = 1; $i <= $options['3column_count']; $i++ ) :
	// 3column pages drop down chooser control and setting
	$wp_customize->add_setting( 'tastypress_pro_theme_options[3column_content_page_' . $i . ']', array(
		'sanitize_callback' => 'tastypress_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Tastypress_Pro_Dropdown_Chooser( $wp_customize, 'tastypress_pro_theme_options[3column_content_page_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Page %d', 'tastypress-pro' ), $i ),
		'section'           => 'tastypress_pro_3column_section',
		'choices'			=> tastypress_pro_page_choices(),
		'active_callback'	=> 'tastypress_pro_is_3column_section_content_page_enable',
	) ) );

	// 3column posts drop down chooser control and setting
	$wp_customize->add_setting( 'tastypress_pro_theme_options[3column_content_post_' . $i . ']', array(
		'sanitize_callback' => 'tastypress_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Tastypress_Pro_Dropdown_Chooser( $wp_customize, 'tastypress_pro_theme_options[3column_content_post_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Post %d', 'tastypress-pro' ), $i ),
		'section'           => 'tastypress_pro_3column_section',
		'choices'			=> tastypress_pro_post_choices(),
		'active_callback'	=> 'tastypress_pro_is_3column_section_content_post_enable',
	) ) );

endfor;

// Add dropdown category setting and control.
$wp_customize->add_setting(  'tastypress_pro_theme_options[3column_content_category]', array(
	'sanitize_callback' => 'tastypress_pro_sanitize_single_category',
) ) ;

$wp_customize->add_control( new Tastypress_Pro_Dropdown_Taxonomies_Control( $wp_customize,'tastypress_pro_theme_options[3column_content_category]', array(
	'label'             => esc_html__( 'Select Category', 'tastypress-pro' ),
	'description'      	=> esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'tastypress-pro' ),
	'section'           => 'tastypress_pro_3column_section',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'tastypress_pro_is_3column_section_content_category_enable'
) ) );

// Add dropdown categories setting and control.
$wp_customize->add_setting( 'tastypress_pro_theme_options[3column_category_exclude]', array(
	'sanitize_callback' => 'tastypress_pro_sanitize_category_list',
) ) ;

$wp_customize->add_control( new Tastypress_Pro_Dropdown_Category_Control( $wp_customize,'tastypress_pro_theme_options[3column_category_exclude]', array(
	'label'             => esc_html__( 'Select Excluding Categories', 'tastypress-pro' ),
	'description'      	=> esc_html__( 'Note: Select categories to exclude. Press Shift key select multilple categories.', 'tastypress-pro' ),
	'section'           => 'tastypress_pro_3column_section',
	'type'              => 'dropdown-categories',
	'active_callback'	=> 'tastypress_pro_is_3column_section_content_recent_enable'
) ) );
