<?php
/**
 * Counter Section options
 *
 * @package Theme Palace
 * @subpackage tastypress Pro
 * @since tastypress Pro 1.0.0
 */

// Add Counter section
$wp_customize->add_section( 'tastypress_pro_counter_section', array(
	'title'             => esc_html__( 'Counters','tastypress-pro' ),
	'description'       => esc_html__( 'Counters Section options.', 'tastypress-pro' ),
	'panel'             => 'tastypress_pro_front_page_panel',
	'active_callback'   => 'tastypress_pro_if_pro_section_enable',
) );

// Counter content enable control and setting
$wp_customize->add_setting( 'tastypress_pro_theme_options[counter_section_enable]', array(
	'default'			=> 	$options['counter_section_enable'],
	'sanitize_callback' => 'tastypress_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Tastypress_Pro_Switch_Control( $wp_customize, 'tastypress_pro_theme_options[counter_section_enable]', array(
	'label'             => esc_html__( 'Counter Section Enable', 'tastypress-pro' ),
	'section'           => 'tastypress_pro_counter_section',
	'on_off_label' 		=> tastypress_pro_switch_options(),
) ) );

if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'tastypress_pro_theme_options[counter_section_enable]', array(
		'selector'            => '#counter .tooltiptext',
		'settings'            => 'tastypress_pro_theme_options[counter_section_enable]',
    ) );
}

if( in_array( $options['home_layout'], array( 'default-design-all', 'default-design', 'fourth-design', 'sixth-design' ) ) ):

// Counter sub title control and setting
$wp_customize->add_setting( 'tastypress_pro_theme_options[counter_sub_title]', array(
    'default'           => $options['counter_sub_title'],
	'sanitize_callback' => 'sanitize_text_field',
	'transport'			=> 'postMessage'
) );

$wp_customize->add_control( 'tastypress_pro_theme_options[counter_sub_title]', array(
	'label'           	=> esc_html__( 'Sub Title', 'tastypress-pro' ),
	'section'        	=> 'tastypress_pro_counter_section',
	'active_callback' 	=> 'tastypress_pro_is_counter_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'tastypress_pro_theme_options[counter_sub_title]', array(
		'selector'            => '#counter p.section-subtitle',
		'settings'            => 'tastypress_pro_theme_options[counter_sub_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'tastypress_pro_counter_sub_title_partial',
    ) );
}

// Counter sub title control and setting
$wp_customize->add_setting( 'tastypress_pro_theme_options[counter_title]', array(
    'default'           => $options['counter_title'],
	'sanitize_callback' => 'sanitize_text_field',
	'transport'			=> 'postMessage'
) );

$wp_customize->add_control( 'tastypress_pro_theme_options[counter_title]', array(
	'label'           	=> esc_html__( 'Title', 'tastypress-pro' ),
	'section'        	=> 'tastypress_pro_counter_section',
	'active_callback' 	=> 'tastypress_pro_is_counter_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'tastypress_pro_theme_options[counter_title]', array(
		'selector'            => '#counter h2.section-title',
		'settings'            => 'tastypress_pro_theme_options[counter_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'tastypress_pro_counter_title_partial',
    ) );
}

endif;


// counter number control and setting
$wp_customize->add_setting( 'tastypress_pro_theme_options[counter_count]', array(
	'default'          	=> $options['counter_count'],
	'sanitize_callback' => 'tastypress_pro_sanitize_number_range',
	'validate_callback' => 'tastypress_pro_validate_counter_count',
) );

$wp_customize->add_control( 'tastypress_pro_theme_options[counter_count]', array(
	'label'             => esc_html__( 'Number of Counters', 'tastypress-pro' ),
	'description'       => esc_html__( 'Note: Min 1 & Max 12. Please input the valid number and save. Then refresh the page to see the change.', 'tastypress-pro' ),
	'section'           => 'tastypress_pro_counter_section',
	'active_callback'   => 'tastypress_pro_is_counter_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 1,
		'max'	=> 12,
		'style' => 'width: 100px;'
		),
) );

for ( $i = 1; $i <= $options['counter_count']; $i++ ) :

	// counter title setting and control
	$wp_customize->add_setting( 'tastypress_pro_theme_options[counter_title_' . $i . ']', array(
		'sanitize_callback' => 'sanitize_text_field',
	) );

	$wp_customize->add_control( 'tastypress_pro_theme_options[counter_title_' . $i . ']', array(
		'label'           	=> sprintf( esc_html__( 'Counter Title %d', 'tastypress-pro' ), $i ),
		'section'        	=> 'tastypress_pro_counter_section',
		'active_callback' 	=> 'tastypress_pro_is_counter_section_enable',
		'type'				=> 'text',
	) );

	$wp_customize->add_setting( 'tastypress_pro_theme_options[counter_content_' . $i . ']', array(
		'sanitize_callback' => 'sanitize_textarea_field',
	) );
	
	$wp_customize->add_control( 'tastypress_pro_theme_options[counter_content_' . $i . ']', array(
		'label'           	=> sprintf( esc_html__( 'Counter Content %d', 'tastypress-pro' ), $i ),
		'section'        	=> 'tastypress_pro_counter_section',
		'active_callback' 	=> 'tastypress_pro_is_counter_section_enable',
		'type'				=> 'textarea',
	) );


	// counter title setting and control
	$wp_customize->add_setting( 'tastypress_pro_theme_options[counter_number_' . $i . ']', array(
		'sanitize_callback' => 'sanitize_text_field',
	) );

	$wp_customize->add_control( 'tastypress_pro_theme_options[counter_number_' . $i . ']', array(
		'label'           	=> sprintf( esc_html__( 'Counter Count %d', 'tastypress-pro' ), $i ),
		'section'        	=> 'tastypress_pro_counter_section',
		'active_callback' 	=> 'tastypress_pro_is_counter_section_enable',
		'type'				=> 'text',
	) );

	// counter hr setting and control
	$wp_customize->add_setting( 'tastypress_pro_theme_options[counter_hr_'. $i .']', array(
		'sanitize_callback' => 'sanitize_text_field'
	) );

	$wp_customize->add_control( new Tastypress_Pro_Customize_Horizontal_Line( $wp_customize, 'tastypress_pro_theme_options[counter_hr_'. $i .']',
		array(
			'section'         => 'tastypress_pro_counter_section',
			'active_callback' => 'tastypress_pro_is_counter_section_enable',
			'type'			  => 'hr'
	) ) );
endfor;
