<?php
/**
 * cta Section options
 *
 * @package Theme Palace
 * @subpackage tastypress Pro
 * @since tastypress Pro 1.0.0
 */

// Add cta section
$wp_customize->add_section( 'tastypress_pro_cta_section', array(
	'title'             => esc_html__( 'CTA','tastypress-pro' ),
	'description'       => esc_html__( 'CTA Section options.', 'tastypress-pro' ),
	'panel'             => 'tastypress_pro_front_page_panel',
	'active_callback'   => 'tastypress_pro_if_all_section_enable',
) );

// cta Section enable control and setting
$wp_customize->add_setting( 'tastypress_pro_theme_options[cta_section_enable]', array(
	'default'			=> 	$options['cta_section_enable'],
	'sanitize_callback' => 'tastypress_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Tastypress_Pro_Switch_Control( $wp_customize, 'tastypress_pro_theme_options[cta_section_enable]', array(
	'label'             => esc_html__( 'CTA Section Enable', 'tastypress-pro' ),
	'section'           => 'tastypress_pro_cta_section',
	'on_off_label' 		=> tastypress_pro_switch_options(),
) ) );

if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'tastypress_pro_theme_options[cta_section_enable]', array(
		'selector'            => '#business-cta-section .tooltiptext',
		'settings'            => 'tastypress_pro_theme_options[cta_section_enable]',
    ) );
}

// cta sub title setting and control
$wp_customize->add_setting( 'tastypress_pro_theme_options[cta_sub_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['cta_sub_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'tastypress_pro_theme_options[cta_sub_title]', array(
	'label'           	=> esc_html__( 'Sub Title', 'tastypress-pro' ),
	'section'        	=> 'tastypress_pro_cta_section',
	'active_callback' 	=> 'tastypress_pro_is_cta_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'tastypress_pro_theme_options[cta_sub_title]', array(
		'selector'            => '#business-cta-section p.section-subtitle',
		'settings'            => 'tastypress_pro_theme_options[cta_sub_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'tastypress_pro_cta_sub_title_partial',
    ) );
}


// cta content type control and setting
$wp_customize->add_setting( 'tastypress_pro_theme_options[cta_content_type]', array(
	'default'          	=> $options['cta_content_type'],
	'sanitize_callback' => 'tastypress_pro_sanitize_select',
) );

$wp_customize->add_control( 'tastypress_pro_theme_options[cta_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'tastypress-pro' ),
	'section'           => 'tastypress_pro_cta_section',
	'type'				=> 'select',
	'active_callback' 	=> 'tastypress_pro_is_cta_section_enable',
	'choices'			=> tastypress_pro_cta_content_type(),
) );

// cta pages drop down chooser control and setting
$wp_customize->add_setting( 'tastypress_pro_theme_options[cta_content_page]', array(
	'sanitize_callback' => 'tastypress_pro_sanitize_page',
) );

$wp_customize->add_control( new Tastypress_Pro_Dropdown_Chooser( $wp_customize, 'tastypress_pro_theme_options[cta_content_page]', array(
	'label'             => esc_html__( 'Select Page', 'tastypress-pro' ),
	'section'           => 'tastypress_pro_cta_section',
	'choices'			=> tastypress_pro_page_choices(),
	'active_callback'	=> 'tastypress_pro_is_cta_section_content_page_enable',
) ) );

// cta posts drop down chooser control and setting
$wp_customize->add_setting( 'tastypress_pro_theme_options[cta_content_post]', array(
	'sanitize_callback' => 'tastypress_pro_sanitize_page',
) );

$wp_customize->add_control( new Tastypress_Pro_Dropdown_Chooser( $wp_customize, 'tastypress_pro_theme_options[cta_content_post]', array(
	'label'             => esc_html__( 'Select Post', 'tastypress-pro' ),
	'section'           => 'tastypress_pro_cta_section',
	'choices'			=> tastypress_pro_post_choices(),
	'active_callback'	=> 'tastypress_pro_is_cta_section_content_post_enable',
) ) );

// cta posts drop down chooser control and setting
$wp_customize->add_setting( 'tastypress_pro_theme_options[cta_content_product]', array(
	'sanitize_callback' => 'tastypress_pro_sanitize_page',
) );

$wp_customize->add_control( new Tastypress_Pro_Dropdown_Chooser( $wp_customize, 'tastypress_pro_theme_options[cta_content_product]', array(
	'label'             => esc_html__( 'Select Product', 'tastypress-pro' ),
	'section'           => 'tastypress_pro_cta_section',
	'choices'			=> tastypress_pro_product_choices(),
	'active_callback'	=> 'tastypress_pro_is_cta_section_content_product_enable',
) ) );


// cta title setting and control
$wp_customize->add_setting( 'tastypress_pro_theme_options[cta_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['cta_title'],
) );

$wp_customize->add_control( 'tastypress_pro_theme_options[cta_title]', array(
	'label'           	=> esc_html__( 'Title', 'tastypress-pro' ),
	'section'        	=> 'tastypress_pro_cta_section',
	'active_callback' 	=> 'tastypress_pro_is_cta_section_content_custom_enable',
	'type'				=> 'text',
) );


// cta description setting and control
$wp_customize->add_setting( 'tastypress_pro_theme_options[cta_description]', array(
	'sanitize_callback' => 'wp_kses_post',
	'default'			=> $options['cta_description'],
) );

$wp_customize->add_control( 'tastypress_pro_theme_options[cta_description]', array(
	'label'           	=> esc_html__( 'Description', 'tastypress-pro' ),
	'section'        	=> 'tastypress_pro_cta_section',
	'active_callback' 	=> 'tastypress_pro_is_cta_section_content_custom_enable',
	'type'				=> 'textarea',
) );

// cta btn title setting and control
$wp_customize->add_setting( 'tastypress_pro_theme_options[cta_btn_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['cta_btn_title'],
	'transport'			=> 'postMessage',
	) );
	
	$wp_customize->add_control( 'tastypress_pro_theme_options[cta_btn_title]', array(
	'label'           	=> esc_html__( 'Button Label', 'tastypress-pro' ),
	'section'        	=> 'tastypress_pro_cta_section',
	'active_callback' 	=> 'tastypress_pro_is_cta_section_enable',
	'type'				=> 'text',
	) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'tastypress_pro_theme_options[cta_btn_title]', array(
		'selector'            => '#business-cta-section div.read-more a',
		'settings'            => 'tastypress_pro_theme_options[cta_btn_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'tastypress_pro_cta_btn_title_partial',
		) );
	}

	// cta btn link setting and control
	$wp_customize->add_setting( 'tastypress_pro_theme_options[cta_btn_link]', array(
	'sanitize_callback' => 'esc_url_raw',
	) );

$wp_customize->add_control( 'tastypress_pro_theme_options[cta_btn_link]', array(
	'label'           	=> esc_html__( 'Button Link', 'tastypress-pro' ),
	'section'        	=> 'tastypress_pro_cta_section',
	'active_callback' 	=> 'tastypress_pro_is_cta_section_content_custom_enable',
	'type'				=> 'url',
	) );

//cta image setting and control.
$wp_customize->add_setting( 'tastypress_pro_theme_options[cta_image]', array(
	'sanitize_callback' => 'tastypress_pro_sanitize_image'
) );

$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'tastypress_pro_theme_options[cta_image]',
		array(
		'label'       		=> esc_html__( 'cta Image', 'tastypress-pro' ),
		'description' 		=> sprintf( esc_html__( 'Recommended size: %1$dpx x %2$dpx ', 'tastypress-pro' ), 500, 690 ),
		'section'     		=> 'tastypress_pro_cta_section',
		'active_callback'	=> 'tastypress_pro_is_cta_section_content_custom_enable',
) ) );

