<?php
/**
 * Event Section options
 *
 * @package Theme Palace
 * @subpackage Mega Charity Pro
 * @since Mega Charity Pro 1.0.0
 */

// Add Event section
$wp_customize->add_section( 'tastypress_pro_event_section', array(
	'title'             => esc_html__( 'Event','tastypress-pro' ),
	'description'       => sprintf( '<a target="_blank" href="https://wordpress.org/plugins/tp-education/"> %1$s  </a> %2$s', esc_html__( 'TP Education', 'tastypress-pro' ), esc_html__( 'plugin is recommended for this section for uploading events', 'tastypress-pro' ) ),
	'panel'             => 'tastypress_pro_front_page_panel',
	'active_callback'   => 'tastypress_pro_if_all_section_enable',
) );


// Event content enable control and setting
$wp_customize->add_setting( 'tastypress_pro_theme_options[event_section_enable]', array(
	'default'			=> 	$options['event_section_enable'],
	'sanitize_callback' => 'tastypress_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new tastypress_Pro_Switch_Control( $wp_customize, 'tastypress_pro_theme_options[event_section_enable]', array(
	'label'             => esc_html__( 'Event Section Enable', 'tastypress-pro' ),
	'section'           => 'tastypress_pro_event_section',
	'on_off_label' 		=> tastypress_pro_switch_options(),
) ) );

if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'tastypress_pro_theme_options[event_section_enable]', array(
		'selector'            => '#upcoming-events .tooltiptext',
		'settings'            => 'tastypress_pro_theme_options[event_section_enable]',
    ) );
}

// event subtitle setting and control
$wp_customize->add_setting( 'tastypress_pro_theme_options[event_subtitle]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['event_subtitle'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'tastypress_pro_theme_options[event_subtitle]', array(
	'label'           	=> esc_html__( 'Sub Title', 'tastypress-pro' ),
	'section'        	=> 'tastypress_pro_event_section',
	'active_callback' 	=> 'tastypress_pro_is_event_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'tastypress_pro_theme_options[event_subtitle]', array(
		'selector'            => '#upcoming-events p.section-subtitle',
		'settings'            => 'tastypress_pro_theme_options[event_subtitle]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'tastypress_pro_event_subtitle_partial',
    ) );
}

// event title setting and control
$wp_customize->add_setting( 'tastypress_pro_theme_options[event_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['event_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'tastypress_pro_theme_options[event_title]', array(
	'label'           	=> esc_html__( 'Title', 'tastypress-pro' ),
	'section'        	=> 'tastypress_pro_event_section',
	'active_callback' 	=> 'tastypress_pro_is_event_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'tastypress_pro_theme_options[event_title]', array(
		'selector'            => '#upcoming-events h2.section-title',
		'settings'            => 'tastypress_pro_theme_options[event_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'tastypress_pro_event_title_partial',
    ) );
}

// event readmore setting and control
$wp_customize->add_setting( 'tastypress_pro_theme_options[event_readmore]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['event_readmore'],
) );

$wp_customize->add_control( 'tastypress_pro_theme_options[event_readmore]', array(
	'label'           	=> esc_html__( 'Read More Label', 'tastypress-pro' ),
	'section'        	=> 'tastypress_pro_event_section',
	'active_callback' 	=> 'tastypress_pro_is_event_section_enable',
	'type'				=> 'text',
) );

// Event content type control and setting
$wp_customize->add_setting( 'tastypress_pro_theme_options_event_content_type', array(
	'default'          	=> $options['event_content_type'],
	'sanitize_callback' => 'tastypress_pro_sanitize_select',
) );

$wp_customize->add_control( 'tastypress_pro_theme_options_event_content_type', array(
	'label'             => esc_html__( 'Content Type', 'tastypress-pro' ),
	'section'           => 'tastypress_pro_event_section',
	'type'				=> 'select',
	'active_callback' 	=> 'tastypress_pro_is_event_section_enable',
	'choices'			=> tastypress_pro_event_content_type(),
) );

// Event social icons number control and setting
$wp_customize->add_setting( 'tastypress_pro_theme_options_event_count', array(
	'default'          	=> $options['event_count'],
	'sanitize_callback' => 'tastypress_pro_sanitize_number_range',
) );

$wp_customize->add_control( 'tastypress_pro_theme_options_event_count', array(
	'label'             => esc_html__( 'Number of Event', 'tastypress-pro' ),
	'description'       => esc_html__( 'Note: Min 1 & Max 12. Please input the valid number and save. Then refresh the page to see the change.', 'tastypress-pro' ),
	'section'           => 'tastypress_pro_event_section',
	'active_callback'   => 'tastypress_pro_is_event_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 1,
		'max'	=> 12,
		'style' => 'width: 100px;'
		),
) );

for ( $i = 1; $i <= get_theme_mod( 'tastypress_pro_theme_options_event_count', 3 ); $i++ ) :

	// event posts drop down chooser control and setting
	$wp_customize->add_setting( 'tastypress_pro_theme_options[event_content_page_' . $i . ']', array(
		'sanitize_callback' => 'tastypress_pro_sanitize_page',
	) );

	$wp_customize->add_control( new tastypress_Pro_Dropdown_Chooser( $wp_customize, 'tastypress_pro_theme_options[event_content_page_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Page %d', 'tastypress-pro' ), $i ),
		'section'           => 'tastypress_pro_event_section',
		'choices'			=> tastypress_pro_page_choices(),
		'active_callback'	=> 'tastypress_pro_is_event_section_content_page_enable',
	) ) );

	// event posts drop down chooser control and setting
	$wp_customize->add_setting( 'tastypress_pro_theme_options[event_content_post_' . $i . ']', array(
		'sanitize_callback' => 'tastypress_pro_sanitize_page',
	) );

	$wp_customize->add_control( new tastypress_Pro_Dropdown_Chooser( $wp_customize, 'tastypress_pro_theme_options[event_content_post_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Post %d', 'tastypress-pro' ), $i ),
		'section'           => 'tastypress_pro_event_section',
		'choices'			=> tastypress_pro_post_choices(),
		'active_callback'	=> 'tastypress_pro_is_event_section_content_post_enable',
	) ) );

	// event posts drop down chooser control and setting
	$wp_customize->add_setting( 'tastypress_pro_theme_options[event_content_event_' . $i . ']', array(
		'sanitize_callback' => 'absint',
	) );

	$wp_customize->add_control( new Tastypress_Pro_Dropdown_Chooser( $wp_customize, 'tastypress_pro_theme_options[event_content_event_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Event %d', 'tastypress-pro' ), $i ),
		'section'           => 'tastypress_pro_event_section',
		'choices'			=> tastypress_pro_event_choices(),
		'active_callback'	=> 'tastypress_pro_is_event_section_content_event_enable',
	) ) );

endfor;

// Add dropdown category setting and control.
$wp_customize->add_setting(  'tastypress_pro_theme_options[event_content_category]', array(
	'sanitize_callback' => 'absint',
) ) ;

$wp_customize->add_control( new Tastypress_Pro_Dropdown_Taxonomies_Control( $wp_customize,'tastypress_pro_theme_options[event_content_category]', array(
	'label'             => esc_html__( 'Select Category', 'tastypress-pro' ),
	'description'      	=> esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'tastypress-pro' ),
	'section'           => 'tastypress_pro_event_section',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'tastypress_pro_is_event_section_content_category_enable'
) ) );

// Add dropdown category setting and control.
$wp_customize->add_setting(  'tastypress_pro_theme_options[event_content_event_category]', array(
	'sanitize_callback' => 'absint',
) ) ;

$wp_customize->add_control( new Tastypress_Pro_Dropdown_Taxonomies_Control( $wp_customize,'tastypress_pro_theme_options[event_content_event_category]', array(
	'label'             => esc_html__( 'Select Event Category', 'tastypress-pro' ),
	'description'      	=> esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'tastypress-pro' ),
	'section'           => 'tastypress_pro_event_section',
	'taxonomy'			=> 'tp-event-category',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'tastypress_pro_is_event_section_content_event_category_enable'
) ) );

// event btn title setting and control
$wp_customize->add_setting( 'tastypress_pro_theme_options[event_btn_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['event_btn_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'tastypress_pro_theme_options[event_btn_title]', array(
	'label'           	=> esc_html__( 'Button Label', 'tastypress-pro' ),
	'section'        	=> 'tastypress_pro_event_section',
	'active_callback' 	=> 'tastypress_pro_is_event_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'tastypress_pro_theme_options[event_btn_title]', array(
		'selector'            => '#upcoming-events .read-more a.btn',
		'settings'            => 'tastypress_pro_theme_options[event_btn_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'tastypress_pro_event_btn_title_partial',
    ) );
}

// event btn link setting and control
$wp_customize->add_setting( 'tastypress_pro_theme_options[event_btn_link]', array(
	'sanitize_callback' => 'esc_url_raw',
) );

$wp_customize->add_control( 'tastypress_pro_theme_options[event_btn_link]', array(
	'label'           	=> esc_html__( 'Button Url', 'tastypress-pro' ),
	'section'        	=> 'tastypress_pro_event_section',
	'active_callback' 	=> 'tastypress_pro_is_event_section_enable',
	'type'				=> 'url',
) );

