<?php
/**
 * Featured Posts Section options
 *
 * @package Theme Palace
 * @subpackage tastypress Pro
 * @since tastypress Pro 1.0.0
 */

// Add Featured Posts section
$wp_customize->add_section( 'tastypress_pro_featured_posts_section', array(
	'title'             => esc_html__( 'Featured Posts','tastypress-pro' ),
	'description'       => esc_html__( 'Featured Posts Section options.', 'tastypress-pro' ),
	'panel'             => 'tastypress_pro_front_page_panel',
	'active_callback'   => 'tastypress_pro_if_all_section_enable',
) );

// Featured Posts content enable control and setting
$wp_customize->add_setting( 'tastypress_pro_theme_options[featured_posts_section_enable]', array(
	'default'			=> 	$options['featured_posts_section_enable'],
	'sanitize_callback' => 'tastypress_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Tastypress_Pro_Switch_Control( $wp_customize, 'tastypress_pro_theme_options[featured_posts_section_enable]', array(
	'label'             => esc_html__( 'Featured Posts Section Enable', 'tastypress-pro' ),
	'section'           => 'tastypress_pro_featured_posts_section',
	'on_off_label' 		=> tastypress_pro_switch_options(),
) ) );

if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'tastypress_pro_theme_options[featured_posts_section_enable]', array(
        'selector'            => '#medical-featured .tooltiptext',
        'settings'            => 'tastypress_pro_theme_options[featured_posts_section_enable]',
    ) );
}

// Featured Posts post  number control and setting
$wp_customize->add_setting( 'tastypress_pro_theme_options[featured_posts_count]', array(
	'default'          	=> $options['featured_posts_count'],
	'sanitize_callback' => 'tastypress_pro_sanitize_number_range',
	'validate_callback' => 'tastypress_pro_validate_featured_posts_count',
) );

$wp_customize->add_control( 'tastypress_pro_theme_options[featured_posts_count]', array(
	'label'             => esc_html__( 'Number of Featured Postss', 'tastypress-pro' ),
	'description'       => esc_html__( 'Note: Min 1 & Max 12. Please input the valid number and save. Then refresh the page to see the change.', 'tastypress-pro' ),
	'section'           => 'tastypress_pro_featured_posts_section',
	'active_callback'   => 'tastypress_pro_is_featured_posts_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 1,
		'max'	=> 12,
		'style' => 'width: 100px;'
		),
) );

// Featured Posts content type control and setting
$wp_customize->add_setting( 'tastypress_pro_theme_options[featured_posts_content_type]', array(
	'default'          	=> $options['featured_posts_content_type'],
	'sanitize_callback' => 'tastypress_pro_sanitize_select',
) );

$wp_customize->add_control( 'tastypress_pro_theme_options[featured_posts_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'tastypress-pro' ),
	'section'           => 'tastypress_pro_featured_posts_section',
	'type'				=> 'select',
	'active_callback' 	=> 'tastypress_pro_is_featured_posts_section_enable',
	'choices'			=> array( 
		'page' 		=> esc_html__( 'Page', 'tastypress-pro' ),
		'post' 		=> esc_html__( 'Post', 'tastypress-pro' ),
		'category' 	=> esc_html__( 'Category', 'tastypress-pro' ),
	),
) );

// Add dropdown category setting and control.
$wp_customize->add_setting(  'tastypress_pro_theme_options[featured_posts_content_category]', array(
	'sanitize_callback' => 'tastypress_pro_sanitize_single_category',
) ) ;

$wp_customize->add_control( new Tastypress_Pro_Dropdown_Taxonomies_Control( $wp_customize,'tastypress_pro_theme_options[featured_posts_content_category]', array(
	'label'             => esc_html__( 'Select Category', 'tastypress-pro' ),
	'description'      	=> esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'tastypress-pro' ),
	'section'           => 'tastypress_pro_featured_posts_section',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'tastypress_pro_is_featured_posts_section_content_category_enable'
) ) );

for ( $i = 1; $i <= $options['featured_posts_count']; $i++ ) :
	// recent_news pages drop down chooser control and setting
	$wp_customize->add_setting( 'tastypress_pro_theme_options[featured_posts_content_page_' . $i . ']', array(
		'sanitize_callback' => 'tastypress_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Tastypress_Pro_Dropdown_Chooser( $wp_customize, 'tastypress_pro_theme_options[featured_posts_content_page_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Page %d', 'tastypress-pro' ), $i ),
		'section'           => 'tastypress_pro_featured_posts_section',
		'choices'			=> tastypress_pro_page_choices(),
		'active_callback'	=> 'tastypress_pro_is_featured_posts_section_content_page_enable',
	) ) );

	// recent_news posts drop down chooser control and setting
	$wp_customize->add_setting( 'tastypress_pro_theme_options[featured_posts_content_post_' . $i . ']', array(
		'sanitize_callback' => 'tastypress_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Tastypress_Pro_Dropdown_Chooser( $wp_customize, 'tastypress_pro_theme_options[featured_posts_content_post_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Post %d', 'tastypress-pro' ), $i ),
		'section'           => 'tastypress_pro_featured_posts_section',
		'choices'			=> tastypress_pro_post_choices(),
		'active_callback'	=> 'tastypress_pro_is_featured_posts_section_content_post_enable',
	) ) );

endfor;

