<?php
/**
 * hero Section options
 *
 * @package Theme Palace
 * @subpackage tastypress Pro
 * @since tastypress Pro 1.0.0
 */

// Add hero section
$wp_customize->add_section( 'tastypress_pro_hero_section', array(
	'title'             => esc_html__( 'Hero','tastypress-pro' ),
	'description'       => esc_html__( 'Hero Section options.', 'tastypress-pro' ),
	'panel'             => 'tastypress_pro_front_page_panel',
	'active_callback'   => 'tastypress_pro_if_pro_section_enable',
) );

// hero Section enable control and setting
$wp_customize->add_setting( 'tastypress_pro_theme_options[hero_section_enable]', array(
	'default'			=> 	$options['hero_section_enable'],
	'sanitize_callback' => 'tastypress_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Tastypress_Pro_Switch_Control( $wp_customize, 'tastypress_pro_theme_options[hero_section_enable]', array(
	'label'             => esc_html__( 'hero Section Enable', 'tastypress-pro' ),
	'section'           => 'tastypress_pro_hero_section',
	'on_off_label' 		=> tastypress_pro_switch_options(),
) ) );

if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'tastypress_pro_theme_options[hero_section_enable]', array(
		'selector'            => '#hero-section .tooltiptext',
		'settings'            => 'tastypress_pro_theme_options[hero_section_enable]',
    ) );
}


// long Excerpt length setting and control.
$wp_customize->add_setting( 'tastypress_pro_theme_options[hero_excerpt_length]', array(
	'sanitize_callback' => 'tastypress_pro_sanitize_number_range',
	'validate_callback' => 'tastypress_pro_validate_long_excerpt',
	'default'			=> $options['hero_excerpt_length'],
) );

$wp_customize->add_control( 'tastypress_pro_theme_options[hero_excerpt_length]', array(
	'label'       		=> esc_html__( 'hero Excerpt Length', 'tastypress-pro' ),
	'description' 		=> esc_html__( 'Total description words to be displayed in hero posts.', 'tastypress-pro' ),
	'section'     		=> 'tastypress_pro_hero_section',
	'active_callback' 	=> 'tastypress_pro_is_hero_section_enable',
	'type'        		=> 'number',
	'input_attrs' 		=> array(
		'style'       => 'width: 80px;',
		'max'         => 100,
		'min'         => 5,
	),
) );

// hero content type control and setting
$wp_customize->add_setting( 'tastypress_pro_theme_options[hero_content_type]', array(
	'default'          	=> $options['hero_content_type'],
	'sanitize_callback' => 'tastypress_pro_sanitize_select',
) );

$wp_customize->add_control( 'tastypress_pro_theme_options[hero_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'tastypress-pro' ),
	'section'           => 'tastypress_pro_hero_section',
	'type'				=> 'select',
	'active_callback' 	=> 'tastypress_pro_is_hero_section_enable',
	'choices'			=> tastypress_pro_hero_content_type(),
) );

// hero pages drop down chooser control and setting
$wp_customize->add_setting( 'tastypress_pro_theme_options[hero_content_page]', array(
	'sanitize_callback' => 'tastypress_pro_sanitize_page',
) );

$wp_customize->add_control( new Tastypress_Pro_Dropdown_Chooser( $wp_customize, 'tastypress_pro_theme_options[hero_content_page]', array(
	'label'             => esc_html__( 'Select Page', 'tastypress-pro' ),
	'section'           => 'tastypress_pro_hero_section',
	'choices'			=> tastypress_pro_page_choices(),
	'active_callback'	=> 'tastypress_pro_is_hero_section_content_page_enable',
) ) );

// hero posts drop down chooser control and setting
$wp_customize->add_setting( 'tastypress_pro_theme_options[hero_content_post]', array(
	'sanitize_callback' => 'tastypress_pro_sanitize_page',
) );

$wp_customize->add_control( new Tastypress_Pro_Dropdown_Chooser( $wp_customize, 'tastypress_pro_theme_options[hero_content_post]', array(
	'label'             => esc_html__( 'Select Post', 'tastypress-pro' ),
	'section'           => 'tastypress_pro_hero_section',
	'choices'			=> tastypress_pro_post_choices(),
	'active_callback'	=> 'tastypress_pro_is_hero_section_content_post_enable',
) ) );


// hero title setting and control
$wp_customize->add_setting( 'tastypress_pro_theme_options[hero_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['hero_title'],
) );

$wp_customize->add_control( 'tastypress_pro_theme_options[hero_title]', array(
	'label'           	=> esc_html__( 'Title', 'tastypress-pro' ),
	'section'        	=> 'tastypress_pro_hero_section',
	'active_callback' 	=> 'tastypress_pro_is_hero_section_content_custom_enable',
	'type'				=> 'text',
) );


// hero description setting and control
$wp_customize->add_setting( 'tastypress_pro_theme_options[hero_description]', array(
	'sanitize_callback' => 'wp_kses_post',
	'default'			=> $options['hero_description'],
) );

$wp_customize->add_control( 'tastypress_pro_theme_options[hero_description]', array(
	'label'           	=> esc_html__( 'Description', 'tastypress-pro' ),
	'section'        	=> 'tastypress_pro_hero_section',
	'active_callback' 	=> 'tastypress_pro_is_hero_section_content_custom_enable',
	'type'				=> 'textarea',
) );

// hero btn title setting and control
$wp_customize->add_setting( 'tastypress_pro_theme_options[hero_btn_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['hero_btn_title'],
	'transport'			=> 'postMessage',
	) );
	
$wp_customize->add_control( 'tastypress_pro_theme_options[hero_btn_title]', array(
	'label'           	=> esc_html__( 'Button Label', 'tastypress-pro' ),
	'section'        	=> 'tastypress_pro_hero_section',
	'active_callback' 	=> 'tastypress_pro_is_hero_section_enable',
	'type'				=> 'text',
	) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'tastypress_pro_theme_options[hero_btn_title]', array(
		'selector'            => '#hero-section div.read-more a',
		'settings'            => 'tastypress_pro_theme_options[hero_btn_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'tastypress_pro_hero_btn_title_partial',
		) );
	}

	// hero btn link setting and control
	$wp_customize->add_setting( 'tastypress_pro_theme_options[hero_btn_link]', array(
	'sanitize_callback' => 'esc_url_raw',
	) );

$wp_customize->add_control( 'tastypress_pro_theme_options[hero_btn_link]', array(
	'label'           	=> esc_html__( 'Button Link', 'tastypress-pro' ),
	'section'        	=> 'tastypress_pro_hero_section',
	'active_callback' 	=> 'tastypress_pro_is_hero_section_content_custom_enable',
	'type'				=> 'url',
	) );

//hero image setting and control.
$wp_customize->add_setting( 'tastypress_pro_theme_options[hero_image]', array(
	'sanitize_callback' => 'tastypress_pro_sanitize_image'
) );

$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'tastypress_pro_theme_options[hero_image]',
		array(
		'label'       		=> esc_html__( 'hero Image', 'tastypress-pro' ),
		'description' 		=> sprintf( esc_html__( 'Recommended size: %1$dpx x %2$dpx ', 'tastypress-pro' ), 500, 690 ),
		'section'     		=> 'tastypress_pro_hero_section',
		'active_callback'	=> 'tastypress_pro_is_hero_section_content_custom_enable',
) ) );

// hero hr setting and control
$wp_customize->add_setting( 'tastypress_pro_theme_options[hero_hr]', array(
	'sanitize_callback' => 'sanitize_text_field'
) );

$wp_customize->add_control( new Tastypress_Pro_Customize_Horizontal_Line( $wp_customize, 'tastypress_pro_theme_options[hero_hr]',
	array(
		'section'         => 'tastypress_pro_hero_section',
		'active_callback' => 'tastypress_pro_is_hero_section_enable',
		'type'			  => 'hr'
) ) );


$wp_customize->add_setting(  'tastypress_pro_theme_options[hero_content_category]', array(
	'sanitize_callback' => 'tastypress_pro_sanitize_single_category',
) ) ;

$wp_customize->add_control( new Tastypress_Pro_Dropdown_Taxonomies_Control( $wp_customize,'tastypress_pro_theme_options[hero_content_category]', array(
	'label'             => esc_html__( 'Select Category', 'tastypress-pro' ),
	'description'      	=> esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'tastypress-pro' ),
	'section'           => 'tastypress_pro_hero_section',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'tastypress_pro_is_hero_section_enable'
) ) );

$wp_customize->add_setting( 'tastypress_pro_theme_options[hero_label]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['hero_label'],
	'transport'			=> 'postMessage',
	) );
	
$wp_customize->add_control( 'tastypress_pro_theme_options[hero_label]', array(
	'label'           	=> esc_html__( 'Hero Label', 'tastypress-pro' ),
	'section'        	=> 'tastypress_pro_hero_section',
	'active_callback' 	=> 'tastypress_pro_is_hero_section_enable',
	'type'				=> 'text',
	) );

$wp_customize->add_setting( 'tastypress_pro_theme_options[hero_sub_label]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['hero_sub_label'],
	'transport'			=> 'postMessage',
	) );
	
$wp_customize->add_control( 'tastypress_pro_theme_options[hero_sub_label]', array(
	'sub_label'           	=> esc_html__( 'Hero Sub Label', 'tastypress-pro' ),
	'section'        	=> 'tastypress_pro_hero_section',
	'active_callback' 	=> 'tastypress_pro_is_hero_section_enable',
	'type'				=> 'text',
	) );