<?php
/**
 * menu Section options
 *
 * @package Theme Palace
 * @subpackage tastypress Pro
 * @since tastypress Pro 1.0.0
 */

// Add menu section
$wp_customize->add_section( 'tastypress_pro_menu_section', array(
	'title'             => esc_html__( 'Menu','tastypress-pro' ),
	'description'       => esc_html__( 'Note: To activate this section you need to install WooCommerce Plugin.', 'tastypress-pro' ),
	'panel'             => 'tastypress_pro_front_page_panel',
	'active_callback'   => 'tastypress_pro_if_pro_section_enable',
) );

// menu content enable control and setting
$wp_customize->add_setting( 'tastypress_pro_theme_options[menu_section_enable]', array(
	'default'			=> 	$options['menu_section_enable'],
	'sanitize_callback' => 'tastypress_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new tastypress_Pro_Switch_Control( $wp_customize, 'tastypress_pro_theme_options[menu_section_enable]', array(
	'label'             => esc_html__( 'Pourse Section Enable', 'tastypress-pro' ),
	'section'           => 'tastypress_pro_menu_section',
	'on_off_label' 		=> tastypress_pro_switch_options(),
) ) );

if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'tastypress_pro_theme_options[menu_section_enable]', array(
		'selector'            => '#our-menu .tooltiptext',
		'settings'            => 'tastypress_pro_theme_options[menu_section_enable]',
    ) );
}

// menu title setting and control
$wp_customize->add_setting( 'tastypress_pro_theme_options[menu_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['menu_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'tastypress_pro_theme_options[menu_title]', array(
	'label'           	=> esc_html__( 'Title', 'tastypress-pro' ),
	'section'        	=> 'tastypress_pro_menu_section',
	'active_callback' 	=> 'tastypress_pro_is_menu_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'tastypress_pro_theme_options[menu_title]', array(
		'selector'            => '#our-menus .section-header h2',
		'settings'            => 'tastypress_pro_theme_options[menu_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'tastypress_pro_menu_title_partial',
    ) );
}

// menu sub title setting and control
$wp_customize->add_setting( 'tastypress_pro_theme_options[menu_sub_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['menu_sub_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'tastypress_pro_theme_options[menu_sub_title]', array(
	'label'           	=> esc_html__( 'Sub Title', 'tastypress-pro' ),
	'section'        	=> 'tastypress_pro_menu_section',
	'active_callback' 	=> 'tastypress_pro_is_menu_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'tastypress_pro_theme_options[menu_sub_title]', array(
		'selector'            => '#our-menus .section-header p',
		'settings'            => 'tastypress_pro_theme_options[menu_sub_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'tastypress_pro_menu_sub_title_partial',
    ) );
}

$wp_customize->add_setting( 'tastypress_pro_theme_options[menu_count]', array(
	'sanitize_callback' => 'tastypress_pro_sanitize_number_range',
	'validate_callback' => 'tastypress_pro_validate_long_excerpt',
	'default'			=> $options['menu_count'],
) );

$wp_customize->add_control( 'tastypress_pro_theme_options[menu_count]', array(
	'label'       		=> esc_html__( 'No. of Category', 'tastypress-pro' ),
	'section'     		=> 'tastypress_pro_menu_section',	
	'active_callback' 	=> 'tastypress_pro_is_menu_section_enable',
	'type'        		=> 'number',
	'input_attrs' 		=> array(
		'style'       => 'width: 80px;',
		'max'         => 30,
		'min'         => 3,
	),
) );


for ( $i = 1; $i <= $options['menu_count']; $i++ ) :

	// Add dropdown category setting and control.
	$wp_customize->add_setting(  'tastypress_pro_theme_options[menu_category_'.$i.']', array(
		'sanitize_callback' => 'absint',
	) ) ;

	$wp_customize->add_control( new Tastypress_Pro_Dropdown_Taxonomies_Control( $wp_customize,'tastypress_pro_theme_options[menu_category_'.$i.']', array(
		'label'             => esc_html__( 'Select Category ', 'tastypress-pro' ).$i,
		'section'           => 'tastypress_pro_menu_section',
		'taxonomy'			=> 'product_cat',
		'type'              => 'dropdown-taxonomies',
		'active_callback'	=> 'tastypress_pro_is_menu_section_enable'
	) ) );

	$wp_customize->add_setting( 'tastypress_pro_theme_options[menu_category_image_'.$i.']', array(
	'sanitize_callback' => 'tastypress_pro_sanitize_image'
	) );

	$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'tastypress_pro_theme_options[menu_category_image_'.$i.']', array(
		'label'       		=> esc_html__( 'Category Image ', 'tastypress-pro' ).$i,
		'section'     		=> 'tastypress_pro_menu_section',
		'active_callback'	=> 'tastypress_pro_is_menu_section_enable'
	) ) );

endfor;
