<?php
/**
 * reserve Section options
 *
 * @package Theme Palace
 * @subpackage tastypress Pro
 * @since tastypress Pro 1.0.0
 */

// Add reserve section
$wp_customize->add_section( 'tastypress_pro_reserve_section', array(
	'title'             => esc_html__( 'Reserve','tastypress-pro' ),
	'description'       => esc_html__( 'Reserve Section options.', 'tastypress-pro' ),
	'panel'             => 'tastypress_pro_front_page_panel',
	'active_callback'   => 'tastypress_pro_if_pro_section_enable',
) );

// reserve Section enable control and setting
$wp_customize->add_setting( 'tastypress_pro_theme_options[reserve_section_enable]', array(
	'default'			=> 	$options['reserve_section_enable'],
	'sanitize_callback' => 'tastypress_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Tastypress_Pro_Switch_Control( $wp_customize, 'tastypress_pro_theme_options[reserve_section_enable]', array(
	'label'             => esc_html__( 'reserve Section Enable', 'tastypress-pro' ),
	'section'           => 'tastypress_pro_reserve_section',
	'on_off_label' 		=> tastypress_pro_switch_options(),
) ) );

if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'tastypress_pro_theme_options[reserve_section_enable]', array(
		'selector'            => '#reserve .tooltiptext',
		'settings'            => 'tastypress_pro_theme_options[reserve_section_enable]',
    ) );
}

// reserve sub title setting and control
$wp_customize->add_setting( 'tastypress_pro_theme_options[reserve_sub_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['reserve_sub_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'tastypress_pro_theme_options[reserve_sub_title]', array(
	'label'           	=> esc_html__( 'Sub Title', 'tastypress-pro' ),
	'section'        	=> 'tastypress_pro_reserve_section',
	'active_callback' 	=> 'tastypress_pro_is_reserve_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'tastypress_pro_theme_options[reserve_sub_title]', array(
		'selector'            => '#reserve p.section-subtitle',
		'settings'            => 'tastypress_pro_theme_options[reserve_sub_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'tastypress_pro_reserve_sub_title_partial',
    ) );
}

// long Excerpt length setting and control.
$wp_customize->add_setting( 'tastypress_pro_theme_options[reserve_excerpt_length]', array(
	'sanitize_callback' => 'tastypress_pro_sanitize_number_range',
	'validate_callback' => 'tastypress_pro_validate_long_excerpt',
	'default'			=> $options['reserve_excerpt_length'],
) );

$wp_customize->add_control( 'tastypress_pro_theme_options[reserve_excerpt_length]', array(
	'label'       		=> esc_html__( 'reserve Excerpt Length', 'tastypress-pro' ),
	'description' 		=> esc_html__( 'Total description words to be displayed in reserve posts.', 'tastypress-pro' ),
	'section'     		=> 'tastypress_pro_reserve_section',
	'active_callback' 	=> 'tastypress_pro_is_reserve_section_enable',
	'type'        		=> 'number',
	'input_attrs' 		=> array(
		'style'       => 'width: 80px;',
		'max'         => 100,
		'min'         => 5,
	),
) );

// reserve content type control and setting
$wp_customize->add_setting( 'tastypress_pro_theme_options[reserve_content_type]', array(
	'default'          	=> $options['reserve_content_type'],
	'sanitize_callback' => 'tastypress_pro_sanitize_select',
) );

$wp_customize->add_control( 'tastypress_pro_theme_options[reserve_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'tastypress-pro' ),
	'section'           => 'tastypress_pro_reserve_section',
	'type'				=> 'select',
	'active_callback' 	=> 'tastypress_pro_is_reserve_section_enable',
	'choices'			=> tastypress_pro_reserve_content_type(),
) );

// reserve pages drop down chooser control and setting
$wp_customize->add_setting( 'tastypress_pro_theme_options[reserve_content_page]', array(
	'sanitize_callback' => 'tastypress_pro_sanitize_page',
) );

$wp_customize->add_control( new Tastypress_Pro_Dropdown_Chooser( $wp_customize, 'tastypress_pro_theme_options[reserve_content_page]', array(
	'label'             => esc_html__( 'Select Page', 'tastypress-pro' ),
	'section'           => 'tastypress_pro_reserve_section',
	'choices'			=> tastypress_pro_page_choices(),
	'active_callback'	=> 'tastypress_pro_is_reserve_section_content_page_enable',
) ) );

// reserve posts drop down chooser control and setting
$wp_customize->add_setting( 'tastypress_pro_theme_options[reserve_content_post]', array(
	'sanitize_callback' => 'tastypress_pro_sanitize_page',
) );

$wp_customize->add_control( new Tastypress_Pro_Dropdown_Chooser( $wp_customize, 'tastypress_pro_theme_options[reserve_content_post]', array(
	'label'             => esc_html__( 'Select Post', 'tastypress-pro' ),
	'section'           => 'tastypress_pro_reserve_section',
	'choices'			=> tastypress_pro_post_choices(),
	'active_callback'	=> 'tastypress_pro_is_reserve_section_content_post_enable',
) ) );


// reserve title setting and control
$wp_customize->add_setting( 'tastypress_pro_theme_options[reserve_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['reserve_title'],
) );

$wp_customize->add_control( 'tastypress_pro_theme_options[reserve_title]', array(
	'label'           	=> esc_html__( 'Title', 'tastypress-pro' ),
	'section'        	=> 'tastypress_pro_reserve_section',
	'active_callback' 	=> 'tastypress_pro_is_reserve_section_content_custom_enable',
	'type'				=> 'text',
) );


// reserve description setting and control
$wp_customize->add_setting( 'tastypress_pro_theme_options[reserve_description]', array(
	'sanitize_callback' => 'wp_kses_post',
	'default'			=> $options['reserve_description'],
) );

$wp_customize->add_control( 'tastypress_pro_theme_options[reserve_description]', array(
	'label'           	=> esc_html__( 'Description', 'tastypress-pro' ),
	'section'        	=> 'tastypress_pro_reserve_section',
	'active_callback' 	=> 'tastypress_pro_is_reserve_section_content_custom_enable',
	'type'				=> 'textarea',
) );

// reserve btn title setting and control
$wp_customize->add_setting( 'tastypress_pro_theme_options[reserve_btn_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['reserve_btn_title'],
	'transport'			=> 'postMessage',
	) );
	
	$wp_customize->add_control( 'tastypress_pro_theme_options[reserve_btn_title]', array(
	'label'           	=> esc_html__( 'Button Label', 'tastypress-pro' ),
	'section'        	=> 'tastypress_pro_reserve_section',
	'active_callback' 	=> 'tastypress_pro_is_reserve_section_enable',
	'type'				=> 'text',
	) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'tastypress_pro_theme_options[reserve_btn_title]', array(
		'selector'            => '#reserve div.read-more a',
		'settings'            => 'tastypress_pro_theme_options[reserve_btn_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'tastypress_pro_reserve_btn_title_partial',
		) );
	}

	// reserve btn link setting and control
	$wp_customize->add_setting( 'tastypress_pro_theme_options[reserve_btn_link]', array(
	'sanitize_callback' => 'esc_url_raw',
	) );

$wp_customize->add_control( 'tastypress_pro_theme_options[reserve_btn_link]', array(
	'label'           	=> esc_html__( 'Button Link', 'tastypress-pro' ),
	'section'        	=> 'tastypress_pro_reserve_section',
	'active_callback' 	=> 'tastypress_pro_is_reserve_section_content_custom_enable',
	'type'				=> 'url',
	) );

//reserve image setting and control.
$wp_customize->add_setting( 'tastypress_pro_theme_options[reserve_image]', array(
	'sanitize_callback' => 'tastypress_pro_sanitize_image'
) );

$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'tastypress_pro_theme_options[reserve_image]',
		array(
		'label'       		=> esc_html__( 'reserve Image', 'tastypress-pro' ),
		'description' 		=> sprintf( esc_html__( 'Recommended size: %1$dpx x %2$dpx ', 'tastypress-pro' ), 500, 690 ),
		'section'     		=> 'tastypress_pro_reserve_section',
		'active_callback'	=> 'tastypress_pro_is_reserve_section_content_custom_enable',
) ) );



