<?php
/**
 * Service Section options
 *
 * @package Theme Palace
 * @subpackage tastypress Pro
 * @since tastypress Pro 1.0.0
 */

// Add Service section
$wp_customize->add_section( 'tastypress_pro_service_section', array(
	'title'             => esc_html__( 'Services','tastypress-pro' ),
	'description'       => esc_html__( 'Services Section options.', 'tastypress-pro' ),
	'panel'             => 'tastypress_pro_front_page_panel',
	'active_callback'   => 'tastypress_pro_if_pro_section_enable',
) );

// Service content enable control and setting
$wp_customize->add_setting( 'tastypress_pro_theme_options[service_section_enable]', array(
	'default'			=> 	$options['service_section_enable'],
	'sanitize_callback' => 'tastypress_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Tastypress_Pro_Switch_Control( $wp_customize, 'tastypress_pro_theme_options[service_section_enable]', array(
	'label'             => esc_html__( 'Service Section Enable', 'tastypress-pro' ),
	'section'           => 'tastypress_pro_service_section',
	'on_off_label' 		=> tastypress_pro_switch_options(),
) ) );


if ( $options['service_design_type'] == 'type-2' ) {
	if ( isset( $wp_customize->selective_refresh ) ) {
	    $wp_customize->selective_refresh->add_partial( 'tastypress_pro_theme_options[service_section_enable]', array(
			'selector'            => '#business-services-section .tooltiptext',
			'settings'            => 'tastypress_pro_theme_options[service_section_enable]',
	    ) );
	}

}else{
	if ( isset( $wp_customize->selective_refresh ) ) {
	    $wp_customize->selective_refresh->add_partial( 'tastypress_pro_theme_options[service_section_enable]', array(
			'selector'            => '#our-services .tooltiptext',
			'settings'            => 'tastypress_pro_theme_options[service_section_enable]',
	    ) );
	}

}



// service title setting and control
$wp_customize->add_setting( 'tastypress_pro_theme_options[service_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['service_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'tastypress_pro_theme_options[service_title]', array(
	'label'           	=> esc_html__( 'Title', 'tastypress-pro' ),
	'section'        	=> 'tastypress_pro_service_section',
	'active_callback' 	=> 'tastypress_pro_is_service_section_enable',
	'type'				=> 'text',
) );


if ( $options['service_design_type'] == 'type-2' ) { 
	if ( isset( $wp_customize->selective_refresh ) ) {
	    $wp_customize->selective_refresh->add_partial( 'tastypress_pro_theme_options[service_title]', array(
			'selector'            => '#business-services-section h2.section-title',
			'settings'            => 'tastypress_pro_theme_options[service_title]',
			'container_inclusive' => false,
			'fallback_refresh'    => true,
			'render_callback'     => 'tastypress_pro_service_title_partial',
	    ) );
	}
}else{
	// Abort if selective refresh is not available.
	if ( isset( $wp_customize->selective_refresh ) ) {
	    $wp_customize->selective_refresh->add_partial( 'tastypress_pro_theme_options[service_title]', array(
			'selector'            => '#our-services h2.section-title',
			'settings'            => 'tastypress_pro_theme_options[service_title]',
			'container_inclusive' => false,
			'fallback_refresh'    => true,
			'render_callback'     => 'tastypress_pro_service_title_partial',
	    ) );
	}
}



// service title setting and control
$wp_customize->add_setting( 'tastypress_pro_theme_options[service_sub_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['service_sub_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'tastypress_pro_theme_options[service_sub_title]', array(
	'label'           	=> esc_html__( 'Sub Title', 'tastypress-pro' ),
	'section'        	=> 'tastypress_pro_service_section',
	'active_callback' 	=> 'tastypress_pro_is_service_section_enable',
	'type'				=> 'text',
) );




if ( $options['service_design_type'] == 'type-2' ) { 
	// Abort if selective refresh is not available.
	if ( isset( $wp_customize->selective_refresh ) ) {
	    $wp_customize->selective_refresh->add_partial( 'tastypress_pro_theme_options[service_sub_title]', array(
			'selector'            => '#business-services-section p.section-subtitle',
			'settings'            => 'tastypress_pro_theme_options[service_sub_title]',
			'container_inclusive' => false,
			'fallback_refresh'    => true,
			'render_callback'     => 'tastypress_pro_service_sub_title_partial',
	    ) );
	}
}else{
	// Abort if selective refresh is not available.
	if ( isset( $wp_customize->selective_refresh ) ) {
	    $wp_customize->selective_refresh->add_partial( 'tastypress_pro_theme_options[service_sub_title]', array(
			'selector'            => '#our-services p.section-subtitle',
			'settings'            => 'tastypress_pro_theme_options[service_sub_title]',
			'container_inclusive' => false,
			'fallback_refresh'    => true,
			'render_callback'     => 'tastypress_pro_service_sub_title_partial',
	    ) );
	}
}

// Service content type control and setting
$wp_customize->add_setting( 'tastypress_pro_theme_options[service_design_type]', array(
	'sanitize_callback' => 'tastypress_pro_sanitize_select',
) );

$wp_customize->add_control( 'tastypress_pro_theme_options[service_design_type]', array(
	'label'             => esc_html__( 'Design Type', 'tastypress-pro' ),
	'section'           => 'tastypress_pro_service_section',
	'type'				=> 'select',
	'active_callback' 	=> 'tastypress_pro_is_service_section_enable',
	'choices'			=> array(
            'type-1'      => esc_html__( 'Type 1', 'tastypress-pro' ),
            'type-2'      => esc_html__( 'Type 2', 'tastypress-pro' ),
        ),
) );


// Servuce count number control and setting
$wp_customize->add_setting( 'tastypress_pro_theme_options[service_count]', array(
	'default'          	=> $options['service_count'],
	'sanitize_callback' => 'tastypress_pro_sanitize_number_range',
	'validate_callback' => 'tastypress_pro_validate_service_count',
) );

$wp_customize->add_control( 'tastypress_pro_theme_options[service_count]', array(
	'label'             => esc_html__( 'Number of Posts', 'tastypress-pro' ),
	'description'       => esc_html__( 'Note: Min 3 & Max 12. Please input the valid number and save. Then refresh the page to see the change.', 'tastypress-pro' ),
	'section'           => 'tastypress_pro_service_section',
	'active_callback'   => 'tastypress_pro_is_service_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 3,
		'max'	=> 12,
		'style' => 'width: 100px;'
		),
) );

// long Excerpt length setting and control.
$wp_customize->add_setting( 'tastypress_pro_theme_options[service_excerpt_length]', array(
	'sanitize_callback' => 'tastypress_pro_sanitize_number_range',
	'validate_callback' => 'tastypress_pro_validate_long_excerpt',
	'default'			=> $options['service_excerpt_length'],
) );

$wp_customize->add_control( 'tastypress_pro_theme_options[service_excerpt_length]', array(
	'label'       		=> esc_html__( 'Service Excerpt Length', 'tastypress-pro' ),
	'description' 		=> esc_html__( 'Total description words to be displayed in service posts.', 'tastypress-pro' ),
	'section'     		=> 'tastypress_pro_service_section',	
	'active_callback' 	=> 'tastypress_pro_is_service_section_enable',
	'type'        		=> 'number',
	'input_attrs' 		=> array(
		'style'       => 'width: 80px;',
		'max'         => 100,
		'min'         => 5,
	),
) );

// Service content type control and setting
$wp_customize->add_setting( 'tastypress_pro_theme_options[service_content_type]', array(
	'default'          	=> $options['service_content_type'],
	'sanitize_callback' => 'tastypress_pro_sanitize_select',
) );

$wp_customize->add_control( 'tastypress_pro_theme_options[service_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'tastypress-pro' ),
	'section'           => 'tastypress_pro_service_section',
	'type'				=> 'select',
	'active_callback' 	=> 'tastypress_pro_is_service_section_enable',
	'choices'			=> array(
            'page'      => esc_html__( 'Page', 'tastypress-pro' ),
            'post'      => esc_html__( 'Post', 'tastypress-pro' ),
            'category'  => esc_html__( 'Category', 'tastypress-pro' ),
        ),
) );

for ( $i = 1; $i <= $options['service_count']; $i++ ) :

	// service note control and setting
	$wp_customize->add_setting( 'tastypress_pro_theme_options[service_content_icon_' . $i . ']', array(
		'sanitize_callback' => 'sanitize_text_field',
		) );

$wp_customize->add_control( new Tastypress_Pro_Icon_Picker( $wp_customize, 'tastypress_pro_theme_options[service_content_icon_' . $i . ']', array(
	'label'             => sprintf( esc_html__( 'Select Icon %d', 'tastypress-pro' ), $i ),
	'section'           => 'tastypress_pro_service_section',
	'active_callback'	=> 'tastypress_pro_is_service_section_enable',
	) ) );

	// service pages drop down chooser control and setting
$wp_customize->add_setting( 'tastypress_pro_theme_options[service_content_page_' . $i . ']', array(
	'sanitize_callback' => 'tastypress_pro_sanitize_page',
	) );

$wp_customize->add_control( new Tastypress_Pro_Dropdown_Chooser( $wp_customize, 'tastypress_pro_theme_options[service_content_page_' . $i . ']', array(
	'label'             => sprintf( esc_html__( 'Select Page %d', 'tastypress-pro' ), $i ),
	'section'           => 'tastypress_pro_service_section',
	'choices'			=> tastypress_pro_page_choices(),
	'active_callback'	=> 'tastypress_pro_is_service_section_content_page_enable',
	) ) );

	// service posts drop down chooser control and setting
$wp_customize->add_setting( 'tastypress_pro_theme_options[service_content_post_' . $i . ']', array(
	'sanitize_callback' => 'tastypress_pro_sanitize_page',
	) );

$wp_customize->add_control( new Tastypress_Pro_Dropdown_Chooser( $wp_customize, 'tastypress_pro_theme_options[service_content_post_' . $i . ']', array(
	'label'             => sprintf( esc_html__( 'Select Post %d', 'tastypress-pro' ), $i ),
	'section'           => 'tastypress_pro_service_section',
	'choices'			=> tastypress_pro_post_choices(),
	'active_callback'	=> 'tastypress_pro_is_service_section_content_post_enable',
	) ) );

	// service hr setting and control
$wp_customize->add_setting( 'tastypress_pro_theme_options[service_hr_'. $i .']', array(
	'sanitize_callback' => 'sanitize_text_field'
	) );

$wp_customize->add_control( new Tastypress_Pro_Customize_Horizontal_Line( $wp_customize, 'tastypress_pro_theme_options[service_hr_'. $i .']',
	array(
		'section'         => 'tastypress_pro_service_section',
		'active_callback' => 'tastypress_pro_is_service_section_content_seperator_enable',
		'type'			  => 'hr'
		) ) );
endfor;

// Add dropdown category setting and control.
$wp_customize->add_setting(  'tastypress_pro_theme_options[service_content_category]', array(
	'sanitize_callback' => 'tastypress_pro_sanitize_single_category',
) ) ;

$wp_customize->add_control( new Tastypress_Pro_Dropdown_Taxonomies_Control( $wp_customize,'tastypress_pro_theme_options[service_content_category]', array(
	'label'             => esc_html__( 'Select Category', 'tastypress-pro' ),
	'description'      	=> esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'tastypress-pro' ),
	'section'           => 'tastypress_pro_service_section',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'tastypress_pro_is_service_section_content_category_enable'
) ) );

