<?php
/**
 * Slider Section options
 *
 * @package Theme Palace
 * @subpackage tastypress Pro
 * @since tastypress Pro 1.0.0
 */

// Add Slider section
$wp_customize->add_section( 'tastypress_pro_slider_section', array(
	'title'             => esc_html__( 'Main Slider','tastypress-pro' ),
	'description'       => esc_html__( 'Slider Section options.', 'tastypress-pro' ),
	'panel'             => 'tastypress_pro_front_page_panel',
	'active_callback'   => 'tastypress_pro_if_all_section_enable',
) );

// Slider section enable control and setting
$wp_customize->add_setting( 'tastypress_pro_theme_options[slider_section_enable]', array(
	'default'			=> 	$options['slider_section_enable'],
	'sanitize_callback' => 'tastypress_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Tastypress_Pro_Switch_Control( $wp_customize, 'tastypress_pro_theme_options[slider_section_enable]', array(
	'label'             => esc_html__( 'Slider Section Enable', 'tastypress-pro' ),
	'section'           => 'tastypress_pro_slider_section',
	'on_off_label' 		=> tastypress_pro_switch_options(),
) ) );

if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'tastypress_pro_theme_options[slider_section_enable]', array(
		'selector'            => '#business-slider-section .tooltiptext',
		'settings'            => 'tastypress_pro_theme_options[slider_section_enable]',
    ) );
}


// slider sub title setting and control
$wp_customize->add_setting( 'tastypress_pro_theme_options[slider_sub_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['slider_sub_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'tastypress_pro_theme_options[slider_sub_title]', array(
	'label'           	=> esc_html__( 'Sub Title', 'tastypress-pro' ),
	'section'        	=> 'tastypress_pro_slider_section',
	'active_callback' 	=> 'tastypress_pro_is_slider_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'tastypress_pro_theme_options[slider_sub_title]', array(
		'selector'            => '#business-slider-section h4.sub-title',
		'settings'            => 'tastypress_pro_theme_options[slider_sub_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'tastypress_pro_slider_sub_title_partial',
    ) );
}


// Slider autoplay enable control and setting
$wp_customize->add_setting( 'tastypress_pro_theme_options[slider_autoplay]', array(
	'default'			=> 	$options['slider_autoplay'],
	'sanitize_callback' => 'tastypress_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Tastypress_Pro_Switch_Control( $wp_customize, 'tastypress_pro_theme_options[slider_autoplay]', array(
	'label'             => esc_html__( 'Auto Play Enable', 'tastypress-pro' ),
	'section'           => 'tastypress_pro_slider_section',
	'on_off_label' 		=> tastypress_pro_switch_options(),
	'active_callback' 	=> 'tastypress_pro_is_slider_section_enable',
) ) );


// Slider post count number control and setting
$wp_customize->add_setting( 'tastypress_pro_theme_options[slider_count]', array(
	'default'          	=> $options['slider_count'],
	'sanitize_callback' => 'tastypress_pro_sanitize_number_range',
	'validate_callback' => 'tastypress_pro_validate_slider_count',
) );

$wp_customize->add_control( 'tastypress_pro_theme_options[slider_count]', array(
	'label'             => esc_html__( 'Number of Slides', 'tastypress-pro' ),
	'description'       => esc_html__( 'Note: Min 1 & Max 10. Please input the valid number and save. Then refresh the page to see the change.', 'tastypress-pro' ),
	'section'           => 'tastypress_pro_slider_section',
	'active_callback'   => 'tastypress_pro_is_slider_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 1,
		'max'	=> 10,
		'style' => 'width: 100px;'
		),
) );

// long Excerpt length setting and control.
$wp_customize->add_setting( 'tastypress_pro_theme_options[slider_excerpt_length]', array(
	'sanitize_callback' => 'tastypress_pro_sanitize_number_range',
	'validate_callback' => 'tastypress_pro_validate_long_excerpt',
	'default'			=> $options['slider_excerpt_length'],
) );

$wp_customize->add_control( 'tastypress_pro_theme_options[slider_excerpt_length]', array(
	'label'       		=> esc_html__( 'No. of Posts', 'tastypress-pro' ),
	'description' 		=> esc_html__( 'Total description words to be displayed in slider posts.', 'tastypress-pro' ),
	'section'     		=> 'tastypress_pro_slider_section',	
	'active_callback' 	=> 'tastypress_pro_is_slider_section_enable',
	'type'        		=> 'number',
	'input_attrs' 		=> array(
		'style'       => 'width: 80px;',
		'max'         => 100,
		'min'         => 5,
	),
) );

// Slider content type control and setting
$wp_customize->add_setting( 'tastypress_pro_theme_options[slider_content_type]', array(
	'default'          	=> $options['slider_content_type'],
	'sanitize_callback' => 'tastypress_pro_sanitize_select',
) );

$wp_customize->add_control( 'tastypress_pro_theme_options[slider_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'tastypress-pro' ),
	'section'           => 'tastypress_pro_slider_section',
	'type'				=> 'select',
	'active_callback' 	=> 'tastypress_pro_is_slider_section_enable',
	'choices'			=> tastypress_pro_slider_content_type(),
) );

for ( $i = 1; $i <= $options['slider_count']; $i++ ) :
	// slider pages drop down chooser control and setting
	$wp_customize->add_setting( 'tastypress_pro_theme_options[slider_content_page_' . $i . ']', array(
		'sanitize_callback' => 'tastypress_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Tastypress_Pro_Dropdown_Chooser( $wp_customize, 'tastypress_pro_theme_options[slider_content_page_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Page %d', 'tastypress-pro' ), $i ),
		'section'           => 'tastypress_pro_slider_section',
		'choices'			=> tastypress_pro_page_choices(),
		'active_callback'	=> 'tastypress_pro_is_slider_section_content_page_enable',
	) ) );

	// slider posts drop down chooser control and setting
	$wp_customize->add_setting( 'tastypress_pro_theme_options[slider_content_post_' . $i . ']', array(
		'sanitize_callback' => 'tastypress_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Tastypress_Pro_Dropdown_Chooser( $wp_customize, 'tastypress_pro_theme_options[slider_content_post_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Post %d', 'tastypress-pro' ), $i ),
		'section'           => 'tastypress_pro_slider_section',
		'choices'			=> tastypress_pro_post_choices(),
		'active_callback'	=> 'tastypress_pro_is_slider_section_content_post_enable',
	) ) );

	// Slider trips drop down chooser control and setting
	$wp_customize->add_setting( 'tastypress_pro_theme_options[slider_content_trip_' . $i . ']', array(
		'sanitize_callback' => 'tastypress_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Tastypress_Pro_Dropdown_Chooser( $wp_customize, 'tastypress_pro_theme_options[slider_content_trip_' . $i . ']', array(
		'label'             => sprintf ( esc_html__( 'Select Trip %d', 'tastypress-pro' ), $i ),
		'section'           => 'tastypress_pro_slider_section',
		'choices'			=> tastypress_pro_trip_choices(),
		'active_callback'	=> 'tastypress_pro_is_slider_section_content_trip_enable',
	) ) );
endfor;

// Add dropdown category setting and control.
$wp_customize->add_setting(  'tastypress_pro_theme_options[slider_content_category]', array(
	'sanitize_callback' => 'tastypress_pro_sanitize_single_category',
) ) ;

$wp_customize->add_control( new Tastypress_Pro_Dropdown_Taxonomies_Control( $wp_customize,'tastypress_pro_theme_options[slider_content_category]', array(
	'label'             => esc_html__( 'Select Category', 'tastypress-pro' ),
	'description'      	=> esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'tastypress-pro' ),
	'section'           => 'tastypress_pro_slider_section',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'tastypress_pro_is_slider_section_content_category_enable'
) ) );

// About sub title setting and control
$wp_customize->add_setting( 'tastypress_pro_theme_options[slider_btn_label]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['slider_btn_label'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'tastypress_pro_theme_options[slider_btn_label]', array(
	'label'           	=> esc_html__( 'Button Label', 'tastypress-pro' ),
	'section'        	=> 'tastypress_pro_slider_section',
	'active_callback' 	=> 'tastypress_pro_is_slider_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'tastypress_pro_theme_options[slider_btn_label]', array(
		'selector'            => '#business-slider-section div.read-more a.btn',
		'settings'            => 'tastypress_pro_theme_options[slider_btn_label]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'tastypress_pro_slider_btn_label_partial',
    ) );
}

