<?php
/**
 * Subscription Section options
 *
 * @package Theme Palace
 * @subpackage tastypress Pro
 * @since tastypress Pro 1.0.0
 */

// Add Subscription section
$wp_customize->add_section( 'tastypress_pro_subscription_section', array(
	'title'             => esc_html__( 'Subscription','tastypress-pro' ),
	'description'       => esc_html__( 'Note: To activate this section you need to install Jetpack Plugin and activate subscription module.', 'tastypress-pro' ),
	'panel'             => 'tastypress_pro_front_page_panel',
	'active_callback'   => 'tastypress_pro_if_all_section_enable',
) );

// Subscription content enable control and setting
$wp_customize->add_setting( 'tastypress_pro_theme_options[subscription_section_enable]', array(
	'default'			=> 	$options['subscription_section_enable'],
	'sanitize_callback' => 'tastypress_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Tastypress_Pro_Switch_Control( $wp_customize, 'tastypress_pro_theme_options[subscription_section_enable]', array(
	'label'             => esc_html__( 'Subscription Section Enable', 'tastypress-pro' ),
	'section'           => 'tastypress_pro_subscription_section',
	'on_off_label' 		=> tastypress_pro_switch_options(),
) ) );

if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'tastypress_pro_theme_options[subscription_section_enable]', array(
		'selector'            => '#subscribe-now .tooltiptext',
		'settings'            => 'tastypress_pro_theme_options[subscription_section_enable]',
    ) );
}

// subscription  background image setting and control.
$wp_customize->add_setting( 'tastypress_pro_theme_options[subscription_bg_image]', array(
	'sanitize_callback' => 'tastypress_pro_sanitize_image'
) );

$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'tastypress_pro_theme_options[subscription_bg_image]',
		array(
		'label'       		=> esc_html__( 'subscription Background Image', 'tastypress-pro'),
		'description' 		=> sprintf( esc_html__( 'Recommended size: %1$dpx x %2$dpx ', 'tastypress-pro' ), 1920, 600 ),
		'section'     		=> 'tastypress_pro_subscription_section',
		'active_callback'	=> 'tastypress_pro_is_subscription_section_enable',
) ) );

// subscription sub title setting and control
$wp_customize->add_setting( 'tastypress_pro_theme_options[subscription_sub_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['subscription_sub_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'tastypress_pro_theme_options[subscription_sub_title]', array(
	'label'           	=> esc_html__( 'Sub Title', 'tastypress-pro' ),
	'section'        	=> 'tastypress_pro_subscription_section',
	'active_callback' 	=> 'tastypress_pro_is_subscription_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'tastypress_pro_theme_options[subscription_sub_title]', array(
		'selector'            => '#subscribe-now div.section-header',
		'settings'            => 'tastypress_pro_theme_options[subscription_sub_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'tastypress_pro_subscription_sub_title_partial',
    ) );
}

// subscription title setting and control
$wp_customize->add_setting( 'tastypress_pro_theme_options[subscription_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['subscription_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'tastypress_pro_theme_options[subscription_title]', array(
	'label'           	=> esc_html__( 'Title', 'tastypress-pro' ),
	'section'        	=> 'tastypress_pro_subscription_section',
	'active_callback' 	=> 'tastypress_pro_is_subscription_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'tastypress_pro_theme_options[subscription_title]', array(
		'selector'            => '#subscribe-now h2.section-title',
		'settings'            => 'tastypress_pro_theme_options[subscription_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'tastypress_pro_subscription_title_partial',
    ) );
}

// subscription description setting and control
$wp_customize->add_setting( 'tastypress_pro_theme_options[subscription_description]', array(
	'sanitize_callback' => 'wp_kses_post',	
	'default'			=> $options['subscription_description'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'tastypress_pro_theme_options[subscription_description]', array(
	'label'           	=> esc_html__( 'Description', 'tastypress-pro' ),
	'section'        	=> 'tastypress_pro_subscription_section',
	'active_callback' 	=> 'tastypress_pro_is_subscription_section_enable',
	'type'				=> 'textarea',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'tastypress_pro_theme_options[subscription_description]', array(
		'selector'            => '#subscribe-now div.entry-content',
		'settings'            => 'tastypress_pro_theme_options[subscription_description]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'tastypress_pro_subscription_description_partial',
    ) );
}

// subscription btn title setting and control
$wp_customize->add_setting( 'tastypress_pro_theme_options[subscription_btn_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['subscription_btn_title'],
) );

$wp_customize->add_control( 'tastypress_pro_theme_options[subscription_btn_title]', array(
	'label'           	=> esc_html__( 'Button Label', 'tastypress-pro' ),
	'section'        	=> 'tastypress_pro_subscription_section',
	'active_callback' 	=> 'tastypress_pro_is_subscription_section_enable',
	'type'				=> 'text',
) );

// subscription hr setting and control
$wp_customize->add_setting( 'tastypress_pro_theme_options[subscription_hr]', array(
	'sanitize_callback' => 'sanitize_text_field'
) );

$wp_customize->add_control( new Tastypress_Pro_Customize_Horizontal_Line( $wp_customize, 'tastypress_pro_theme_options[subscription_hr]',
	array(
		'section'         => 'tastypress_pro_subscription_section',
		'active_callback' => 'tastypress_pro_is_subscription_section_enable',
		'type'			  => 'hr'
) ) );
