<?php
/**
 * Team Section options
 *
 * @package Theme Palace
 * @subpackage tastypress Pro
 * @since tastypress Pro 1.0.0
 */

// Add Team section
$wp_customize->add_section( 'tastypress_pro_team_section', array(
	'title'             => esc_html__( 'Teams','tastypress-pro' ),
	'description'       => esc_html__( 'Teams Section options.', 'tastypress-pro' ),
	'panel'             => 'tastypress_pro_front_page_panel',
	'active_callback'   => 'tastypress_pro_if_all_section_enable',
) );

// Team content enable control and setting
$wp_customize->add_setting( 'tastypress_pro_theme_options[team_section_enable]', array(
	'default'			=> 	$options['team_section_enable'],
	'sanitize_callback' => 'tastypress_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Tastypress_Pro_Switch_Control( $wp_customize, 'tastypress_pro_theme_options[team_section_enable]', array(
	'label'             => esc_html__( 'Team Section Enable', 'tastypress-pro' ),
	'section'           => 'tastypress_pro_team_section',
	'on_off_label' 		=> tastypress_pro_switch_options(),
) ) );

if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'tastypress_pro_theme_options[team_section_enable]', array(
		'selector'            => '#business-team-section .tooltiptext',
		'settings'            => 'tastypress_pro_theme_options[team_section_enable]',
    ) );
}

// team title setting and control
$wp_customize->add_setting( 'tastypress_pro_theme_options[team_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['team_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'tastypress_pro_theme_options[team_title]', array(
	'label'           	=> esc_html__( 'Title', 'tastypress-pro' ),
	'section'        	=> 'tastypress_pro_team_section',
	'active_callback' 	=> 'tastypress_pro_is_team_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'tastypress_pro_theme_options[team_title]', array(
		'selector'            => '#business-team-section h2.section-title',
		'settings'            => 'tastypress_pro_theme_options[team_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'tastypress_pro_team_title_partial',
    ) );
}

// team sub title
$wp_customize->add_setting( 'tastypress_pro_theme_options[team_sub_title]', array(
	'default'          	=> $options['team_sub_title'],
	'sanitize_callback' => 'sanitize_textarea_field',
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'tastypress_pro_theme_options[team_sub_title]', array(
	'label'             => esc_html__( 'Sub Title', 'tastypress-pro' ),
	'section'           => 'tastypress_pro_team_section',
	'active_callback'	=> 'tastypress_pro_is_team_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'tastypress_pro_theme_options[team_sub_title]', array(
		'selector'            => '#business-team-section p.section-subtitle',
		'settings'            => 'tastypress_pro_theme_options[team_sub_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'tastypress_pro_team_sub_title_partial',
    ) );
}

// Team content type control and setting
$wp_customize->add_setting( 'tastypress_pro_theme_options[team_content_type]', array(
	'default'          	=> $options['team_content_type'],
	'sanitize_callback' => 'tastypress_pro_sanitize_select',
) );

$wp_customize->add_control( 'tastypress_pro_theme_options[team_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'tastypress-pro' ),
	'section'           => 'tastypress_pro_team_section',
	'type'				=> 'select',
	'active_callback' 	=> 'tastypress_pro_is_team_section_enable',
	'choices'			=> array( 
		'page' 		=> esc_html__( 'Page', 'tastypress-pro' ),
		'post' 		=> esc_html__( 'Post', 'tastypress-pro' ),
		'category' 	=> esc_html__( 'Category', 'tastypress-pro' ),
	),
) );

// Event social icons number control and setting
$wp_customize->add_setting( 'tastypress_pro_theme_options[team_count]', array(
	'default'          	=> $options['team_count'],
	'sanitize_callback' => 'tastypress_pro_sanitize_number_range',
	'validate_callback' => 'tastypress_pro_validate_team_count',
) );

$wp_customize->add_control( 'tastypress_pro_theme_options[team_count]', array(
	'label'             => esc_html__( 'Number of Teams', 'tastypress-pro' ),
	'description'       => esc_html__( 'Note: Min 1 & Max 9. Please input the valid number and save. Then refresh the page to see the change.', 'tastypress-pro' ),
	'section'           => 'tastypress_pro_team_section',
	'active_callback'   => 'tastypress_pro_is_team_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 1,
		'max'	=> 9,
		'style' => 'width: 100px;'
		),
) );


// long Excerpt length setting and control.
$wp_customize->add_setting( 'tastypress_pro_theme_options[team_excerpt_length]', array(
	'sanitize_callback' => 'tastypress_pro_sanitize_number_range',
	'validate_callback' => 'tastypress_pro_validate_long_excerpt',
	'default'			=> $options['team_excerpt_length'],
) );

$wp_customize->add_control( 'tastypress_pro_theme_options[team_excerpt_length]', array(
	'label'       		=> esc_html__( 'Team Excerpt Length', 'tastypress-pro' ),
	'description' 		=> esc_html__( 'Total description words to be displayed in team posts.', 'tastypress-pro' ),
	'section'     		=> 'tastypress_pro_team_section',	
	'active_callback' 	=> 'tastypress_pro_is_team_section_enable',
	'type'        		=> 'number',
	'input_attrs' 		=> array(
		'style'       => 'width: 80px;',
		'max'         => 100,
		'min'         => 5,
	),
) );

// Add dropdown category setting and control.
$wp_customize->add_setting(  'tastypress_pro_theme_options[team_content_category]', array(
	'sanitize_callback' => 'tastypress_pro_sanitize_single_category',
) ) ;

$wp_customize->add_control( new Tastypress_Pro_Dropdown_Taxonomies_Control( $wp_customize,'tastypress_pro_theme_options[team_content_category]', array(
	'label'             => esc_html__( 'Select Category', 'tastypress-pro' ),
	'description'      	=> esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'tastypress-pro' ),
	'section'           => 'tastypress_pro_team_section',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'tastypress_pro_is_team_section_content_category_enable'
) ) );


for ( $i = 1; $i <= $options['team_count']; $i++ ) :

	// team pages drop down chooser control and setting
	$wp_customize->add_setting( 'tastypress_pro_theme_options[team_content_page_' . $i . ']', array(
		'sanitize_callback' => 'tastypress_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Tastypress_Pro_Dropdown_Chooser( $wp_customize, 'tastypress_pro_theme_options[team_content_page_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Page %d', 'tastypress-pro' ), $i ),
		'section'           => 'tastypress_pro_team_section',
		'choices'			=> tastypress_pro_page_choices(),
		'active_callback'	=> 'tastypress_pro_is_team_section_content_page_enable',
	) ) );

	// team posts drop down chooser control and setting
	$wp_customize->add_setting( 'tastypress_pro_theme_options[team_content_post_' . $i . ']', array(
		'sanitize_callback' => 'tastypress_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Tastypress_Pro_Dropdown_Chooser( $wp_customize, 'tastypress_pro_theme_options[team_content_post_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Post %d', 'tastypress-pro' ), $i ),
		'section'           => 'tastypress_pro_team_section',
		'choices'			=> tastypress_pro_post_choices(),
		'active_callback'	=> 'tastypress_pro_is_team_section_content_post_enable',
	) ) );

	// team custom content
	$wp_customize->add_setting( 'tastypress_pro_theme_options[team_position_' . $i . ']', array(
		'sanitize_callback' => 'wp_kses_post',
	) );

	$wp_customize->add_control( 'tastypress_pro_theme_options[team_position_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Position %d', 'tastypress-pro' ), $i ),
		'section'           => 'tastypress_pro_team_section',
		'active_callback'	=> 'tastypress_pro_is_team_section_enable',
	) );

	// team social
	$wp_customize->add_setting( 'tastypress_pro_theme_options[team_social_' . $i. ']', array(
		'sanitize_callback' => 'esc_url_raw',
	) );

	$wp_customize->add_control( new Tastypress_Pro_Multi_Input_Custom_Control( $wp_customize, 'tastypress_pro_theme_options[team_social_' . $i. ']', array(
		'label'             => esc_html__( 'Social ', 'tastypress-pro' ),
		'button_text'       => esc_html__( 'Add social.', 'tastypress-pro' ),
		'section'           => 'tastypress_pro_team_section',
		'active_callback' 	=> 'tastypress_pro_is_team_section_enable',
	) ) );

	// team hr setting and control
	$wp_customize->add_setting( 'tastypress_pro_theme_options[team_hr_'. $i .']', array(
		'sanitize_callback' => 'sanitize_text_field'
	) );

	$wp_customize->add_control( new Tastypress_Pro_Customize_Horizontal_Line( $wp_customize, 'tastypress_pro_theme_options[team_hr_'. $i .']',
		array(
			'section'         => 'tastypress_pro_team_section',
			'active_callback' => 'tastypress_pro_is_team_section_enable',
			'type'			  => 'hr'
	) ) );
endfor;

