<?php
/**
 * Testimonial Section options
 *
 * @package Theme Palace
 * @subpackage tastypress Pro
 * @since tastypress Pro 1.0.0
 */

// Add Testimonial section
$wp_customize->add_section( 'tastypress_pro_testimonial_section', array(
	'title'             => esc_html__( 'Testimonial','tastypress-pro' ),
	'description'       => esc_html__( 'Testimonial Section options.', 'tastypress-pro' ),
	'panel'             => 'tastypress_pro_front_page_panel',
	'active_callback'   => 'tastypress_pro_if_pro_section_enable',
) );

// Testimonial content enable control and setting
$wp_customize->add_setting( 'tastypress_pro_theme_options[testimonial_section_enable]', array(
	'default'			=> 	$options['testimonial_section_enable'],
	'sanitize_callback' => 'tastypress_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Tastypress_Pro_Switch_Control( $wp_customize, 'tastypress_pro_theme_options[testimonial_section_enable]', array(
	'label'             => esc_html__( 'Testimonial Section Enable', 'tastypress-pro' ),
	'section'           => 'tastypress_pro_testimonial_section',
	'on_off_label' 		=> tastypress_pro_switch_options(),
) ) );

if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'tastypress_pro_theme_options[testimonial_section_enable]', array(
		'selector'            => '#testimonial .wrapper',
		'settings'            => 'tastypress_pro_theme_options[testimonial_section_enable]',
    ) );
}

$wp_customize->add_setting( 'tastypress_pro_theme_options[testimonial_sub_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['testimonial_sub_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'tastypress_pro_theme_options[testimonial_sub_title]', array(
	'label'           	=> esc_html__( 'Sub Title', 'tastypress-pro' ),
	'section'        	=> 'tastypress_pro_testimonial_section',
	'active_callback' 	=> 'tastypress_pro_is_testimonial_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'tastypress_pro_theme_options[testimonial_sub_title]', array(
		'selector'            => '#testimonial p.section-subtitle',
		'settings'            => 'tastypress_pro_theme_options[testimonial_sub_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'tastypress_pro_testimonial_sub_title_partial',
    ) );
}

// testimonial title setting and control
$wp_customize->add_setting( 'tastypress_pro_theme_options[testimonial_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['testimonial_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'tastypress_pro_theme_options[testimonial_title]', array(
	'label'           	=> esc_html__( 'Title', 'tastypress-pro' ),
	'section'        	=> 'tastypress_pro_testimonial_section',
	'active_callback' 	=> 'tastypress_pro_is_testimonial_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'tastypress_pro_theme_options[testimonial_title]', array(
		'selector'            => '#testimonial .section-header h2.section-title',
		'settings'            => 'tastypress_pro_theme_options[testimonial_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'tastypress_pro_testimonial_title_partial',
    ) );
}

// Testimonial post  number control and setting
$wp_customize->add_setting( 'tastypress_pro_theme_options[testimonial_count]', array(
	'default'          	=> $options['testimonial_count'],
	'sanitize_callback' => 'tastypress_pro_sanitize_number_range',
	'validate_callback' => 'tastypress_pro_validate_testimonial_count',
) );

$wp_customize->add_control( 'tastypress_pro_theme_options[testimonial_count]', array(
	'label'             => esc_html__( 'Number of Testimonials', 'tastypress-pro' ),
	'description'       => esc_html__( 'Note: Min 1 & Max 10. Please input the valid number and save. Then refresh the page to see the change.', 'tastypress-pro' ),
	'section'           => 'tastypress_pro_testimonial_section',
	'active_callback'   => 'tastypress_pro_is_testimonial_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 1,
		'max'	=> 10,
		'style' => 'width: 100px;'
		),
) );

// long Excerpt length setting and control.
$wp_customize->add_setting( 'tastypress_pro_theme_options[testimonial_excerpt_length]', array(
	'sanitize_callback' => 'tastypress_pro_sanitize_number_range',
	'validate_callback' => 'tastypress_pro_validate_long_excerpt',
	'default'			=> $options['testimonial_excerpt_length'],
) );

$wp_customize->add_control( 'tastypress_pro_theme_options[testimonial_excerpt_length]', array(
	'label'       		=> esc_html__( 'No. of Posts', 'tastypress-pro' ),
	'description' 		=> esc_html__( 'Total description words to be displayed in testimonial posts.', 'tastypress-pro' ),
	'section'     		=> 'tastypress_pro_testimonial_section',	
	'active_callback' 	=> 'tastypress_pro_is_testimonial_section_enable',
	'type'        		=> 'number',
	'input_attrs' 		=> array(
		'style'       => 'width: 80px;',
		'max'         => 100,
		'min'         => 5,
	),
) );

// Testimonial content type control and setting
$wp_customize->add_setting( 'tastypress_pro_theme_options[testimonial_content_type]', array(
	'default'          	=> $options['testimonial_content_type'],
	'sanitize_callback' => 'tastypress_pro_sanitize_select',
) );

$wp_customize->add_control( 'tastypress_pro_theme_options[testimonial_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'tastypress-pro' ),
	'section'           => 'tastypress_pro_testimonial_section',
	'type'				=> 'select',
	'active_callback' 	=> 'tastypress_pro_is_testimonial_section_enable',
	'choices'			=> array( 
		'page' 		=> esc_html__( 'Page', 'tastypress-pro' ),
		'post' 		=> esc_html__( 'Post', 'tastypress-pro' ),
		'category' 	=> esc_html__( 'Category', 'tastypress-pro' ),
	),
) );

// Add dropdown category setting and control.
$wp_customize->add_setting(  'tastypress_pro_theme_options[testimonial_content_category]', array(
	'sanitize_callback' => 'tastypress_pro_sanitize_single_category',
) ) ;

$wp_customize->add_control( new Tastypress_Pro_Dropdown_Taxonomies_Control( $wp_customize,'tastypress_pro_theme_options[testimonial_content_category]', array(
	'label'             => esc_html__( 'Select Category', 'tastypress-pro' ),
	'description'      	=> esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'tastypress-pro' ),
	'section'           => 'tastypress_pro_testimonial_section',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'tastypress_pro_is_testimonial_section_content_category_enable'
) ) );

for ( $i = 1; $i <= $options['testimonial_count']; $i++ ) :
	// testimonial pages drop down chooser control and setting
	$wp_customize->add_setting( 'tastypress_pro_theme_options[testimonial_content_page_' . $i . ']', array(
		'sanitize_callback' => 'tastypress_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Tastypress_Pro_Dropdown_Chooser( $wp_customize, 'tastypress_pro_theme_options[testimonial_content_page_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Page %d', 'tastypress-pro' ), $i ),
		'section'           => 'tastypress_pro_testimonial_section',
		'choices'			=> tastypress_pro_page_choices(),
		'active_callback'	=> 'tastypress_pro_is_testimonial_section_content_page_enable',
	) ) );

	// testimonial posts drop down chooser control and setting
	$wp_customize->add_setting( 'tastypress_pro_theme_options[testimonial_content_post_' . $i . ']', array(
		'sanitize_callback' => 'tastypress_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Tastypress_Pro_Dropdown_Chooser( $wp_customize, 'tastypress_pro_theme_options[testimonial_content_post_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Post %d', 'tastypress-pro' ), $i ),
		'section'           => 'tastypress_pro_testimonial_section',
		'choices'			=> tastypress_pro_post_choices(),
		'active_callback'	=> 'tastypress_pro_is_testimonial_section_content_post_enable',
	) ) );


	$wp_customize->add_setting( 'tastypress_pro_theme_options[testimonial_position_' . $i . ']', array(
		'sanitize_callback' => 'sanitize_text_field',

	) );

	$wp_customize->add_control( 'tastypress_pro_theme_options[testimonial_position_' . $i . ']', array(
		'label'           	=> esc_html__( 'Position ', 'tastypress-pro' ). $i,
		'section'        	=> 'tastypress_pro_testimonial_section',
		'active_callback' 	=> 'tastypress_pro_is_testimonial_section_enable',
		'type'				=> 'text',
	) );

endfor;

