<?php
/**
 * trending_product Section options
 *
 * @package Theme Palace
 * @subpackage tastypress Pro
 * @since tastypress Pro 1.0.0
 */
if ( !class_exists('WooCommerce') ) {
	return;
}
// Add trending_product section
$wp_customize->add_section( 'tastypress_pro_trending_product_section', array(
	'title'             => esc_html__( 'Trending Product','tastypress-pro' ),
	'description'       => esc_html__( 'Trending Product Section options.', 'tastypress-pro' ),
	'panel'             => 'tastypress_pro_front_page_panel',
	'active_callback'   => 'tastypress_pro_if_all_section_enable',
) );

// trending_product content enable control and setting
$wp_customize->add_setting( 'tastypress_pro_theme_options[trending_product_section_enable]', array(
	'default'			=> 	$options['trending_product_section_enable'],
	'sanitize_callback' => 'tastypress_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Tastypress_Pro_Switch_Control( $wp_customize, 'tastypress_pro_theme_options[trending_product_section_enable]', array(
	'label'             => esc_html__( 'Trending Product Section Enable', 'tastypress-pro' ),
	'section'           => 'tastypress_pro_trending_product_section',
	'on_off_label' 		=> tastypress_pro_switch_options(),
) ) );

if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'tastypress_pro_theme_options[trending_product_section_enable]', array(
        'selector'            => '#trending-products .tooltiptext',
        'settings'            => 'tastypress_pro_theme_options[trending_product_section_enable]',
    ) );
}

$wp_customize->add_setting( 'tastypress_pro_theme_options[trending_product_count]', array(
	'default'          	=> $options['trending_product_count'],
	'sanitize_callback' => 'tastypress_pro_sanitize_number_range',
	'validate_callback' => 'tastypress_pro_validate_trending_product_count',
) );

$wp_customize->add_control( 'tastypress_pro_theme_options[trending_product_count]', array(
	'label'             => esc_html__( 'Number of Product Per Column', 'tastypress-pro' ),
	'description'       => esc_html__( 'Note: Min 1 & Max 12. Please input the valid number and save. Then refresh the page to see the change.', 'tastypress-pro' ),
	'section'           => 'tastypress_pro_trending_product_section',
	'active_callback'   => 'tastypress_pro_is_trending_product_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 1,
		'max'	=> 12,
		'style' => 'width: 100px;'
		),
) );

for( $i = 1 ; $i <= 3 ; $i++ ){

$wp_customize->add_setting( 'tastypress_pro_theme_options[trending_product_column_'. $i .']', array(
		'sanitize_callback' => 'sanitize_text_field'
	) );

$wp_customize->add_control( new Tastypress_Pro_Customize_Column( $wp_customize, 'tastypress_pro_theme_options[trending_product_column_'. $i .']',
	array(
		'label'			  => esc_html__('Column ', 'tastypress-pro').$i,
		'section'         => 'tastypress_pro_trending_product_section',
		'active_callback' => 'tastypress_pro_is_trending_product_section_enable',
		'type'			  => 'column'
) ) );

// trending_product title setting and control
$wp_customize->add_setting( 'tastypress_pro_theme_options[trending_product_title_'.$i.']', array(
    'sanitize_callback' => 'sanitize_text_field',
) );

$wp_customize->add_control( 'tastypress_pro_theme_options[trending_product_title_'.$i.']', array(
    'label'             => esc_html__( 'Title', 'tastypress-pro' ),
    'section'           => 'tastypress_pro_trending_product_section',
    'active_callback'   => 'tastypress_pro_is_trending_product_section_enable',
    'type'              => 'text',
) );

$wp_customize->add_setting( 'tastypress_pro_theme_options[trending_content_type_'.$i.']', array(
	'default'          	=> 'product',
	'sanitize_callback' => 'tastypress_pro_sanitize_select',
) );

$wp_customize->add_control( 'tastypress_pro_theme_options[trending_content_type_'.$i.']', array(
	'label'             => esc_html__( 'Content Type', 'tastypress-pro' ),
	'section'           => 'tastypress_pro_trending_product_section',
	'type'				=> 'select',
	'active_callback' 	=> 'tastypress_pro_is_trending_product_section_enable',
	'choices'			=> array(
		'product'           => esc_html__( 'Product', 'tastypress-pro' ),
		'product_cat'       => esc_html__( 'Product Category', 'tastypress-pro' ),
		),
) );

for ( $j=1 ; $j <= $options['trending_product_count'] ; $j++ ) { 
	$wp_customize->add_setting( 'tastypress_pro_theme_options[trending_product_content_page_'. $i.$j. ']', array(
		'sanitize_callback' => 'tastypress_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Tastypress_Pro_Dropdown_Chooser( $wp_customize, 'tastypress_pro_theme_options[trending_product_content_page_' .$i.$j. ']', array(
			'label'             => sprintf( esc_html__( 'Select Product %d', 'tastypress-pro' ), $j ),
			'section'           => 'tastypress_pro_trending_product_section',
			'choices'			=> tastypress_pro_product_choices(),
			'active_callback'	=> 'tastypress_pro_is_trending_product_section_content_product_enable_'.$i,

	) ) );
}

$wp_customize->add_setting(  'tastypress_pro_theme_options[trending_product_category_'.$i.']', array(
	'sanitize_callback' => 'tastypress_pro_sanitize_integers',
	) ) ;

$wp_customize->add_control( new Tastypress_Pro_Dropdown_Taxonomies_Control( $wp_customize,'tastypress_pro_theme_options[trending_product_category_'.$i.']', array(
	'label'             => esc_html__( 'Select Product Categories', 'tastypress-pro' ),
	'description'      	=> esc_html__( 'Note: Press CTRL and select multiple category. Latest four posts will be shown from each selected category', 'tastypress-pro' ),
	'section'           => 'tastypress_pro_trending_product_section',
	'taxonomy'			=> 'product_cat',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'tastypress_pro_is_trending_product_section_content_category_enable_'.$i,

) ) );

$wp_customize->add_setting( 'tastypress_pro_theme_options[trending_product_hr_'. $i .']', array(
		'sanitize_callback' => 'sanitize_text_field'
	) );

$wp_customize->add_control( new Tastypress_Pro_Customize_Horizontal_Line( $wp_customize, 'tastypress_pro_theme_options[trending_product_hr_'. $i .']',
	array(
		'section'         => 'tastypress_pro_trending_product_section',
		'active_callback' => 'tastypress_pro_is_trending_product_section_enable',
		'type'			  => 'hr'
) ) );

}

