<?php
/**
 * video Section options
 *
 * @package Theme Palace
 * @subpackage tastypress Pro
 * @since tastypress Pro 1.0.0
 */

// Add video section
$wp_customize->add_section( 'tastypress_pro_video_section', array(
	'title'             => esc_html__( 'Video','tastypress-pro' ),
	'description'       => esc_html__( 'Video Section options.', 'tastypress-pro' ),
	'panel'             => 'tastypress_pro_front_page_panel',
	'active_callback'   => 'tastypress_pro_if_all_section_enable',
) );

// video Section enable control and setting
$wp_customize->add_setting( 'tastypress_pro_theme_options[video_section_enable]', array(
	'default'			=> 	$options['video_section_enable'],
	'sanitize_callback' => 'tastypress_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Tastypress_Pro_Switch_Control( $wp_customize, 'tastypress_pro_theme_options[video_section_enable]', array(
	'label'             => esc_html__( 'Video Section Enable', 'tastypress-pro' ),
	'section'           => 'tastypress_pro_video_section',
	'on_off_label' 		=> tastypress_pro_switch_options(),
) ) );

if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'tastypress_pro_theme_options[video_section_enable]', array(
		'selector'            => '#video .tooltiptext',
		'settings'            => 'tastypress_pro_theme_options[video_section_enable]',
    ) );
}

// video sub title setting and control
$wp_customize->add_setting( 'tastypress_pro_theme_options[video_sub_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['video_sub_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'tastypress_pro_theme_options[video_sub_title]', array(
	'label'           	=> esc_html__( 'Sub Title', 'tastypress-pro' ),
	'section'        	=> 'tastypress_pro_video_section',
	'active_callback' 	=> 'tastypress_pro_is_video_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'tastypress_pro_theme_options[video_sub_title]', array(
		'selector'            => '#video p.section-subtitle',
		'settings'            => 'tastypress_pro_theme_options[video_sub_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'tastypress_pro_video_sub_title_partial',
    ) );
}

// long Excerpt length setting and control.
$wp_customize->add_setting( 'tastypress_pro_theme_options[video_excerpt_length]', array(
	'sanitize_callback' => 'tastypress_pro_sanitize_number_range',
	'validate_callback' => 'tastypress_pro_validate_long_excerpt',
	'default'			=> $options['video_excerpt_length'],
) );

$wp_customize->add_control( 'tastypress_pro_theme_options[video_excerpt_length]', array(
	'label'       		=> esc_html__( 'video Excerpt Length', 'tastypress-pro' ),
	'description' 		=> esc_html__( 'Total description words to be displayed in video posts.', 'tastypress-pro' ),
	'section'     		=> 'tastypress_pro_video_section',
	'active_callback' 	=> 'tastypress_pro_is_video_section_enable',
	'type'        		=> 'number',
	'input_attrs' 		=> array(
		'style'       => 'width: 80px;',
		'max'         => 100,
		'min'         => 5,
	),
) );

// video content type control and setting
$wp_customize->add_setting( 'tastypress_pro_theme_options[video_content_type]', array(
	'default'          	=> $options['video_content_type'],
	'sanitize_callback' => 'tastypress_pro_sanitize_select',
) );

$wp_customize->add_control( 'tastypress_pro_theme_options[video_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'tastypress-pro' ),
	'section'           => 'tastypress_pro_video_section',
	'type'				=> 'select',
	'active_callback' 	=> 'tastypress_pro_is_video_section_enable',
	'choices'			=> tastypress_pro_video_content_type(),
) );

// video pages drop down chooser control and setting
$wp_customize->add_setting( 'tastypress_pro_theme_options[video_content_page]', array(
	'sanitize_callback' => 'tastypress_pro_sanitize_page',
) );

$wp_customize->add_control( new Tastypress_Pro_Dropdown_Chooser( $wp_customize, 'tastypress_pro_theme_options[video_content_page]', array(
	'label'             => esc_html__( 'Select Page', 'tastypress-pro' ),
	'section'           => 'tastypress_pro_video_section',
	'choices'			=> tastypress_pro_page_choices(),
	'active_callback'	=> 'tastypress_pro_is_video_section_content_page_enable',
) ) );

// video posts drop down chooser control and setting
$wp_customize->add_setting( 'tastypress_pro_theme_options[video_content_post]', array(
	'sanitize_callback' => 'tastypress_pro_sanitize_page',
) );

$wp_customize->add_control( new Tastypress_Pro_Dropdown_Chooser( $wp_customize, 'tastypress_pro_theme_options[video_content_post]', array(
	'label'             => esc_html__( 'Select Post', 'tastypress-pro' ),
	'section'           => 'tastypress_pro_video_section',
	'choices'			=> tastypress_pro_post_choices(),
	'active_callback'	=> 'tastypress_pro_is_video_section_content_post_enable',
) ) );

// video posts drop down chooser control and setting
$wp_customize->add_setting( 'tastypress_pro_theme_options[video_content_product]', array(
	'sanitize_callback' => 'tastypress_pro_sanitize_page',
) );

$wp_customize->add_control( new Tastypress_Pro_Dropdown_Chooser( $wp_customize, 'tastypress_pro_theme_options[video_content_product]', array(
	'label'             => esc_html__( 'Select Product', 'tastypress-pro' ),
	'section'           => 'tastypress_pro_video_section',
	'choices'			=> tastypress_pro_product_choices(),
	'active_callback'	=> 'tastypress_pro_is_video_section_content_product_enable',
) ) );


// video title setting and control
$wp_customize->add_setting( 'tastypress_pro_theme_options[video_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['video_title'],
) );

$wp_customize->add_control( 'tastypress_pro_theme_options[video_title]', array(
	'label'           	=> esc_html__( 'Title', 'tastypress-pro' ),
	'section'        	=> 'tastypress_pro_video_section',
	'active_callback' 	=> 'tastypress_pro_is_video_section_content_custom_enable',
	'type'				=> 'text',
) );


// video description setting and control
$wp_customize->add_setting( 'tastypress_pro_theme_options[video_description]', array(
	'sanitize_callback' => 'wp_kses_post',
	'default'			=> $options['video_description'],
) );

$wp_customize->add_control( 'tastypress_pro_theme_options[video_description]', array(
	'label'           	=> esc_html__( 'Description', 'tastypress-pro' ),
	'section'        	=> 'tastypress_pro_video_section',
	'active_callback' 	=> 'tastypress_pro_is_video_section_content_custom_enable',
	'type'				=> 'textarea',
) );


	// video btn link setting and control
$wp_customize->add_setting( 'tastypress_pro_theme_options[video_btn_link]', array(
	'sanitize_callback' => 'esc_url_raw',
) );

$wp_customize->add_control( 'tastypress_pro_theme_options[video_btn_link]', array(
	'label'           	=> esc_html__( 'Video Link', 'tastypress-pro' ),
	'section'        	=> 'tastypress_pro_video_section',
	'active_callback' 	=> 'tastypress_pro_is_video_section_enable',
	'type'				=> 'url',
	) );





