<?php
/**
 * Archive options
 *
 * @package Theme Palace
 * @subpackage tastypress Pro
 * @since tastypress Pro 1.0.0
 */

// Add archive section
$wp_customize->add_section( 'tastypress_pro_archive_section', array(
	'title'             => esc_html__( 'Blog/Archive','tastypress-pro' ),
	'description'       => esc_html__( 'Archive section options.', 'tastypress-pro' ),
	'panel'             => 'tastypress_pro_theme_options_panel',
) );

// Your latest posts title setting and control.
$wp_customize->add_setting( 'tastypress_pro_theme_options[your_latest_posts_title]', array(
	'default'           => $options['your_latest_posts_title'],
	'sanitize_callback' => 'sanitize_text_field',
) );

$wp_customize->add_control( 'tastypress_pro_theme_options[your_latest_posts_title]', array(
	'label'             => esc_html__( 'Your Latest Posts Title', 'tastypress-pro' ),
	'description'       => esc_html__( 'This option only works if Static Front Page is set to "Your latest posts."', 'tastypress-pro' ),
	'section'           => 'tastypress_pro_archive_section',
	'type'				=> 'text',
	'active_callback'   => 'tastypress_pro_is_latest_posts'
) );

// Archive date meta setting and control.
$wp_customize->add_setting( 'tastypress_pro_theme_options[hide_date]', array(
	'default'           => $options['hide_date'],
	'sanitize_callback' => 'tastypress_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Tastypress_Pro_Switch_Control( $wp_customize, 'tastypress_pro_theme_options[hide_date]', array(
	'label'             => esc_html__( 'Hide Date', 'tastypress-pro' ),
	'section'           => 'tastypress_pro_archive_section',
	'on_off_label' 		=> tastypress_pro_hide_options(),
) ) );

// Archive category setting and control.
$wp_customize->add_setting( 'tastypress_pro_theme_options[hide_category]', array(
	'default'           => $options['hide_category'],
	'sanitize_callback' => 'tastypress_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Tastypress_Pro_Switch_Control( $wp_customize, 'tastypress_pro_theme_options[hide_category]', array(
	'label'             => esc_html__( 'Hide Category', 'tastypress-pro' ),
	'section'           => 'tastypress_pro_archive_section',
	'on_off_label' 		=> tastypress_pro_hide_options(),
) ) );

// features content type control and setting
$wp_customize->add_setting( 'tastypress_pro_theme_options[blog_column]', array(
	'default'          	=> $options['blog_column'],
	'sanitize_callback' => 'tastypress_pro_sanitize_select',
	'transport'			=> 'refresh',
) );

$wp_customize->add_control( 'tastypress_pro_theme_options[blog_column]', array(
	'label'             => esc_html__( 'Column Layout', 'tastypress-pro' ),
	'section'           => 'tastypress_pro_archive_section',
	'type'				=> 'select',
	'choices'			=> array( 
		'col-1'		=> esc_html__( 'One Column', 'tastypress-pro' ),
		'col-2'		=> esc_html__( 'Two Column', 'tastypress-pro' ),
		'col-3'		=> esc_html__( 'Three Column', 'tastypress-pro' ),
	),
) );

// Archive sub title setting and control
$wp_customize->add_setting( 'tastypress_pro_theme_options[blog_page_button]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['blog_page_button'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'tastypress_pro_theme_options[blog_page_button]', array(
	'label'           	=> esc_html__( 'Read More Button', 'tastypress-pro' ),
	'section'        	=> 'tastypress_pro_archive_section',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'tastypress_pro_theme_options[blog_page_button]', array(
		'selector'            => '#inner-content-wrapper div.read-more a.btn',
		'settings'            => 'tastypress_pro_theme_options[blog_page_button]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'tastypress_pro_blog_page_button_partial',
    ) );
}
