<?php
/**
 * Theme Palace options
 *
 * @package Theme Palace
 * @subpackage tastypress Pro
 * @since tastypress Pro 1.0.0
 */

/**
 * List of pages for page choices.
 * @return Array Array of page ids and name.
 */
function tastypress_pro_page_choices() {
    $pages = get_pages();
    $choices = array();
    $choices[0] = esc_html__( '--Select--', 'tastypress-pro' );
    foreach ( $pages as $page ) {
        $choices[ $page->ID ] = $page->post_title;
    }
    return  $choices;
}

/**
 * List of posts for post choices.
 * @return Array Array of post ids and name.
 */
function tastypress_pro_post_choices() {
    $posts = get_posts( array( 'numberposts' => -1 ) );
    $choices = array();
    $choices[0] = esc_html__( '--Select--', 'tastypress-pro' );
    foreach ( $posts as $post ) {
        $choices[ $post->ID ] = $post->post_title;
    }
    return  $choices;
}

/**
 * List of trips for post choices.
 * @return Array Array of post ids and name.
 */
function tastypress_pro_trip_choices() {
    $posts = get_posts( array( 'post_type' => 'itineraries', 'numberposts' => -1 ) );
    $choices = array();
    $choices[0] = esc_html__( '--Select--', 'tastypress-pro' );
    foreach ( $posts as $post ) {
        $choices[ $post->ID ] = $post->post_title;
    }
    return  $choices;
}

function tastypress_pro_product_choices() {
    $full_product_list = array();
    $product_id = array();
    $loop = new WP_Query(array('post_type' => array('product', 'product_variation'), 'posts_per_page' => -1));
    while ($loop->have_posts()) : $loop->the_post();
        $product_id[] = get_the_id();
    endwhile;
    wp_reset_postdata();
    $choices = array();
    $choices[0] = esc_html__( '--Select--', 'tastypress-pro' );
    foreach ( $product_id  as $id ) {
        $choices[ $id ] = get_the_title( $id );
    }
    return  $choices;
}

if ( ! function_exists( 'tastypress_pro_typography_options' ) ) :
    /**
     * Returns list of typography
     * @return array font styles
     */
    function tastypress_pro_typography_options(){
        $font_family_arr = array();
        $font_family_arr[''] = esc_html__( '--Default--', 'tastypress-pro' );

        // Make the request
        $request = wp_remote_get( get_theme_file_uri( 'assets/webfonts.json' ) );

        if( is_wp_error( $request ) ) {
            return false; // Bail early
        }
        // Retrieve the data
        $body = wp_remote_retrieve_body( $request );
        $data = json_decode( $body );
        if ( ! empty( $data ) ) {
            foreach ( $data->items as $items => $fonts ) {
                $family_str_arr = explode( ' ', $fonts->family );
                $family_value = implode( '+', $family_str_arr );
                $font_family_arr[ $family_value ] = $fonts->family;
            }
        }

        return $font_family_arr;
    }
endif;


if ( ! function_exists( 'tastypress_pro_body_typography_options' ) ) :
    /**
     * Returns list of typography
     * @return array font styles
     */
    function tastypress_pro_body_typography_options(){
        $choices = array(
            'default'         => esc_html__( 'Default', 'tastypress-pro' ),
            'body-font-1'     => esc_html__( 'News Cycle', 'tastypress-pro' ),
            'body-font-2'     => esc_html__( 'Pontano Sans', 'tastypress-pro' ),
            'body-font-3'     => esc_html__( 'Gudea', 'tastypress-pro' ),
            'body-font-4'     => esc_html__( 'Quattrocento', 'tastypress-pro' ),
            'body-font-5'     => esc_html__( 'Khand', 'tastypress-pro' ),
        );

        $output = apply_filters( 'tastypress_pro_body_typography_options', $choices );
        if ( ! empty( $output ) ) {
            ksort( $output );
        }

        return $output;
    }
endif;


if ( ! function_exists( 'tastypress_pro_selected_sidebar' ) ) :
    /**
     * Sidebars options
     * @return array Sidbar positions
     */
    function tastypress_pro_selected_sidebar() {
        $tastypress_pro_selected_sidebar = array(
            'sidebar-1'             => esc_html__( 'Default Sidebar', 'tastypress-pro' ),
            'optional-sidebar'      => esc_html__( 'Optional Sidebar 1', 'tastypress-pro' ),
            'optional-sidebar-2'    => esc_html__( 'Optional Sidebar 2', 'tastypress-pro' ),
            'optional-sidebar-3'    => esc_html__( 'Optional Sidebar 3', 'tastypress-pro' ),
            'optional-sidebar-4'    => esc_html__( 'Optional Sidebar 4', 'tastypress-pro' ),
        );

        $output = apply_filters( 'tastypress_pro_selected_sidebar', $tastypress_pro_selected_sidebar );

        return $output;
    }
endif;

if ( ! function_exists( 'tastypress_pro_site_layout' ) ) :
    /**
     * Site Layout
     * @return array site layout options
     */
    function tastypress_pro_site_layout() {
        $tastypress_pro_site_layout = array(
            'wide-layout'  => get_template_directory_uri() . '/assets/images/full.png',
            'boxed-layout' => get_template_directory_uri() . '/assets/images/boxed.png',
            'frame-layout' => get_template_directory_uri() . '/assets/images/framed.png',
        );

        $output = apply_filters( 'tastypress_pro_site_layout', $tastypress_pro_site_layout );
        return $output;
    }
endif;


if ( ! function_exists( 'tastypress_pro_global_sidebar_position' ) ) :
    /**
     * Global Sidebar position
     * @return array Global Sidebar positions
     */
    function tastypress_pro_global_sidebar_position() {
        $tastypress_pro_global_sidebar_position = array(
            'right-sidebar' => get_template_directory_uri() . '/assets/images/right.png',
            'left-sidebar'  => get_template_directory_uri() . '/assets/images/left.png',
            'no-sidebar'    => get_template_directory_uri() . '/assets/images/full.png',
        );

        $output = apply_filters( 'tastypress_pro_global_sidebar_position', $tastypress_pro_global_sidebar_position );

        return $output;
    }
endif;


if ( ! function_exists( 'tastypress_pro_sidebar_position' ) ) :
    /**
     * Sidebar position
     * @return array Sidbar positions
     */
    function tastypress_pro_sidebar_position() {
        $tastypress_pro_sidebar_position = array(
            'right-sidebar' => get_template_directory_uri() . '/assets/images/right.png',
            'left-sidebar'  => get_template_directory_uri() . '/assets/images/left.png',
            'no-sidebar'    => get_template_directory_uri() . '/assets/images/full.png',
            'no-sidebar-content'   => get_template_directory_uri() . '/assets/images/boxed.png',
        );

        $output = apply_filters( 'tastypress_pro_sidebar_position', $tastypress_pro_sidebar_position );

        return $output;
    }
endif;


if ( ! function_exists( 'tastypress_pro_pagination_options' ) ) :
    /**
     * Pagination
     * @return array site pagination options
     */
    function tastypress_pro_pagination_options() {
        $tastypress_pro_pagination_options = array(
            'numeric'   => esc_html__( 'Numeric', 'tastypress-pro' ),
            'default'   => esc_html__( 'Default(Older/Newer)', 'tastypress-pro' ),
            'infinite'  => esc_html__( 'Infinite', 'tastypress-pro' ),
        );

        $output = apply_filters( 'tastypress_pro_pagination_options', $tastypress_pro_pagination_options );

        return $output;
    }
endif;

if ( ! function_exists( 'tastypress_pro_get_spinner_list' ) ) :
    /**
     * List of spinner icons options.
     * @return array List of all spinner icon options.
     */
    function tastypress_pro_get_spinner_list() {
        $arr = array(
            'default'               => esc_html__( 'Default', 'tastypress-pro' ),
            'spinner-wheel'         => esc_html__( 'Wheel', 'tastypress-pro' ),
            'spinner-double-circle' => esc_html__( 'Double Circle', 'tastypress-pro' ),
            'spinner-two-way'       => esc_html__( 'Two Way', 'tastypress-pro' ),
            'spinner-umbrella'      => esc_html__( 'Umbrella', 'tastypress-pro' ),
            'spinner-dots'          => esc_html__( 'Dots', 'tastypress-pro' ),
            'spinner-one-way'       => esc_html__( 'One Way', 'tastypress-pro' ),
            'spinner-fidget'        => esc_html__( 'Fidget', 'tastypress-pro' ),
        );
        return apply_filters( 'tastypress_pro_spinner_list', $arr );
    }
endif;

if ( ! function_exists( 'tastypress_pro_switch_options' ) ) :
    /**
     * List of custom Switch Control options
     * @return array List of switch control options.
     */
    function tastypress_pro_switch_options() {
        $arr = array(
            'on'        => esc_html__( 'Enable', 'tastypress-pro' ),
            'off'       => esc_html__( 'Disable', 'tastypress-pro' )
        );
        return apply_filters( 'tastypress_pro_switch_options', $arr );
    }
endif;

if ( ! function_exists( 'tastypress_pro_hide_options' ) ) :
    /**
     * List of custom Switch Control options
     * @return array List of switch control options.
     */
    function tastypress_pro_hide_options() {
        $arr = array(
            'on'        => esc_html__( 'Yes', 'tastypress-pro' ),
            'off'       => esc_html__( 'No', 'tastypress-pro' )
        );
        return apply_filters( 'tastypress_pro_hide_options', $arr );
    }
endif;

if ( ! function_exists( 'tastypress_pro_sortable_sections' ) ) :
    /**
     * List of sections Control options
     * @return array List of Sections control options.
     */
    function tastypress_pro_sortable_sections() {
        $sections = array(
            'slider'                    => esc_html__( 'Slider Section', 'tastypress-pro' ),
            'hero'                      => esc_html__( 'Hero Section', 'tastypress-pro' ),
            'service'                   => esc_html__( 'Service Section', 'tastypress-pro' ),
            'menu'                      => esc_html__( 'Menu Section', 'tastypress-pro' ),
            'about'                     => esc_html__( 'About Section', 'tastypress-pro' ),
            'counter'                   => esc_html__( 'Counter Section', 'tastypress-pro' ),
            'reserve'                   => esc_html__( 'Reserve Section', 'tastypress-pro' ),
            'testimonial'               => esc_html__( 'Testimonial Section', 'tastypress-pro' ),
            'download'                  => esc_html__( 'Download Section', 'tastypress-pro' ),
            'cta'                       => esc_html__( 'CTA Section', 'tastypress-pro' ),
            'video'                     => esc_html__( 'Video Section', 'tastypress-pro' ),
            'team'                      => esc_html__( 'Team', 'tastypress-pro' ),
            'recent_products'           => esc_html__( 'Recent Products', 'tastypress-pro' ),
            'blog'                      => esc_html__( 'Blog Section', 'tastypress-pro' ),
            'event'                     => esc_html__( 'Event Section', 'tastypress-pro' ),
            'release'                   => esc_html__( 'Release Section', 'tastypress-pro' ),
            'featured_products'         => esc_html__( 'Featured Products Section', 'tastypress-pro' ),
            'featured_posts'            => esc_html__( 'Featured Posts Section', 'tastypress-pro' ),
            'latest_products'           => esc_html__( 'Latest Products Section', 'tastypress-pro' ),
            'trending_product'          => esc_html__( 'Trending Products Section', 'tastypress-pro' ),
            'highlighted'               => esc_html__( 'Highlighted Section', 'tastypress-pro' ),
            '3column'                   => esc_html__( 'There Column Section', 'tastypress-pro' ),
            '2column'                   => esc_html__( 'Two Column Section', 'tastypress-pro' ),
            '4column'                   => esc_html__( 'Four Column Section', 'tastypress-pro' ),
            'magazine_featured_post'    => esc_html__( 'Magazine Featured Post News', 'tastypress-pro' ),
            'ads'                       => esc_html__( 'Ads', 'tastypress-pro' ),
            'subscription'              => esc_html__( 'Subscription', 'tastypress-pro' ),
        );
        
        return apply_filters( 'tastypress_pro_sortable_sections', $sections );
    }
endif;

if ( ! function_exists( 'tastypress_pro_slider_content_type' ) ) :
    /**
     * slider Options
     * @return array site slider options
     */
    function tastypress_pro_slider_content_type() {
      
        $tastypress_pro_slider_content_type = array(
            'page'      => esc_html__( 'Page', 'tastypress-pro' ),
            'post'      => esc_html__( 'Post', 'tastypress-pro' ),
            'category'  => esc_html__( 'Category', 'tastypress-pro' ),
        );

        if ( class_exists( 'WP_Travel' )) {
            $tastypress_pro_slider_content_type = array_merge( $tastypress_pro_slider_content_type, array(
                'trip'          => esc_html__( 'Trip', 'tastypress-pro' ),
                'trip-types'    => esc_html__( 'Trip Types', 'tastypress-pro' ),
                'destination'   => esc_html__( 'Destination', 'tastypress-pro' ),
                'activity'      => esc_html__( 'Activity', 'tastypress-pro' ),
                ) );
        }

        $output = apply_filters( 'tastypress_pro_slider_content_type', $tastypress_pro_slider_content_type );

        return $output;
    }
endif;

if ( ! function_exists( 'tastypress_pro_menu_content_type' ) ) :
    /**
     * gallery_slider Options
     * @return array site gallery_slider options
     */
    function tastypress_pro_gallery_slider_content_type() {
      
        $tastypress_pro_gallery_slider_content_type = array(
            'page'      => esc_html__( 'Page', 'tastypress-pro' ),
            'post'      => esc_html__( 'Post', 'tastypress-pro' ),
            'category'  => esc_html__( 'Category', 'tastypress-pro' ),
        );

        if ( class_exists( 'WP_Travel' )) {
            $tastypress_pro_gallery_slider_content_type = array_merge( $tastypress_pro_gallery_slider_content_type, array(
                'trip'          => esc_html__( 'Trip', 'tastypress-pro' ),
                'trip-types'    => esc_html__( 'Trip Types', 'tastypress-pro' ),
                'destination'   => esc_html__( 'Destination', 'tastypress-pro' ),
                'activity'      => esc_html__( 'Activity', 'tastypress-pro' ),
                ) );
        }

        $output = apply_filters( 'tastypress_pro_gallery_slider_content_type', $tastypress_pro_gallery_slider_content_type );

        return $output;
    }
endif;


if ( ! function_exists( 'tastypress_pro_hero_content_type' ) ) :
    /**
     * hero Options
     * @return array site hero options
     */
    function tastypress_pro_hero_content_type() {
        $tastypress_pro_hero_content_type = array(
            'page'      => esc_html__( 'Page', 'tastypress-pro' ),
            'post'      => esc_html__( 'Post', 'tastypress-pro' ),
            'custom'  => esc_html__( 'Custom', 'tastypress-pro' ),
        );

        $output = apply_filters( 'tastypress_pro_hero_content_type', $tastypress_pro_hero_content_type );


        return $output;
    }
endif;

if ( ! function_exists( 'tastypress_pro_reserve_content_type' ) ) :
    /**
     * hero Options
     * @return array site hero options
     */
    function tastypress_pro_reserve_content_type() {
        $tastypress_pro_reserve_content_type = array(
            'page'      => esc_html__( 'Page', 'tastypress-pro' ),
            'post'      => esc_html__( 'Post', 'tastypress-pro' ),
            'custom'  => esc_html__( 'Custom', 'tastypress-pro' ),
        );

        $output = apply_filters( 'tastypress_pro_reserve_content_type', $tastypress_pro_reserve_content_type );


        return $output;
    }
endif;

if ( ! function_exists( 'tastypress_pro_download_content_type' ) ) :
    /**
     * hero Options
     * @return array site hero options
     */
    function tastypress_pro_download_content_type() {
        $tastypress_pro_download_content_type = array(
            'page'      => esc_html__( 'Page', 'tastypress-pro' ),
            'post'      => esc_html__( 'Post', 'tastypress-pro' ),
            'custom'  => esc_html__( 'Custom', 'tastypress-pro' ),
        );

        $output = apply_filters( 'tastypress_pro_download_content_type', $tastypress_pro_download_content_type );


        return $output;
    }
endif;

if ( ! function_exists( 'tastypress_pro_about_content_type' ) ) :
    /**
     * about Options
     * @return array site about options
     */
    function tastypress_pro_about_content_type() {
        $tastypress_pro_about_content_type = array(
            'page'      => esc_html__( 'Page', 'tastypress-pro' ),
            'post'      => esc_html__( 'Post', 'tastypress-pro' ),
            'custom'  => esc_html__( 'Custom', 'tastypress-pro' ),
        );

        if ( class_exists( 'WooCommerce' ) ) {
            $tastypress_pro_about_content_type = array_merge( $tastypress_pro_about_content_type, array(
                'product'    => esc_html__( 'Product', 'tastypress-pro' ),
                ) );
        }

        $output = apply_filters( 'tastypress_pro_about_content_type', $tastypress_pro_about_content_type );


        return $output;
    }
endif;

if ( ! function_exists( 'tastypress_pro_cta_content_type' ) ) :
    /**
     * cta Options
     * @return array site cta options
     */
    function tastypress_pro_cta_content_type() {
        $tastypress_pro_cta_content_type = array(
            'page'      => esc_html__( 'Page', 'tastypress-pro' ),
            'post'      => esc_html__( 'Post', 'tastypress-pro' ),
            'custom'  => esc_html__( 'Custom', 'tastypress-pro' ),
        );

        if ( class_exists( 'WooCommerce' ) ) {
            $tastypress_pro_cta_content_type = array_merge( $tastypress_pro_cta_content_type, array(
                'product'    => esc_html__( 'Product', 'tastypress-pro' ),
                ) );
        }

        $output = apply_filters( 'tastypress_pro_cta_content_type', $tastypress_pro_cta_content_type );


        return $output;
    }
endif;

if ( ! function_exists( 'tastypress_pro_video_content_type' ) ) :
    /**
     * video Options
     * @return array site video options
     */
    function tastypress_pro_video_content_type() {
        $tastypress_pro_video_content_type = array(
            'page'      => esc_html__( 'Page', 'tastypress-pro' ),
            'post'      => esc_html__( 'Post', 'tastypress-pro' ),
            'custom'  => esc_html__( 'Custom', 'tastypress-pro' ),
        );

        $output = apply_filters( 'tastypress_pro_video_content_type', $tastypress_pro_video_content_type );


        return $output;
    }
endif;

if ( ! function_exists( 'tastypress_pro_featured_content_type' ) ) :
    /**
     * featured Options
     * @return array site featured options
     */
    function tastypress_pro_featured_content_type() {
        $tastypress_pro_featured_content_type = array(
            'category'  => esc_html__( 'Category', 'tastypress-pro' ),
        );

        if ( class_exists( 'WP_Travel' ) ) {
            $tastypress_pro_featured_content_type = array_merge( $tastypress_pro_featured_content_type, array(
                'trip-types'    => esc_html__( 'Trip Types', 'tastypress-pro' ),
                'destination'   => esc_html__( 'Destination', 'tastypress-pro' ),
                'activity'      => esc_html__( 'Activity', 'tastypress-pro' ),
                ) );
        }

        $output = apply_filters( 'tastypress_pro_featured_content_type', $tastypress_pro_featured_content_type );


        return $output;
    }
endif;



if ( ! function_exists( 'tastypress_pro_event_content_type' ) ) :
    /**
     * Special Offer Options
     * @return array site event options
     */
    function tastypress_pro_event_content_type() {
        $tastypress_pro_event_content_type = array(
            'page'      => esc_html__( 'Page', 'tastypress-pro' ),
            'post'      => esc_html__( 'Post', 'tastypress-pro' ),
            'category'  => esc_html__( 'Category', 'tastypress-pro' ),
        );

        if ( class_exists( 'TP_Education' ) ) {
            $tastypress_pro_event_content_type = array_merge( $tastypress_pro_event_content_type, array(
                'event'   => esc_html__( 'Event', 'tastypress-pro' ),
                'event-category'   => esc_html__( 'Event Category', 'tastypress-pro' ),
                ) );
        }

        $output = apply_filters( 'tastypress_pro_event_content_type', $tastypress_pro_event_content_type );


        return $output;
    }
endif;

function tastypress_pro_event_choices() {
    $posts = get_posts( array( 'numberposts' => -1, 'post_type' => 'tp-event' ) );
    $choices = array();
    $choices[0] = esc_html__( '--Select--', 'tastypress-pro' );
    foreach ( $posts as $post ) {
        $choices[ $post->ID ] = $post->post_title;
    }
    return  $choices;
}