<?php
/**
 * 3column section
 *
 * This is the template for the content of 3column section
 *
 * @package Theme Palace
 * @subpackage tastypress Pro
 * @since tastypress Pro 1.0.0
 */
if ( ! function_exists( 'tastypress_pro_add_3column_section' ) ) :
    /**
    * Add 3column section
    *
    *@since tastypress Pro 1.0.0
    */
    function tastypress_pro_add_3column_section() {
        $options = tastypress_pro_get_theme_options();
        
        // Check if 3column is enabled on frontpage
        $three_3column_enable = apply_filters( 'tastypress_pro_section_status', true, '3column_section_enable' );

        if ( $options['home_layout'] !== 'all-design' ) {
            $three_3column_enable = false;
        }


        if ( true !== $three_3column_enable ) {
            return false;
        }
        // Get 3column section details
        $section_details = array();
        $section_details = apply_filters( 'tastypress_pro_filter_3column_section_details', $section_details );
        if ( empty( $section_details ) ) {
            return;
        }
        // Render Default 3column section now.
        tastypress_pro_render_3column_section( $section_details );
    }
endif;

if ( ! function_exists( 'tastypress_pro_get_3column_section_details' ) ) :
    /**
    * 3column section details.
    *
    * @since tastypress Pro 1.0.0
    * @param array $input 3column section details.
    */
    function tastypress_pro_get_3column_section_details( $input ) {
        $options = tastypress_pro_get_theme_options();

        $three_column_content_type  = $options['3column_content_type']; // Content type.
        $three_column_counter = $options['3column_count'];
        
        $content = array();
        switch ( $three_column_content_type ) {
            
            case 'page':
                $page_ids = array();

                for ( $i = 1; $i <= 5; $i++ ) {
                    if ( ! empty( $options['3column_content_page_' . $i] ) )
                        $page_ids[] = $options['3column_content_page_' . $i];
                }
                
                $args = array(
                    'post_type'         => 'page',
                    'post__in'          => ( array ) $page_ids,
                    'posts_per_page'    => absint( $three_column_counter ),
                    'orderby'           => 'post__in',
                    );                    
            break;

            case 'post':
                $post_ids = array();

                for ( $i = 1; $i <= $three_column_counter; $i++ ) {
                    if ( ! empty( $options['3column_content_post_' . $i] ) )
                        $post_ids[] = $options['3column_content_post_' . $i];
                }
                
                $args = array(
                    'post_type'         => 'post',
                    'post__in'          => ( array ) $post_ids,
                    'posts_per_page'    => absint( $three_column_counter ),
                    'orderby'           => 'post__in',
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'category':
                $cat_id = ! empty( $options['3column_content_category'] ) ? $options['3column_content_category'] : '';
                $args = array(
                    'post_type'         => 'post',
                    'posts_per_page'    => absint( $three_column_counter ),
                    'cat'               => absint( $cat_id ),
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'recent':
                $cat_ids = ! empty( $options['3column_category_exclude'] ) ? $options['3column_category_exclude'] : array();
                $args = array(
                    'post_type'         => 'post',
                    'posts_per_page'    => absint( $three_column_counter ),
                    'category__not_in'  => ( array ) $cat_ids,
                    'ignore_sticky_posts'   => true,
                    );            
            break;

            default:
            break;
        }

        $content['details'] = array();
        // Run The Loop.
        $query = new WP_Query( $args );
        if ( $query->have_posts() ) : 
            while ( $query->have_posts() ) : $query->the_post();
                $page_post['id']            = get_the_id();
                $page_post['title']         = get_the_title();
                $page_post['url']           = get_the_permalink();
                $page_post['excerpt']       = tastypress_pro_trim_content( $options['3column_excerpt_length'] );
                $page_post['image']         = has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'full' ) : get_template_directory_uri().'/assets/uploads/no-featured-image-590x650.jpg';

                // Push to the main array.
                array_push( $content['details'], $page_post );
            endwhile;
        endif;
        wp_reset_postdata();

            
        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// 3column section content details.
add_filter( 'tastypress_pro_filter_3column_section_details', 'tastypress_pro_get_3column_section_details' );


if ( ! function_exists( 'tastypress_pro_render_3column_section' ) ) :
  /**
   * Start 3column section
   *
   * @return string 3column content
   * @since tastypress Pro 1.0.0
   *
   */
   function tastypress_pro_render_3column_section( $content_details = array() ) {
        $options            = tastypress_pro_get_theme_options();
        $three_column_content_type  = $options['3column_content_type'];

        if ( empty( $content_details ) ) {
            return;
        } ?>
        <div id="tastypress_pro_3column_section">
            <div id="magazine-three-column-posts" class="three-column-posts relative page-section same-background">
                <div class="wrapper">
                    <?php if ( is_customize_preview()):
                    tastypress_pro_section_tooltip( 'three-column-posts-class' );
                    endif; ?>
                    <?php if ( !empty($options['3column_title']) ): ?>
                        <div class="section-header">
                            <h2 class="section-title"><?php echo esc_html( $options['3column_title'] ) ?></h2>
                        </div><!-- .section-header -->
                    <?php endif ?>
                    

                    <div class="col-3 clear">
                        <?php foreach($content_details['details'] as $content): ?>
                        <article>
                            <div class="featured-post-item">
                                <div class="featured-image">
                                    <img src="<?php echo esc_url($content['image']); ?>">

                                    <?php tastypress_pro_posted_on( $content['id'] ); ?>
                                </div><!-- .featured-image -->

                                <div class="entry-container">
                                    <?php the_category( ' ', ' ',  $content['id'] ) ?>

                                    <header class="entry-header">
                                        <h2 class="entry-title"><a href="<?php echo esc_url($content['url']); ?>"><?php echo esc_html($content['title']); ?></a></h2>
                                    </header>

                                    <div class="entry-content">
                                        <p><?php echo esc_html( $content['excerpt'] ); ?></p>
                                    </div><!-- .entry-content -->
                                </div><!-- .entry-container -->
                            </div><!-- .featured-post-item -->
                        </article>
                        <?php endforeach; ?>
                    </div><!-- .col-3 -->
                </div><!-- .wrapper -->
            </div><!-- #magazine-three-column-posts -->
        </div>
       
    <?php }
endif;
