<?php
/**
 * Blog section
 *
 * This is the template for the content of Blog section
 *
 * @package Theme Palace
 * @subpackage tastypress Pro
 * @since tastypress Pro 1.0.0
 */
if ( ! function_exists( 'tastypress_pro_add_blog_section' ) ) :
    /**
    * Add Blog section
    *
    *@since tastypress Pro 1.0.0
    */
    function tastypress_pro_add_blog_section() {
        $options = tastypress_pro_get_theme_options();
        
        // Check if blog is enabled on frontpage
        $blog_enable = apply_filters( 'tastypress_pro_section_status', true, 'blog_section_enable' );

        if ( $options['home_layout'] !== 'all-design' ) {
            $blog_enable = false;
        }


        if ( true !== $blog_enable ) {
            return false;
        }
        // Get Blog section details
        $section_details = array();
        $section_details = apply_filters( 'tastypress_pro_filter_blog_section_details', $section_details );
        if ( empty( $section_details ) ) {
            return;
        }
        // Render Default blog section now.
        tastypress_pro_render_blog_section( $section_details );
    }
endif;

if ( ! function_exists( 'tastypress_pro_get_blog_section_details' ) ) :
    /**
    * Blog section details.
    *
    * @since tastypress Pro 1.0.0
    * @param array $input Blog section details.
    */
    function tastypress_pro_get_blog_section_details( $input ) {
        $options = tastypress_pro_get_theme_options();

        $blog_content_type  = $options['blog_content_type']; // Content type.
        $blog_count = $options['blog_count'];
        $content = array();
        switch ( $blog_content_type ) {
        	
            case 'page':
                $page_ids = array();

                for ( $i = 1; $i <= 4; $i++ ) {
                    if ( ! empty( $options['blog_content_page_' . $i] ) )
                        $page_ids[] = $options['blog_content_page_' . $i];
                }
                
                $args = array(
                    'post_type'         => 'page',
                    'post__in'          => ( array ) $page_ids,
                    'posts_per_page'    => absint( $blog_count ),
                    'orderby'           => 'post__in',
                    );                    
            break;

            case 'post':
                $post_ids = array();

                for ( $i = 1; $i <= 4; $i++ ) {
                    if ( ! empty( $options['blog_content_post_' . $i] ) )
                        $post_ids[] = $options['blog_content_post_' . $i];
                }
                
                $args = array(
                    'post_type'         => 'post',
                    'post__in'          => ( array ) $post_ids,
                    'posts_per_page'    => absint( $blog_count ),
                    'orderby'           => 'post__in',
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'category':
                $cat_id = ! empty( $options['blog_content_category'] ) ? $options['blog_content_category'] : '';
                $args = array(
                    'post_type'         => 'post',
                    'posts_per_page'    => absint( $blog_count ),
                    'cat'               => absint( $cat_id ),
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'recent':
                $cat_ids = ! empty( $options['blog_category_exclude'] ) ? $options['blog_category_exclude'] : array();
                $args = array(
                    'post_type'         => 'post',
                    'posts_per_page'    => absint( $blog_count ),
                    'category__not_in'  => ( array ) $cat_ids,
                    'ignore_sticky_posts'   => true,
                    );            
            break;

            default:
            break;
        }

        $content['details'] = array();
        // Run The Loop.
        $query = new WP_Query( $args );
        if ( $query->have_posts() ) : 
            while ( $query->have_posts() ) : $query->the_post();
                $page_post['id']            = get_the_id();
                $page_post['title']         = get_the_title();
                $page_post['url']           = get_the_permalink();
                $page_post['excerpt']       = tastypress_pro_trim_content( $options['blog_excerpt_length'] );
                $page_post['image']         = has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'full' ) : get_template_directory_uri().'/assets/uploads/no-featured-image-590x650.jpg';

                // Push to the main array.
                array_push( $content['details'], $page_post );
            endwhile;
        endif;
        wp_reset_postdata();

            
        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// Blog section content details.
add_filter( 'tastypress_pro_filter_blog_section_details', 'tastypress_pro_get_blog_section_details' );


if ( ! function_exists( 'tastypress_pro_render_blog_section' ) ) :
  /**
   * Start Blog section
   *
   * @return string Blog content
   * @since tastypress Pro 1.0.0
   *
   */
   function tastypress_pro_render_blog_section( $content_details = array() ) {
        $options            = tastypress_pro_get_theme_options();
        $blog_content_type  = $options['blog_content_type'];
        $blog_title         = ! empty( $options['blog_title'] ) ? $options['blog_title'] : '';
        $blog_sub_title     = ! empty( $options['blog_sub_title'] ) ? $options['blog_sub_title'] : '';
        if ( empty( $content_details ) ) {
            return;
        } ?>
        <div id="tastypress_pro_blog_section">
            <div id="business-blog-section" class="blog-section relative page-section">
                <div class="wrapper">
                     <?php if ( is_customize_preview()):
                    tastypress_pro_section_tooltip( 'blog-section-class' );
                    endif; ?>
                     <div class="section-header">
                        <p class="section-subtitle"><?php echo esc_html( $blog_sub_title ); ?></p>
                        <h2 class="section-title"><?php echo esc_html( $blog_title ); ?></h2>
                    </div><!-- .section-header -->

                    <div class="section-content col-3">
                        <div class="archive-blog-wrapper">

                            <?php foreach($content_details['details'] as $content): ?>
                            <article>
                                <div class="popular-post-wrapper">
                                    <div class="featured-image" style="background-image: url('<?php echo esc_url($content['image']); ?>');">
                                        <a href="<?php echo esc_url($content['url']); ?>" class="post-thumbnail-link"></a>
                                    </div><!-- .featured-image -->

                                    <div class="entry-container">
                                        <div class="entry-meta">
                                            <span class="posted-on">
                                                <?php tastypress_pro_posted_on( $content['id'] ); ?>
                                            </span><!-- .posted-on -->

                                            <span class="cat-links">
                                                <?php the_category( ' ', '', $content['id'] ); ?>
                                            </span><!-- .cat-links -->
                                        </div><!-- .entry-meta -->
                                       
                                        <header class="entry-header">
                                            <h2 class="entry-title"><a href="<?php echo esc_url($content['url']); ?>"><?php echo esc_html($content['title']); ?></a></h2>
                                        </header>

                                        <div class="entry-content">
                                            <p><?php echo esc_html($content['excerpt']); ?></p>
                                        </div>
                                    </div><!-- .entry-container -->
                                </div><!-- .popular-post-wrapper -->
                            </article>
                            <?php endforeach; ?>
                        </div>
                    </div><!-- .section-content -->                        
                </div><!-- .wrapper -->
            </div><!-- #business-blog-section -->
        </div>
       
      
    <?php }
endif;