<?php
/**
 * cta section
 *
 * This is the template for the content of cta section
 *
 * @package Theme Palace
 * @subpackage tastypress Pro
 * @since tastypress Pro 1.0.0
 */
if ( ! function_exists( 'tastypress_pro_add_cta_section' ) ) :
    /**
    * Add cta section
    *
    *@since tastypress Pro 1.0.0
    */
    function tastypress_pro_add_cta_section() {
        $options = tastypress_pro_get_theme_options();
        
        // Check if cta is enabled on frontpage
        $cta_enable = apply_filters( 'tastypress_pro_section_status', true, 'cta_section_enable' );

        if ( $options['home_layout'] !== 'all-design' ) {
            $cta_enable = false;
        }
        
        if ( true !== $cta_enable ) {
            return false;
        }
        $section_details = array();

        // Get cta section details
        $section_details = apply_filters( 'tastypress_pro_filter_cta_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }
        
        tastypress_pro_render_cta_section( $section_details );

    }
endif;

if ( ! function_exists( 'tastypress_pro_get_cta_section_details' ) ) :
    /**
    * cta section details.
    *
    * @since tastypress Pro 1.0.0
    * @param array $input cta section details.
    */
    function tastypress_pro_get_cta_section_details( $input ) {
        $options = tastypress_pro_get_theme_options();

        // Content type.
        $cta_content_type  = $options['cta_content_type'];
        
        $content = array();
        switch ( $cta_content_type ) {
            
            case 'custom':
                $custom['title']        = ! empty( $options['cta_title'] ) ? $options['cta_title'] : '';
                $custom['excerpt']      = ! empty( $options['cta_description'] ) ? $options['cta_description'] : '';
                $custom['url']          = ! empty( $options['cta_btn_link'] ) ? $options['cta_btn_link'] : '';
                $custom['image']          = ! empty( $options['cta_image'] ) ? $options['cta_image'] : '';

                // Push to the main array.
                array_push( $content, $custom );
            break;

            case 'page':
                $page_id = ! empty( $options['cta_content_page'] ) ? $options['cta_content_page'] : '';
                $args = array(
                    'post_type'         => 'page',
                    'page_id'           => $page_id,
                    'posts_per_page'    => 1,
                    );                    
            break;

            case 'post':
                $post_id = ! empty( $options['cta_content_post'] ) ? $options['cta_content_post'] : '';
                $args = array(
                    'post_type'         => 'post',
                    'p'                 => $post_id,
                    'posts_per_page'    => 1,
                    );
            break;

            case 'product':
   
                $page_id = $options['cta_content_product'];
     
                $args = array(
                    'post_type'         => 'product',
                    'p'          => $page_id,
                    'posts_per_page'    => 1,
                    );
            break;


            default:
            break;
        }

        if ( 'custom' !== $cta_content_type ) :
            // Run The Loop.
            $query = new WP_Query( $args );
            if ( $query->have_posts() ) : 
                while ( $query->have_posts() ) : $query->the_post();
                    $page_post['title']     = get_the_title();
                    $page_post['id']        = get_the_id();
                    $page_post['excerpt']   = tastypress_pro_trim_content( $options['cta_excerpt_length'] );
                    $page_post['url']       = get_the_permalink();
                    $page_post['image']     = has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'full' ) : '';

                    // Push to the main array.
                    array_push( $content, $page_post );
                endwhile;
            endif;
            wp_reset_postdata();
        endif;

        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// cta section content details.
add_filter( 'tastypress_pro_filter_cta_section_details', 'tastypress_pro_get_cta_section_details' );


if ( ! function_exists( 'tastypress_pro_render_cta_section' ) ) :
  /**
   * Start cta section
   *
   * @return string cta content
   * @since tastypress Pro 1.0.0
   *
   */
   function tastypress_pro_render_cta_section( $content_details = array() ) {
        $options = tastypress_pro_get_theme_options();
        $cta_btn_title = ! empty( $options['cta_btn_title'] ) ? $options['cta_btn_title'] : '';

        $content = $content_details[0];
        if ( empty( $content_details ) ) {
            return;
        } 
        ?>
        <div id="tastypress_pro_cta_section">
            <div id="business-cta-section" class="cta-section relative page-section" style="background-image: url('<?php echo esc_url($content['image']); ?>');">
                <div class="overlay"></div>
                <div class="wrapper">
                     <?php if ( is_customize_preview()):
                    tastypress_pro_section_tooltip( 'cta-section-class' );
                    endif; ?>
                    <div class="section-header">
                        <p class="section-subtitle"><?php echo esc_html( $options['cta_sub_title'] ); ?></p>
                        <h2 class="section-title"><?php echo esc_html($content['title']); ?></h2>
                    </div><!-- .section-header -->
        
                    <div class="read-more">
                        <a href="<?php echo esc_url($content['url']); ?>" class="btn"><?php echo esc_html( $cta_btn_title ) ?></a>
                    </div><!-- .read-more -->
                </div><!-- .wrapper -->
            </div><!-- #business-cta-section -->    
        </div>
       
        <?php 
    }
endif;