<?php
/**
 * featured_products section
 *
 * This is the template for the content of featured_products section
 *
 * @package Theme Palace
 * @subpackage tastypress Pro
 * @since tastypress Pro 1.0.0
 */
if ( ! function_exists( 'tastypress_pro_add_featured_products_section' ) ) :
    /**
    * Add featured_products section
    *
    *@since tastypress Pro 1.0.0
    */
    function tastypress_pro_add_featured_products_section() {
    	$options = tastypress_pro_get_theme_options();
        // Check if featured_products is enabled on frontpage
        $featured_products_enable = apply_filters( 'tastypress_pro_section_status', true, 'featured_products_section_enable' );

        if ( $options['home_layout'] !== 'all-design' ) {
            $featured_products_enable = false;
        }

        if ( ( true !== $featured_products_enable) || ! class_exists( 'WooCommerce' ) ) {
            return false;
        }

        // Render featured_products section now.
        tastypress_pro_render_featured_products_section();
    }
endif;

if ( ! function_exists( 'tastypress_pro_render_featured_products_section' ) ) :
  /**
   * Start featured_products section
   *
   * @return string featured_products content
   * @since tastypress Pro 1.0.0
   *
   */
   function tastypress_pro_render_featured_products_section() {
        $options = tastypress_pro_get_theme_options();

    ?>
    <div id="tastypress_pro_featured_products_section">
        <div id="featured-products" class="relative page-section same-background">
        
            <div class="wrapper">
                 <?php if ( is_customize_preview()):
                    tastypress_pro_section_tooltip( 'featured-products' );
                    endif; ?>
                <div class="section-content clear col-3">
                    <?php for ( $i=1; $i <= 3 ; $i++ ) { 
                        if ( empty($options['featured_products_content_featured_products_category_'.$i]) ) {
                            continue;
                        }
                        $thumbnail_id = get_term_meta( $options['featured_products_content_featured_products_category_'.$i], 'thumbnail_id', true );
                        $image = wp_get_attachment_url( $thumbnail_id );
                        $cat_name = get_term_by( 'id', $options['featured_products_content_featured_products_category_'.$i], 'product_cat' )->name;
                        $cat_link = get_category_link( $options['featured_products_content_featured_products_category_'.$i] );
                        $banner_title = empty( $options['featured_products_title_'.$i] ) ? '' : $options['featured_products_title_'.$i];
                        $banner_short_description = empty( $options['featured_products_short_description_'.$i] ) ? '' : $options['featured_products_short_description_'.$i];
                        $featured_products_btn_title = empty( $options['featured_products_btn_title'] ) ? '' : $options['featured_products_btn_title'];
                        ?>

                    <article>
                        <div class="featured-image" style="background-image: url('<?php echo esc_url( $image ); ?>');">
                            <div class="entry-container">
                                <span class="cat-links">
                                    <ul class="post-categories">
                                        <li><a href="<?php echo esc_url( $cat_link ); ?>"><?php echo esc_html( $cat_name ); ?></a></li>
                                    </ul>
                                </span><!-- .cat-links -->

                                <header class="entry-header">
                                    <h2 class="entry-title"><a href="<?php echo esc_url( $cat_link ) ?>"><?php echo esc_html( $banner_title ); ?></a></h2>
                                </header>

                                <div class="entry-content">
                                    <p><?php echo esc_html( $banner_short_description ); ?></p>
                                </div><!-- .entry-content -->

                                <?php if( !empty( $featured_products_btn_title ) ): ?>
                                <div class="read-more">
                                    <a href="<?php echo esc_url( $cat_link ); ?>" class="btn"><?php echo esc_html( $featured_products_btn_title ); ?></a>
                                </div><!-- .read-more -->
                            <?php endif; ?>
                            </div><!-- .entry-container -->
                        </div><!-- .featured-image -->
                    </article>

                    <?php } ?>

                </div><!-- .section-content -->
            </div><!-- .wrapper -->
        </div><!-- #featured-products -->
    </div>
 

    <?php }
endif;

