<?php
/**
 * Slider section
 *
 * This is the template for the content of slider section
 *
 * @package Theme Palace
 * @subpackage tastypress Pro
 * @since tastypress Pro 1.0.0
 */
if ( ! function_exists( 'tastypress_pro_add_slider_section' ) ) :
    /**
    * Add slider section
    *
    *@since tastypress Pro 1.0.0
    */
function tastypress_pro_add_slider_section() {
    $options = tastypress_pro_get_theme_options();

        // Check if slider is enabled on frontpage
    $slider_enable = apply_filters( 'tastypress_pro_section_status', true, 'slider_section_enable' );

    if ( $options['home_layout'] !== 'all-design' ) {
            $slider_enable = false;
        }

    if ( true !== $slider_enable ) {
        return false;
    }
        // Get slider section details
    $section_details = array();
    $section_details = apply_filters( 'tastypress_pro_filter_slider_section_details', $section_details );
    if ( empty( $section_details ) ) {
        return;
    }
    tastypress_pro_render_slider_section( $section_details );
}
endif;

if ( ! function_exists( 'tastypress_pro_get_slider_section_details' ) ) :
    /**
    * slider section details.
    *
    * @since tastypress Pro 1.0.0
    * @param array $input slider section details.
    */
    function tastypress_pro_get_slider_section_details( $input ) {
        $options = tastypress_pro_get_theme_options();

        
        $slider_content_type  = $options['slider_content_type']; // Slider Content type.
        $slider_count = ! empty( $options['slider_count'] ) ? $options['slider_count'] : 3; //Slider Post Count
        
        $content = array();
        switch ( $slider_content_type ) {
        	
            case 'page':
                $page_ids = array();

                for ( $i = 1; $i <= $slider_count; $i++ ) {
                    if ( ! empty( $options['slider_content_page_' . $i] ) )
                        $page_ids[] = $options['slider_content_page_' . $i];
                }
                
                $args = array(
                    'post_type'         => 'page',
                    'post__in'          => ( array ) $page_ids,
                    'posts_per_page'    => absint( $slider_count ),
                    'orderby'           => 'post__in',
                    );                    
            break;

            case 'post':
                $post_ids = array();

                for ( $i = 1; $i <= $slider_count; $i++ ) {
                    if ( ! empty( $options['slider_content_post_' . $i] ) )
                        $post_ids[] = $options['slider_content_post_' . $i];
                }
                $args = array(
                    'post_type'             => 'post',
                    'post__in'              => ( array ) $post_ids,
                    'posts_per_page'        => absint( $slider_count ),
                    'orderby'               => 'post__in',
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'category':
                $cat_id = ! empty( $options['slider_content_category'] ) ? $options['slider_content_category'] : '';
                $args = array(
                    'post_type'             => 'post',
                    'posts_per_page'        => absint( $slider_count ),
                    'cat'                   => absint( $cat_id ),
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'product':
                $page_ids = array();

                for ( $i = 1; $i <= $latest_products_count; $i++ ) {
                    if ( ! empty( $options['latest_products_content_product_' . $i] ) ) {
                        $page_ids[] = $options['latest_products_content_product_' . $i];
                    }
                }
                
                $args = array(
                    'post_type'         => 'product',
                    'post__in'          => ( array ) $page_ids,
                    'posts_per_page'    => absint( $latest_products_count ),
                    'orderby'           => 'post__in',
                    );                    
            break;

            case 'product-category':
                $cat_id = ! empty( $options['latest_products_content_product_category'] ) ? $options['latest_products_content_product_category'] : '';
                $args = array(
                    'post_type'      => 'product',
                    'tax_query' => array(
                        array(
                            'taxonomy' => 'product_cat',
                            'field'    => 'id',
                            'terms'    => $cat_id,
                        ),
                    ),
                    'posts_per_page'  => absint( $latest_products_count ),
                    );                    
            break;

            default:
            break;
        }

            $content['details'] = array();
            // Run The Loop.
            $query = new WP_Query( $args );
            if ( $query->have_posts() ) : 
                while ( $query->have_posts() ) : $query->the_post();
                    $page_post['id']        = get_the_id();
                    $page_post['title']     = get_the_title();
                    $page_post['url']       = get_the_permalink();
                    $page_post['excerpt']   = tastypress_pro_trim_content( $options['slider_excerpt_length'] );
                    $page_post['image']     = has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'full' ) : get_template_directory_uri() . '/assets/uploads/no-featured-image-590x650.jpg';

                    // Push to the main array.
                    array_push( $content['details'], $page_post );
                endwhile;
            endif;
            wp_reset_postdata();
            
        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;

// slider section content details.
add_filter( 'tastypress_pro_filter_slider_section_details', 'tastypress_pro_get_slider_section_details' );


if ( ! function_exists( 'tastypress_pro_render_slider_section' ) ) :
  /**
   * Start slider section
   *
   * @return string slider content
   * @since tastypress Pro 1.0.0
   *
   */
   function tastypress_pro_render_slider_section( $content_details = array() ) {
        $options = tastypress_pro_get_theme_options();

        $slider_autoplay = ($options['slider_autoplay'] == true ) ? 'true' : 'false';

        if ( empty( $content_details ) ) {
            return;
        } ?>
        <div id="tastypress_pro_slider_section">
             <div id="business-slider-section" data-slick='{"slidesToShow": 1, "slidesToScroll": 1, "infinite": true, "speed": 1500, "dots": true, "arrows": false, "autoplay": <?php echo esc_attr( $options['slider_autoplay'] ) ?>, "draggable": true, "fade": false }'>
                <?php foreach ($content_details['details'] as $content) : ?>
                    <article style="background-image: url('<?php echo esc_url($content['image'])?>');">
                        <div class="wrapper">
                            <div class="business-slider-content">
                                <h4 class="sub-title"><?php echo esc_html( $options['slider_sub_title'] ); ?></h4>
                                <header class="entry-header">
                                    <h2 class="entry-title"><a href="<?php echo esc_url($content['url'])?>"><?php echo esc_html($content['title']); ?></a></h2>
                                </header>
                            <div class="entry-content">
                                <p><?php echo esc_html($content['excerpt']); ?></p>
                            </div><!-- .entry-content -->

                            <?php if ( !empty($options['slider_btn_label']) ): ?>
                                <div class="read-more">
                                    <a href="<?php echo esc_url($content['url'])?>" class="btn btn-primary" tabindex="-1">
                                        <?php echo esc_html( $options['slider_btn_label'] ); ?>
                                    </a>
                                </div><!-- .read-more -->
                            <?php endif ?>
                            
                            </div><!-- .business-slider-content -->
                        </div><!-- .wrapper -->
                    </article>
                <?php endforeach; ?>
               
            </div><!-- #business-slider-section -->
        </div>
           

    <?php }
endif;   