<?php
/**
 * hero section
 *
 * This is the template for the content of hero section
 *
 * @package Theme Palace
 * @subpackage tastypress Pro
 * @since tastypress Pro 1.0.0
 */
if ( ! function_exists( 'tastypress_pro_add_hero_section' ) ) :
    /**
    * Add hero section
    *
    *@since tastypress Pro 1.0.0
    */
    function tastypress_pro_add_hero_section() {
        $options = tastypress_pro_get_theme_options();
        
        // Check if hero is enabled on frontpage
        $hero_enable = apply_filters( 'tastypress_pro_section_status', true, 'hero_section_enable' );

    
        if ( true !== $hero_enable ) {
            return false;
        }
        $section_details = array();

        // Get hero section details
        $section_details = apply_filters( 'tastypress_pro_filter_hero_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }
        
        tastypress_pro_render_hero_section( $section_details );

    }
endif;

if ( ! function_exists( 'tastypress_pro_get_hero_section_details' ) ) :
    /**
    * hero section details.
    *
    * @since tastypress Pro 1.0.0
    * @param array $input hero section details.
    */
    function tastypress_pro_get_hero_section_details( $input ) {
        $options = tastypress_pro_get_theme_options();

        // Content type.
        $hero_content_type  = $options['hero_content_type'];
        
        $content = array();
        switch ( $hero_content_type ) {
            
            case 'custom':
                $custom['title']        = ! empty( $options['hero_title'] ) ? $options['hero_title'] : '';
                $custom['excerpt']      = ! empty( $options['hero_description'] ) ? $options['hero_description'] : '';
                $custom['url']          = ! empty( $options['hero_btn_link'] ) ? $options['hero_btn_link'] : '';
                $custom['image']          = ! empty( $options['hero_image'] ) ? $options['hero_image'] : '';

                // Push to the main array.
                array_push( $content, $custom );
            break;

            case 'page':
                $page_id = ! empty( $options['hero_content_page'] ) ? $options['hero_content_page'] : '';
                $args = array(
                    'post_type'         => 'page',
                    'page_id'           => $page_id,
                    'posts_per_page'    => 1,
                    );                    
            break;

            case 'post':
                $post_id = ! empty( $options['hero_content_post'] ) ? $options['hero_content_post'] : '';
                $args = array(
                    'post_type'         => 'post',
                    'p'                 => $post_id,
                    'posts_per_page'    => 1,
                    );
            break;

            default:
            break;
        }

        if ( 'custom' !== $hero_content_type ) :
            // Run The Loop.
            $query = new WP_Query( $args );
            if ( $query->have_posts() ) : 
                while ( $query->have_posts() ) : $query->the_post();
                    $page_post['title']     = get_the_title();
                    $page_post['excerpt']   = tastypress_pro_trim_content( $options['hero_excerpt_length'] );
                    $page_post['url']       = get_the_permalink();
                    $page_post['image']     = has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'full' ) : '';

                    // Push to the main array.
                    array_push( $content, $page_post );
                endwhile;
            endif;
            wp_reset_postdata();
        endif;

        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;


    }
endif;
// hero section content details.
add_filter( 'tastypress_pro_filter_hero_section_details', 'tastypress_pro_get_hero_section_details' );


if ( ! function_exists( 'tastypress_pro_render_hero_section' ) ) :
  /**
   * Start hero section
   *
   * @return string hero content
   * @since tastypress Pro 1.0.0
   *
   */
   function tastypress_pro_render_hero_section( $content_details = array() ) {
        $options = tastypress_pro_get_theme_options();
        $hero_btn_title = ! empty( $options['hero_btn_title'] ) ? $options['hero_btn_title'] : '';

        $content = $content_details[0];
        if ( empty( $content_details ) ) {
            return;
        } 
        ?>
        <div id="tastypress_pro_hero_section">
            <div id="hero-section" class="relative same-background">
                <div class="wrapper">
                    <?php if ( is_customize_preview()):
                    tastypress_pro_section_tooltip( 'hero-section' );
                    endif; ?>
                    <article  class="has-post-thumbnail clear">
                        <div class="featured-image">
                            <a href="<?php echo esc_url($content['url']); ?>"><img src="<?php echo esc_url($content['image']);?>" alt="<?php echo esc_attr($content['title']); ?>"></a>
                        </div><!-- .featured-image -->
                        

                        <div class="entry-container">
                            <header class="entry-header">
                                <h2 class="entry-title"><a href="<?php echo esc_url($content['url']); ?>"><?php echo esc_html($content['title']); ?></a></h2>
                            </header>

                            <div class="entry-content">
                                <p><?php echo wp_kses_post($content['excerpt']); ?></p>
                            </div><!-- .entry-content -->

                            <div class="read-more">
                                <a href="<?php echo esc_url($content['url']); ?>" class="btn">
                                    <?php echo esc_html( $hero_btn_title ) ?>
                                    <svg viewBox="0 0 512 512">
                                        <path d="M508.875,248.458l-160-160c-4.167-4.167-10.917-4.167-15.083,0c-4.167,4.167-4.167,10.917,0,15.083l141.792,141.792
                                        H10.667C4.771,245.333,0,250.104,0,256s4.771,10.667,10.667,10.667h464.917L333.792,408.458c-4.167,4.167-4.167,10.917,0,15.083
                                        c2.083,2.083,4.813,3.125,7.542,3.125c2.729,0,5.458-1.042,7.542-3.125l160-160C513.042,259.375,513.042,252.625,508.875,248.458z
                                        "/>
                                    </svg>
                                </a>
                            </div>
                            <?php  
                                $category_args = array(
                                    'post_type'         => 'post',
                                    'posts_per_page'    => absint( 3 ),
                                    'cat'               => absint( $options['hero_content_category'] ),
                                    'ignore_sticky_posts'   => true,
                                    );
                            ?>
                            <div class="customer clear">
                                <div class="customer-image">
                                    <?php  
                                        $query = new WP_Query( $category_args );
                                        if ( $query->have_posts() ) : 
                                            while ( $query->have_posts() ) : $query->the_post();
                                    ?>  
                                        <a href="<?php the_permalink(); ?>"><img src="<?php echo esc_url(get_the_post_thumbnail_url( get_the_id(), 'thumbnail' ));?>"></a>
                                    <?php
                                            endwhile;
                                        endif;
                                        wp_reset_postdata();
                                    ?>
                                </div><!-- .featured-image -->

                                <div class="customer-details">
                                    <div class="customer-header">
                                        <h2 class="admin-name"><?php echo esc_html( $options['hero_label'] ); ?></h2>
                                    </div>
                                    <div class="review">
                                        <span><?php echo esc_html( $options['hero_sub_label'] ); ?></span>
                                    </div>  
                                </div>
                            </div>
                        </div><!-- .entry-container -->
                    </article>
                </div><!-- .wrapper -->
            </div><!-- #hero-section -->
        </div>
       
    
        <?php 
    }
endif;