<?php
/**
 * highlighted section
 *
 * This is the template for the content of highlighted section
 *
 * @package Theme Palace
 * @subpackage tastypress Pro
 * @since tastypress Pro 1.0.0
 */
if ( ! function_exists( 'tastypress_pro_add_highlighted_section' ) ) :
    /**
    * Add highlighted section
    *
    *@since tastypress Pro 1.0.0
    */
    function tastypress_pro_add_highlighted_section() {
        $options = tastypress_pro_get_theme_options();
        
        // Check if highlighted is enabled on frontpage
        $highlighted_enable = apply_filters( 'tastypress_pro_section_status', true, 'highlighted_section_enable' );

        if ( $options['home_layout'] !== 'all-design' ) {
            $highlighted_enable = false;
        }

        if ( true !== $highlighted_enable ) {
            return false;
        }
        // Get highlighted section details
        $section_details = array();
        $section_details = apply_filters( 'tastypress_pro_filter_highlighted_section_details', $section_details );
        if ( empty( $section_details ) ) {
            return;
        }
        // Render Default highlighted section now.
        tastypress_pro_render_highlighted_section( $section_details );
    }
endif;

if ( ! function_exists( 'tastypress_pro_get_highlighted_section_details' ) ) :
    /**
    * highlighted section details.
    *
    * @since tastypress Pro 1.0.0
    * @param array $input highlighted section details.
    */
    function tastypress_pro_get_highlighted_section_details( $input ) {
        $options = tastypress_pro_get_theme_options();

        $highlighted_content_type  = $options['highlighted_content_type']; // Content type.
        
        $content = array();
        switch ( $highlighted_content_type ) {
            
            case 'page':
                $page_ids = array();

                for ( $i = 1; $i <= 5; $i++ ) {
                    if ( ! empty( $options['highlighted_content_page_' . $i] ) )
                        $page_ids[] = $options['highlighted_content_page_' . $i];
                }
                
                $args = array(
                    'post_type'         => 'page',
                    'post__in'          => ( array ) $page_ids,
                    'posts_per_page'    => absint( 5 ),
                    'orderby'           => 'post__in',
                    );                    
            break;

            case 'post':
                $post_ids = array();

                for ( $i = 1; $i <= 5; $i++ ) {
                    if ( ! empty( $options['highlighted_content_post_' . $i] ) )
                        $post_ids[] = $options['highlighted_content_post_' . $i];
                }
                
                $args = array(
                    'post_type'         => 'post',
                    'post__in'          => ( array ) $post_ids,
                    'posts_per_page'    => absint( 5 ),
                    'orderby'           => 'post__in',
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'category':
                $cat_id = ! empty( $options['highlighted_content_category'] ) ? $options['highlighted_content_category'] : '';
                $args = array(
                    'post_type'         => 'post',
                    'posts_per_page'    => absint( 5 ),
                    'cat'               => absint( $cat_id ),
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'recent':
                $cat_ids = ! empty( $options['highlighted_category_exclude'] ) ? $options['highlighted_category_exclude'] : array();
                $args = array(
                    'post_type'         => 'post',
                    'posts_per_page'    => absint( 5 ),
                    'category__not_in'  => ( array ) $cat_ids,
                    'ignore_sticky_posts'   => true,
                    );            
            break;

            default:
            break;
        }

        $content['details'] = array();
        // Run The Loop.
        $query = new WP_Query( $args );
        if ( $query->have_posts() ) : 
            while ( $query->have_posts() ) : $query->the_post();
                $page_post['id']            = get_the_id();
                $page_post['title']         = get_the_title();
                $page_post['url']           = get_the_permalink();
                $page_post['excerpt']       = tastypress_pro_trim_content( $options['highlighted_excerpt_length'] );
                $page_post['image']         = has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'full' ) : get_template_directory_uri().'/assets/uploads/no-featured-image-590x650.jpg';

                // Push to the main array.
                array_push( $content['details'], $page_post );
            endwhile;
        endif;
        wp_reset_postdata();

            
        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// highlighted section content details.
add_filter( 'tastypress_pro_filter_highlighted_section_details', 'tastypress_pro_get_highlighted_section_details' );


if ( ! function_exists( 'tastypress_pro_render_highlighted_section' ) ) :
  /**
   * Start highlighted section
   *
   * @return string highlighted content
   * @since tastypress Pro 1.0.0
   *
   */
   function tastypress_pro_render_highlighted_section( $content_details = array() ) {
        $options            = tastypress_pro_get_theme_options();
        $highlighted_content_type  = $options['highlighted_content_type'];

        if ( empty( $content_details ) ) {
            return;
        } ?>
        <div id="tastypress_pro_highlighted_section">
            <div id="magazine-highlighted-posts" class="highlighted-posts relative">
                <div class="wrapper">
                    <?php if ( is_customize_preview()):
                    tastypress_pro_section_tooltip( 'highlighted-posts-class' );
                    endif; ?>
                    <div class="col-3 grid clear">
                        <?php foreach($content_details['details'] as $content): ?>
                        <article class="grid-item">
                            <div class="highlighted-post-item">
                                <div class="featured-image">
                                    <img src="<?php echo esc_url($content['image']); ?>">
                                </div><!-- .featured-image -->

                                <div class="entry-container">
                                    <?php the_category( ' ', ' ',  $content['id'] ) ?>

                                    <header class="entry-header">
                                        <h2 class="entry-title"><a href="<?php echo esc_url($content['url']); ?>"><?php echo esc_html($content['title']); ?></a></h2>
                                    </header>

                                    <?php tastypress_pro_posted_on( $content['id'] ); ?>
                                </div><!-- .entry-container -->
                            </div><!-- .highlighted-post-item -->
                        </article>
                        <?php endforeach; ?>
                    </div><!-- .col-3 -->
                </div><!-- .wrapper -->
            </div><!-- #magazine-highlighted-posts -->
        </div>
       
    <?php }
endif;
