<?php
/**
 * magazine_featured_post section
 *
 * This is the template for the content of magazine_featured_post section
 *
 * @package Theme Palace
 * @subpackage tastypress Pro
 * @since tastypress Pro 1.0.0
 */
if ( ! function_exists( 'tastypress_pro_add_magazine_featured_post_section' ) ) :
    /**
    * Add magazine_featured_post section
    *
    *@since tastypress Pro 1.0.0
    */
    function tastypress_pro_add_magazine_featured_post_section() {
        $options = tastypress_pro_get_theme_options();
        
        // Check if magazine_featured_post is enabled on frontpage
        $three_magazine_featured_post_enable = apply_filters( 'tastypress_pro_section_status', true, 'magazine_featured_post_section_enable' );

        if ( $options['home_layout'] !== 'all-design' ) {
            $three_magazine_featured_post_enable = false;
        }


        if ( true !== $three_magazine_featured_post_enable ) {
            return false;
        }
        // Get magazine_featured_post section details
        $section_details = array();
        $section_details = apply_filters( 'tastypress_pro_filter_magazine_featured_post_section_details', $section_details );
        if ( empty( $section_details ) ) {
            return;
        }
        // Render Default magazine_featured_post section now.
        tastypress_pro_render_magazine_featured_post_section( $section_details );
    }
endif;

if ( ! function_exists( 'tastypress_pro_get_magazine_featured_post_section_details' ) ) :
    /**
    * magazine_featured_post section details.
    *
    * @since tastypress Pro 1.0.0
    * @param array $input magazine_featured_post section details.
    */
    function tastypress_pro_get_magazine_featured_post_section_details( $input ) {
        $options = tastypress_pro_get_theme_options();

        $magazine_featured_post_content_type  = $options['magazine_featured_post_content_type']; // Content type.
        $magazine_featured_post_counter = $options['magazine_featured_post_count'];
        
        $content = array();
        switch ( $magazine_featured_post_content_type ) {
            
            case 'page':
                $page_ids = array();

                for ( $i = 1; $i <= 5; $i++ ) {
                    if ( ! empty( $options['magazine_featured_post_content_page_' . $i] ) )
                        $page_ids[] = $options['magazine_featured_post_content_page_' . $i];
                }
                
                $args = array(
                    'post_type'         => 'page',
                    'post__in'          => ( array ) $page_ids,
                    'posts_per_page'    => absint( $magazine_featured_post_counter ),
                    'orderby'           => 'post__in',
                    );                    
            break;

            case 'post':
                $post_ids = array();

                for ( $i = 1; $i <= $magazine_featured_post_counter; $i++ ) {
                    if ( ! empty( $options['magazine_featured_post_content_post_' . $i] ) )
                        $post_ids[] = $options['magazine_featured_post_content_post_' . $i];
                }
                
                $args = array(
                    'post_type'         => 'post',
                    'post__in'          => ( array ) $post_ids,
                    'posts_per_page'    => absint( $magazine_featured_post_counter ),
                    'orderby'           => 'post__in',
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'category':
                $cat_id = ! empty( $options['magazine_featured_post_content_category'] ) ? $options['magazine_featured_post_content_category'] : '';
                $args = array(
                    'post_type'         => 'post',
                    'posts_per_page'    => absint( $magazine_featured_post_counter ),
                    'cat'               => absint( $cat_id ),
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'recent':
                $cat_ids = ! empty( $options['magazine_featured_post_category_exclude'] ) ? $options['magazine_featured_post_category_exclude'] : array();
                $args = array(
                    'post_type'         => 'post',
                    'posts_per_page'    => absint( $magazine_featured_post_counter ),
                    'category__not_in'  => ( array ) $cat_ids,
                    'ignore_sticky_posts'   => true,
                    );            
            break;

            default:
            break;
        }

        $content['details'] = array();
        // Run The Loop.
        $query = new WP_Query( $args );
        if ( $query->have_posts() ) : 
            while ( $query->have_posts() ) : $query->the_post();
                $page_post['id']            = get_the_id();
                $page_post['title']         = get_the_title();
                $page_post['url']           = get_the_permalink();
                $page_post['excerpt']       = tastypress_pro_trim_content( $options['magazine_featured_post_excerpt_length'] );
                $page_post['image']         = has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'full' ) : get_template_directory_uri().'/assets/uploads/no-featured-image-590x650.jpg';

                // Push to the main array.
                array_push( $content['details'], $page_post );
            endwhile;
        endif;
        wp_reset_postdata();

            
        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// magazine_featured_post section content details.
add_filter( 'tastypress_pro_filter_magazine_featured_post_section_details', 'tastypress_pro_get_magazine_featured_post_section_details' );


if ( ! function_exists( 'tastypress_pro_render_magazine_featured_post_section' ) ) :
  /**
   * Start magazine_featured_post section
   *
   * @return string magazine_featured_post content
   * @since tastypress Pro 1.0.0
   *
   */
   function tastypress_pro_render_magazine_featured_post_section( $content_details = array() ) {
        $options            = tastypress_pro_get_theme_options();
        $magazine_featured_post_content_type  = $options['magazine_featured_post_content_type'];

        if ( empty( $content_details ) ) {
            return;
        } ?>
        <div id="tastypress_pro_magazine_featured_post_section">
            <div id="magazine-featured-posts" class="relative page-section same-background">
                <div class="wrapper">
                    <?php if ( is_customize_preview()):
                    tastypress_pro_section_tooltip( 'magazine-featured-posts' );
                    endif; ?>
                    <div class="section-header">
                        <h2 class="section-title">Featured Posts</h2>
                    </div><!-- .section-header -->

                    <div class="col-2 clear">
                        <?php foreach($content_details['details'] as $content): ?>
                        <article>
                            <div class="featured-post-item">
                                <div class="featured-image">
                                    <img src="<?php echo esc_url($content['image']); ?>">

                                    <?php tastypress_pro_posted_on( $content['id'] ); ?>
                                </div><!-- .featured-image -->

                                <div class="entry-container">
                                    <?php the_category( ' ', ' ',  $content['id'] ) ?>

                                    <header class="entry-header">
                                        <h2 class="entry-title"><a href="<?php echo esc_url($content['url']); ?>"><?php echo esc_html($content['title']); ?></a></h2>
                                    </header>

                                    <div class="entry-content">
                                        <p><?php echo esc_html( $content['excerpt'] ); ?></p>
                                    </div><!-- .entry-content -->
                                </div><!-- .entry-container -->
                            </div><!-- .featured-post-item -->
                        </article>
                        <?php endforeach; ?>
                    </div><!-- .col-2 -->
                </div><!-- .wrapper -->
            </div><!-- #magazine-featured-posts -->
        </div>
       
      
    <?php }
endif;
