<?php
/**
 * menu section
 *
 * This is the template for the content of gallery_slider section
 *
 * @package Theme Palace
 * @subpackage tastypress Pro
 * @since tastypress Pro 1.0.0
 */
if ( ! function_exists( 'tastypress_pro_add_menu_section' ) ) :
    /**
    * Add menu section
    *
    *@since tastypress Pro 1.0.0
    */
    function tastypress_pro_add_menu_section() {
        $options = tastypress_pro_get_theme_options();
        // Check if menu is enabled on frontpage
        $menu_enable = apply_filters( 'tastypress_pro_section_status', true, 'menu_section_enable' );

        if ( true !== $menu_enable || ! class_exists( 'WooCommerce' ) ) {
            return false;
        }

        // Get menu section details
        $section_details = array();
        $section_details = apply_filters( 'tastypress_pro_filter_menu_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render menu section now.
        tastypress_pro_render_menu_section( $section_details );
    }
endif;

if ( ! function_exists( 'tastypress_pro_get_menu_section_details' ) ) :
    /**
    * menu section details.
    *
    * @since tastypress Pro 1.0.0
    * @param array $input menu section details.
    */
    function tastypress_pro_get_menu_section_details( $input ) {
        $options = tastypress_pro_get_theme_options();

        $cats = array();
        for ( $j=1; $j <= $options['menu_count'] ; $j++ ) { 
             $cats[] = $options['menu_category_'.$j];
        }
        $content = array();
        $i = 0;
        foreach ( $cats as $cat_id ) :
            $content[$i] = array();
     
            $args = array(
            'post_type'         => 'product',
            'tax_query'         => array(
                array(
                    'taxonomy'  => 'product_cat',
                    'field'     => 'id',
                    'terms'     => $cat_id
                )
            ) );                


            // Run The Loop.
            $query = new WP_Query( $args );
            if ( $query->have_posts() ) : 
                while ( $query->have_posts() ) : $query->the_post();
                    $page_post[$i]['id']     = get_the_id();
                    $page_post[$i]['title']     = get_the_title();
                    $page_post[$i]['url']       = get_the_permalink();
                    $page_post['excerpt']   = tastypress_pro_trim_content( 10 );
                    $page_post[$i]['image']     = has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'post-thumbnail' ) : '';

                    // Push to the main array.
                    array_push( $content[$i], $page_post[$i] );
                endwhile;
            endif;
            wp_reset_postdata();
            $i++;
        endforeach;

            
        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// menu section content details.
add_filter( 'tastypress_pro_filter_menu_section_details', 'tastypress_pro_get_menu_section_details' );


if ( ! function_exists( 'tastypress_pro_render_menu_section' ) ) :
  /**
   * Start menu section
   *
   * @return string menu content
   * @since tastypress Pro 1.0.0
   *
   */
   function tastypress_pro_render_menu_section( $content_details = array() ) {
        $options = tastypress_pro_get_theme_options();
        $cats = array();
        for ( $j=1; $j <= $options['menu_count'] ; $j++ ) { 
             $cats[] = $options['menu_category_'.$j];
        }
     ?> 
        <div id="tastypress_pro_menu_section">
            <div id="our-menu" class="page-section same-background">
                <div class="wrapper">
                    <?php if ( is_customize_preview()):
                        tastypress_pro_section_tooltip( 'our-menu' );
                    endif; ?>
                   <div class="section-header">
                        <?php if( !empty( $options['menu_sub_title'] ) ): ?>
                            <h3 class="section-subtitle"><?php echo esc_html( $options['menu_sub_title'] ) ; ?></h3>
                        <?php endif; 
                        if( !empty( $options['menu_title'] ) ):
                        ?>
                            <h2 class="section-title"><?php echo esc_html( $options['menu_title'] ) ; ?></h2>
                        <?php endif; ?>
                    </div><!-- .section-header -->

                    <div class="section-content">
                        <div class="product-filtering">
                            <ul class="product-nav">
                                <?php $i = 1 ; foreach ( $cats as $cat ): 
                                    $png = $options['menu_category_image_'.$i];
                                ?>
                                    <?php if ( !empty($cat) ): ?>
                                        <li>
                                            <a href="#" data-slug="<?php echo absint( $cat ) ; ?>" class="<?php echo $i == 1 ? 'active' : '' ; ?>">
                                                <?php if ( !empty($png) ): ?>
                                                    <img src="<?php echo esc_url( $png ) ?>">
                                                <?php endif ?>   

                                                <?php echo get_term_by( 'id', $cat, 'product_cat' )->name; ?>                                        
                                            </a>
                                        </li>
                                    <?php endif ?>
                                   
                                <?php $i++ ; endforeach ?>
                            </ul>
                        </div><!-- .product-filtering -->
                        <div class="product-wrapper">

                           <ul class="products columns-3 product-slider" data-slick='{"slidesToShow": 3, "slidesToScroll": 4, "infinite": false, "speed": 1500, "dots": false, "arrows": true, "autoplay": false, "draggable": true, "fade": false }'>
                                <?php $i = 0 ; foreach ( $content_details as $content_detail ): ?>
                                <?php foreach ( $content_detail as $content ): ?>
                                <li class="product featured-products <?php echo absint( $cats[$i] ) ; ?>">
                                    <a href="<?php echo esc_url( $content['url'] ) ; ?>" class="woocommerce-LoopProduct-link woocommerce-loop-product__link">
                                        <img width="330" height="400" src="<?php echo esc_url( $content['image'] ) ; ?>">
                                     </a>
                                    <div class="product-header">
                                        <h2 class="woocommerce-loop-product__title"><a href="<?php echo esc_url( $content['url'] ) ; ?>"> <?php echo esc_html( $content['title'] ) ; ?></a></h2>
                                         <span class="price clear">
                                            <?php 
                                            $product = new WC_Product( $content['id'] );
                                            echo $product->get_price_html();
                                            ?> 
                                        </span>
                                    </div>                                   
                                </li>
                                <?php endforeach ?>
                                <?php $i++; endforeach ?>
                            


                            </ul><!-- .product-slider -->
                        </div>
                    </div>
                </div>
            </div><!-- #our-menu -->
        </div>
         

    <?php }
endif;