<?php
/**
 * release section
 *
 * This is the template for the content of release section
 *
 * @package Theme Palace
 * @subpackage tastypress Pro
 * @since tastypress Pro 1.0.0
 */
if ( ! function_exists( 'tastypress_pro_add_release_section' ) ) :
    /**
    * Add release section
    *
    *@since tastypress Pro 1.0.0
    */
    function tastypress_pro_add_release_section() {
        $options = tastypress_pro_get_theme_options();
        
        // Check if release is enabled on frontpage
        $release_enable = apply_filters( 'tastypress_pro_section_status', true, 'release_section_enable' );

        if ( $options['home_layout'] !== 'all-design' ) {
            $release_enable = false;
        }



        if ( true !== $release_enable ) {
            return false;
        }
        // Get release section details
        $section_details = array();
        $section_details = apply_filters( 'tastypress_pro_filter_release_section_details', $section_details );
        if ( empty( $section_details ) ) {
            return;
        }
        // Render Default release section now.
        tastypress_pro_render_release_section( $section_details );
    }
endif;

if ( ! function_exists( 'tastypress_pro_get_release_section_details' ) ) :
    /**
    * release section details.
    *
    * @since tastypress Pro 1.0.0
    * @param array $input release section details.
    */
    function tastypress_pro_get_release_section_details( $input ) {
        $options = tastypress_pro_get_theme_options();

        $release_content_type  = $options['release_content_type']; // Content type.
        
        $content = array();
        switch ( $release_content_type ) {
        	
            case 'page':
                $page_ids = array();

                for ( $i = 1; $i <= 4; $i++ ) {
                    if ( ! empty( $options['release_content_page_' . $i] ) )
                        $page_ids[] = $options['release_content_page_' . $i];
                }
                
                $args = array(
                    'post_type'         => 'page',
                    'post__in'          => ( array ) $page_ids,
                    'posts_per_page'    => absint( 4 ),
                    'orderby'           => 'post__in',
                    );                    
            break;

            case 'post':
                $post_ids = array();

                for ( $i = 1; $i <= 4; $i++ ) {
                    if ( ! empty( $options['release_content_post_' . $i] ) )
                        $post_ids[] = $options['release_content_post_' . $i];
                }
                
                $args = array(
                    'post_type'         => 'post',
                    'post__in'          => ( array ) $post_ids,
                    'posts_per_page'    => absint( 4 ),
                    'orderby'           => 'post__in',
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'category':
                $cat_id = ! empty( $options['release_content_category'] ) ? $options['release_content_category'] : '';
                $args = array(
                    'post_type'         => 'post',
                    'posts_per_page'    => absint( 4 ),
                    'cat'               => absint( $cat_id ),
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'recent':
                $cat_ids = ! empty( $options['release_category_exclude'] ) ? $options['release_category_exclude'] : array();
                $args = array(
                    'post_type'         => 'post',
                    'posts_per_page'    => absint( 4 ),
                    'category__not_in'  => ( array ) $cat_ids,
                    'ignore_sticky_posts'   => true,
                    );            
            break;

            default:
            break;
        }

        $content['details'] = array();
        // Run The Loop.
        $query = new WP_Query( $args );
        if ( $query->have_posts() ) : 
            while ( $query->have_posts() ) : $query->the_post();
                $page_post['id']            = get_the_id();
                $page_post['title']         = get_the_title();
                $page_post['url']           = get_the_permalink();
                $page_post['excerpt']       = tastypress_pro_trim_content( $options['release_excerpt_length'] );
                $page_post['image']         = has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'full' ) : get_template_directory_uri().'/assets/uploads/no-featured-image-590x650.jpg';

                // Push to the main array.
                array_push( $content['details'], $page_post );
            endwhile;
        endif;
        wp_reset_postdata();

            
        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// release section content details.
add_filter( 'tastypress_pro_filter_release_section_details', 'tastypress_pro_get_release_section_details' );


if ( ! function_exists( 'tastypress_pro_render_release_section' ) ) :
  /**
   * Start release section
   *
   * @return string release content
   * @since tastypress Pro 1.0.0
   *
   */
   function tastypress_pro_render_release_section( $content_details = array() ) {
        $options            = tastypress_pro_get_theme_options();
        $release_content_type  = $options['release_content_type'];
        $release_title         = ! empty( $options['release_title'] ) ? $options['release_title'] : '';
        $release_sub_title     = ! empty( $options['release_sub_title'] ) ? $options['release_sub_title'] : '';
        if ( empty( $content_details ) ) {
            return;
        } ?>
        <div id="tastypress_pro_release_section">
            <div id="release" class="page-section">
                <div class="wrapper">
                     <?php if ( is_customize_preview()):
                    tastypress_pro_section_tooltip( 'release' );
                    endif; ?>
                    <div class="section-header">
                        <p class="section-subtitle"><?php echo esc_html( $release_sub_title ); ?></p>
                        <h2 class="section-title"><?php echo esc_html( $release_title ); ?></h2>
                    </div><!-- .section-header -->

                    <div class="release-wrapper col-3 clear">
                        <?php foreach($content_details['details'] as $content): ?>
                            <article class="hentry">
                                <div class="featured-image" style="background-image: url('<?php echo esc_url($content['image']); ?>');">
                                    <header class="entry-header">
                                        <h2 class="entry-title"><a href="<?php echo esc_url($content['url']); ?>"><?php echo esc_html($content['title']); ?></a></h2>
                                    </header>
                                </div>
                            </article>
                        <?php endforeach; ?>
                    </div><!-- .release-wrapper -->
                </div><!-- .wrapper -->
            </div><!-- #relaese -->
        </div>
     
      
    <?php }
endif;