<?php
/**
 * Subscription section
 *
 * This is the template for the content of subscription section
 *
 * @package Theme Palace
 * @subpackage tastypress Pro
 * @since tastypress Pro 1.0.0
 */
if ( ! function_exists( 'tastypress_pro_add_subscription_section' ) ) :
    /**
    * Add subscription section
    *
    *@since tastypress Pro 1.0.0
    */
    function tastypress_pro_add_subscription_section() {
        $options = tastypress_pro_get_theme_options();

        // Check if subscription is enabled on frontpage
        $subscription_enable = apply_filters( 'tastypress_pro_section_status', true, 'subscription_section_enable' );

        if ( $options['home_layout'] !== 'all-design' ) {
            $subscription_enable = false;
        }
        
        if ( true !== $subscription_enable ) {
           return false;
        }

        // Render subscription section now.
        tastypress_pro_render_subscription_section();
    }
endif;

if ( ! function_exists( 'tastypress_pro_render_subscription_section' ) ) :
  /**
   * Start subscription section
   *
   * @return string subscription content
   * @since tastypress Pro 1.0.0
   *
   */
   function tastypress_pro_render_subscription_section() {
        if ( ! class_exists( 'Jetpack' ) ) {
           return;
        } elseif ( class_exists( 'Jetpack' ) ) {
            if ( ! Jetpack::is_module_active( 'subscriptions' ) )
               return;
        }
        $options = tastypress_pro_get_theme_options();

        $subscription_title             = ! empty( $options['subscription_title'] ) ? $options['subscription_title'] : '';
        $subscription_sub_title         = ! empty( $options['subscription_sub_title'] ) ? $options['subscription_sub_title'] : '';
        $subscription_description       = ! empty( $options['subscription_description'] ) ? $options['subscription_description'] : '';
        $subscription_btn_title         = ! empty( $options['subscription_btn_title'] ) ? $options['subscription_btn_title'] : esc_html__( 'Subscribe Now', 'tastypress-pro' );
        $subscription_bg_image          = ! empty( $options['subscription_bg_image'] ) ? $options['subscription_bg_image'] : '';
   
        ?>
        <div id="tastypress_pro_subscription_section">
             <div id="subscribe-now" class="relative page-section" style="background-image: url('<?php echo esc_url($subscription_bg_image); ?>');">
                <div class="overlay"></div>
                <div class="wrapper">
                <?php if ( is_customize_preview()):
                    tastypress_pro_section_tooltip( 'subscribe-now' );
                    endif; ?>
                    <div class="section-header">
                        <?php if( !empty( $subscription_sub_title ) ): ?>
                            <h3 class="section-subtitle"><?php echo esc_html($subscription_sub_title); ?></h3>
                        <?php endif;
                        if( !empty( $subscription_title ) ):
                            ?>
                        <h2 class="section-title"><?php echo esc_html($subscription_title); ?></h2>
                    <?php endif; ?>
                    <span class="separator"></span>
                </div><!-- .section-header -->

                <?php if( !empty( $subscription_description ) ): ?>
                    <div class="entry-content">
                        <p><?php echo esc_html($subscription_description); ?></p>
                    </div><!-- .entry-content -->
                <?php endif; ?>

                <div class="subscribe-form-wrapper">

                    <?php 
                    $subscription_shortcode = '[jetpack_subscription_form title="" subscribe_text="" subscribe_button="' . esc_html( $subscription_btn_title ) . '" show_subscribers_total="0"]';
                    echo do_shortcode( wp_kses_post( $subscription_shortcode ) ); 
                    ?> 

                </div>

            </div><!-- .wrapper -->
        </div>
    </div>
       

    <?php }
endif; ?>

