<?php
/**
 * video section
 *
 * This is the template for the content of video section
 *
 * @package Theme Palace
 * @subpackage tastypress Pro
 * @since tastypress Pro 1.0.0
 */
if ( ! function_exists( 'tastypress_pro_add_video_section' ) ) :
    /**
    * Add video section
    *
    *@since tastypress Pro 1.0.0
    */
    function tastypress_pro_add_video_section() {
        $options = tastypress_pro_get_theme_options();
        
        // Check if video is enabled on frontpage
        $video_enable = apply_filters( 'tastypress_pro_section_status', true, 'video_section_enable' );

        if ( $options['home_layout'] !== 'all-design' ) {
            $video_enable = false;
        }


        if ( true !== $video_enable ) {
            return false;
        }
        $section_details = array();

        // Get video section details
        $section_details = apply_filters( 'tastypress_pro_filter_video_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }
        
        tastypress_pro_render_video_section( $section_details );

    }
endif;

if ( ! function_exists( 'tastypress_pro_get_video_section_details' ) ) :
    /**
    * video section details.
    *
    * @since tastypress Pro 1.0.0
    * @param array $input video section details.
    */
    function tastypress_pro_get_video_section_details( $input ) {
        $options = tastypress_pro_get_theme_options();

        // Content type.
        $video_content_type  = $options['video_content_type'];
        
        $content = array();
        switch ( $video_content_type ) {
            
            case 'custom':
                $custom['title']        = ! empty( $options['video_title'] ) ? $options['video_title'] : '';
                $custom['excerpt']      = ! empty( $options['video_description'] ) ? $options['video_description'] : '';
                $custom['url']          = ! empty( $options['video_btn_link'] ) ? $options['video_btn_link'] : '';
                $custom['image']          = ! empty( $options['video_image'] ) ? $options['video_image'] : '';

                // Push to the main array.
                array_push( $content, $custom );
            break;

            case 'page':
                $page_id = ! empty( $options['video_content_page'] ) ? $options['video_content_page'] : '';
                $args = array(
                    'post_type'         => 'page',
                    'page_id'           => $page_id,
                    'posts_per_page'    => 1,
                    );                    
            break;

            case 'post':
                $post_id = ! empty( $options['video_content_post'] ) ? $options['video_content_post'] : '';
                $args = array(
                    'post_type'         => 'post',
                    'p'                 => $post_id,
                    'posts_per_page'    => 1,
                    );
            break;

            case 'product':
   
                $page_id = $options['video_content_product'];
     
                $args = array(
                    'post_type'         => 'product',
                    'p'          => $page_id,
                    'posts_per_page'    => 1,
                    );
            break;


            default:
            break;
        }

        if ( 'custom' !== $video_content_type ) :
            // Run The Loop.
            $query = new WP_Query( $args );
            if ( $query->have_posts() ) : 
                while ( $query->have_posts() ) : $query->the_post();
                    $page_post['title']     = get_the_title();
                    $page_post['id']        = get_the_id();
                    $page_post['excerpt']   = tastypress_pro_trim_content( $options['video_excerpt_length'] );
                    $page_post['url']       = get_the_permalink();
                    $page_post['image']     = has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'full' ) : '';

                    // Push to the main array.
                    array_push( $content, $page_post );
                endwhile;
            endif;
            wp_reset_postdata();
        endif;

        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// video section content details.
add_filter( 'tastypress_pro_filter_video_section_details', 'tastypress_pro_get_video_section_details' );


if ( ! function_exists( 'tastypress_pro_render_video_section' ) ) :
  /**
   * Start video section
   *
   * @return string video content
   * @since tastypress Pro 1.0.0
   *
   */
   function tastypress_pro_render_video_section( $content_details = array() ) {
        $options = tastypress_pro_get_theme_options();
        $video_btn_title = ! empty( $options['video_btn_title'] ) ? $options['video_btn_title'] : '';

        $content = $content_details[0];
        if ( empty( $content_details ) ) {
            return;
        } 
        ?>
        <div id="tastypress_pro_video_section">
            <div id="video" class="relative page-section" style="background-image:url('<?php echo esc_url($content['image']); ?>')">
                <div class="wrapper">
                     <?php if ( is_customize_preview()):
                    tastypress_pro_section_tooltip( 'video' );
                    endif; ?>
                    <div class="video-wrapper">
                        <div class="section-header">
                            <p class="section-subtitle"><?php echo esc_html( $options['video_sub_title'] ) ; ?></p>
                            <h2 class="section-title"><?php echo esc_html($content['title']); ?></h2>
                        </div>

                        <div class="section-content">
                            <div class="entry-content">
                                <p><?php echo esc_html($content['excerpt']); ?></p>
                            </div><!-- .entry-content -->

                            <?php if ( !empty( $options['video_btn_link'] ) ): ?>
                                <div class="video-button">
                                    <a href="<?php echo esc_html( $options['video_btn_link'] ); ?>" class="popup-youtube">
                                        <svg class="svg-inline--fa fa-play fa-w-14" viewBox="0 0 448 512"><path d="M424.4 214.7L72.4 6.6C43.8-10.3 0 6.1 0 47.9V464c0 37.5 40.7 60.1 72.4 41.3l352-208c31.4-18.5 31.5-64.1 0-82.6z"></path></svg>
                                    </a>
                                </div>
                            <?php endif ?>
                            
                        </div><!-- .section-content -->
                    </div>
                </div>
            </div>
        </div>
      
    
        <?php 
    }
endif;